/* eslint-disable import/no-duplicates */
declare module '@sage/x3-project-management-data-api-partial' {
    import type { Package as SageX3MasterData$Package, ProductCategoryInput } from '@sage/x3-master-data-api';
    import type { Package as SageX3Structure$Package } from '@sage/x3-structure-api';
    import type { Company, Package as SageX3System$Package, Site } from '@sage/x3-system-api';
    import type { Package as SageXtremX3SystemUtils$Package, SysUser } from '@sage/xtrem-x3-system-utils-api';
    import type {
        AggregateQueryOperation,
        AggregateReadOperation,
        ClientNode,
        ClientNodeInput,
        GetDefaultsOperation,
        QueryOperation,
        ReadOperation,
        TextStream,
    } from '@sage/xtrem-client';
    export interface BillingMode$Enum {
        none: 1;
        progressBilling: 2;
        timeBilling: 3;
    }
    export type BillingMode = keyof BillingMode$Enum;
    export interface CostType extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        code: string;
        site: Site;
        localizedDescription: string;
        localizedShortDescription: string;
        isActive: boolean;
    }
    export interface CostTypeInput extends ClientNodeInput {
        code?: string;
        site?: string;
        localizedDescription?: string;
        localizedShortDescription?: string;
        isActive?: boolean | string;
    }
    export interface CostTypeBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        code: string;
        site: Site;
        localizedDescription: string;
        localizedShortDescription: string;
        isActive: boolean;
    }
    export interface CostType$Lookups {
        site: QueryOperation<Site>;
    }
    export interface CostType$Operations {
        query: QueryOperation<CostType>;
        read: ReadOperation<CostType>;
        aggregate: {
            read: AggregateReadOperation<CostType>;
            query: AggregateQueryOperation<CostType>;
        };
        lookups(dataOrId: string | { data: CostTypeInput }): CostType$Lookups;
        getDefaults: GetDefaultsOperation<CostType>;
    }
    export interface ProjectLink extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        id: string;
        localizedDescription: string;
        localizedShortDescription: string;
        site: Site;
        type: ProjectAllocationType;
        isActive: boolean;
        company: Company;
    }
    export interface ProjectLinkInput extends ClientNodeInput {
        id?: string;
        localizedDescription?: string;
        localizedShortDescription?: string;
        site?: string;
        type?: ProjectAllocationType;
        isActive?: boolean | string;
        company?: string;
    }
    export interface ProjectLinkBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        id: string;
        localizedDescription: string;
        localizedShortDescription: string;
        site: Site;
        type: ProjectAllocationType;
        isActive: boolean;
        company: Company;
    }
    export interface ProjectLink$Lookups {
        site: QueryOperation<Site>;
        company: QueryOperation<Company>;
    }
    export interface ProjectLink$Operations {
        query: QueryOperation<ProjectLink>;
        read: ReadOperation<ProjectLink>;
        aggregate: {
            read: AggregateReadOperation<ProjectLink>;
            query: AggregateQueryOperation<ProjectLink>;
        };
        lookups(dataOrId: string | { data: ProjectLinkInput }): ProjectLink$Lookups;
        getDefaults: GetDefaultsOperation<ProjectLink>;
    }
    export interface ProjectText extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        code: string;
        identifier1: string;
        identifier2: string;
        identifier3: string;
        identifier4: string;
        text: TextStream;
    }
    export interface ProjectTextInput extends ClientNodeInput {
        code?: string;
        identifier1?: string;
        identifier2?: string;
        identifier3?: string;
        identifier4?: string;
        text?: TextStream;
    }
    export interface ProjectTextBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        code: string;
        identifier1: string;
        identifier2: string;
        identifier3: string;
        identifier4: string;
        text: TextStream;
    }
    export interface ProjectText$Operations {
        query: QueryOperation<ProjectText>;
        read: ReadOperation<ProjectText>;
        aggregate: {
            read: AggregateReadOperation<ProjectText>;
            query: AggregateQueryOperation<ProjectText>;
        };
        getDefaults: GetDefaultsOperation<ProjectText>;
    }
    export interface ProductCategoryExtension {
        costType: CostType;
    }
    export interface ProductCategoryInputExtension {
        costType?: string;
    }
    export interface ProductCategoryBindingExtension {
        costType: CostType;
    }
    export interface ProductCategoryExtension$Lookups {
        costType: QueryOperation<CostType>;
    }
    export interface ProductCategoryExtension$Operations {
        lookups(dataOrId: string | { data: ProductCategoryInput }): ProductCategoryExtension$Lookups;
    }
    export interface Package {
        '@sage/x3-project-management-data/CostType': CostType$Operations;
        '@sage/x3-project-management-data/ProjectLink': ProjectLink$Operations;
        '@sage/x3-project-management-data/ProjectText': ProjectText$Operations;
    }
    export interface GraphApi
        extends Package,
            SageX3MasterData$Package,
            SageX3Structure$Package,
            SageX3System$Package,
            SageXtremX3SystemUtils$Package {}
}
declare module '@sage/x3-project-management-data-api' {
    export type * from '@sage/x3-project-management-data-api-partial';
}
declare module '@sage/x3-master-data-api-partial' {
    import type { GraphApi as GraphApiExtension } from '@sage/x3-project-management-data-api';
    export interface GraphApi extends GraphApiExtension {}
}
declare module '@sage/x3-structure-api-partial' {
    import type { GraphApi as GraphApiExtension } from '@sage/x3-project-management-data-api';
    export interface GraphApi extends GraphApiExtension {}
}
declare module '@sage/x3-system-api-partial' {
    import type { GraphApi as GraphApiExtension } from '@sage/x3-project-management-data-api';
    export interface GraphApi extends GraphApiExtension {}
}
declare module '@sage/xtrem-x3-system-utils-api-partial' {
    import type { GraphApi as GraphApiExtension } from '@sage/x3-project-management-data-api';
    export interface GraphApi extends GraphApiExtension {}
}
declare module '@sage/x3-master-data-api-partial' {
    import type {
        ProductCategoryBindingExtension,
        ProductCategoryExtension,
        ProductCategoryExtension$Lookups,
        ProductCategoryExtension$Operations,
        ProductCategoryInputExtension,
    } from '@sage/x3-project-management-data-api';
    export interface ProductCategory extends ProductCategoryExtension {}
    export interface ProductCategoryBinding extends ProductCategoryBindingExtension {}
    export interface ProductCategoryInput extends ProductCategoryInputExtension {}
    export interface ProductCategory$Lookups extends ProductCategoryExtension$Lookups {}
    export interface ProductCategory$Operations extends ProductCategoryExtension$Operations {}
}
