/* eslint-disable import/no-duplicates */
declare module '@sage/x3-manufacturing-data-api-partial' {
    import type { Package as SageX3MasterData$Package, ProductSite, WeeklyStructure } from '@sage/x3-master-data-api';
    import type { Package as SageX3ProjectManagementData$Package } from '@sage/x3-project-management-data-api';
    import type { Package as SageX3StockData$Package } from '@sage/x3-stock-data-api';
    import type { Package as SageX3Structure$Package } from '@sage/x3-structure-api';
    import type { Package as SageX3System$Package, Site, User } from '@sage/x3-system-api';
    import type { Package as SageXtremX3SystemUtils$Package, SysUser } from '@sage/xtrem-x3-system-utils-api';
    import type {
        AggregateQueryOperation,
        AggregateReadOperation,
        ClientCollection,
        ClientNode,
        ClientNodeInput,
        decimal,
        GetDefaultsOperation,
        integer,
        QueryOperation,
        ReadOperation,
    } from '@sage/xtrem-client';
    export interface OperationStatus$Enum {
        pending: 1;
        previousOperationInProcess: 2;
        previousOperationClosed: 3;
        inProcess: 4;
        closed: 5;
        excluded: 6;
        ordered: 7;
    }
    export type OperationStatus = keyof OperationStatus$Enum;
    export interface StatusInProgress$Enum {
        firm: 1;
        planned: 2;
        suggested: 3;
        closed: 4;
    }
    export type StatusInProgress = keyof StatusInProgress$Enum;
    export interface WorkCenterType$Enum {
        machine: 1;
        labour: 2;
        subcontractor: 3;
    }
    export type WorkCenterType = keyof WorkCenterType$Enum;
    export interface WorkOrderType$Enum {
        customerOrder: 1;
        supplierOrder: 2;
        subcontractedMaterial: 3;
        subcontractedService: 4;
        workOrder: 5;
        materialRequirements: 6;
        transferOrder: 7;
        transferRequest: 8;
        byProduct: 9;
        miscellaneousRequests: 10;
        miscellaneousResources: 11;
        customerReservation: 12;
        subcontractOrder: 13;
        projectDemand: 14;
    }
    export type WorkOrderType = keyof WorkOrderType$Enum;
    export interface Assignment extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        _auuid: string;
        storageSite: Site;
        product: ProductSite;
        requestType: EntryTypeEnum;
        demandNumber: string;
        demandLineNumber: integer;
        demandSequence: integer;
        demandOrderType: WorkOrderType;
        demandOrderStatus: StatusInProgress;
        resourceType: EntryTypeEnum;
        resourceNumber: string;
        resourceLineNumber: integer;
        resourceSequence: integer;
        resourceOrderType: WorkOrderType;
        resourceOrderStatus: StatusInProgress;
        quantityAssigned: string;
    }
    export interface AssignmentInput extends ClientNodeInput {
        _auuid?: string;
        storageSite?: string;
        product?: string;
        requestType?: EntryTypeEnum;
        demandNumber?: string;
        demandLineNumber?: integer | string;
        demandSequence?: integer | string;
        demandOrderType?: WorkOrderType;
        demandOrderStatus?: StatusInProgress;
        resourceType?: EntryTypeEnum;
        resourceNumber?: string;
        resourceLineNumber?: integer | string;
        resourceSequence?: integer | string;
        resourceOrderType?: WorkOrderType;
        resourceOrderStatus?: StatusInProgress;
        quantityAssigned?: decimal | string;
    }
    export interface AssignmentBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        _auuid: string;
        storageSite: Site;
        product: ProductSite;
        requestType: EntryTypeEnum;
        demandNumber: string;
        demandLineNumber: integer;
        demandSequence: integer;
        demandOrderType: WorkOrderType;
        demandOrderStatus: StatusInProgress;
        resourceType: EntryTypeEnum;
        resourceNumber: string;
        resourceLineNumber: integer;
        resourceSequence: integer;
        resourceOrderType: WorkOrderType;
        resourceOrderStatus: StatusInProgress;
        quantityAssigned: string;
    }
    export interface Assignment$Lookups {
        storageSite: QueryOperation<Site>;
        product: QueryOperation<ProductSite>;
    }
    export interface Assignment$Operations {
        query: QueryOperation<Assignment>;
        read: ReadOperation<Assignment>;
        aggregate: {
            read: AggregateReadOperation<Assignment>;
            query: AggregateQueryOperation<Assignment>;
        };
        lookups(dataOrId: string | { data: AssignmentInput }): Assignment$Lookups;
        getDefaults: GetDefaultsOperation<Assignment>;
    }
    export interface EmployeeId extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        teamId: integer;
        description: string;
        employeeShortDesignation: string;
        teamType: EmployeeType;
        userCode: User;
        laborRate: string;
        isActive: boolean;
        site: Site;
        workCenter: string;
        workCenterGroup: WorkCenterGroup;
    }
    export interface EmployeeIdInput extends ClientNodeInput {
        teamId?: integer | string;
        description?: string;
        employeeShortDesignation?: string;
        teamType?: EmployeeType;
        userCode?: string;
        laborRate?: decimal | string;
        isActive?: boolean | string;
        site?: string;
        workCenter?: string;
        workCenterGroup?: string;
    }
    export interface EmployeeIdBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        teamId: integer;
        description: string;
        employeeShortDesignation: string;
        teamType: EmployeeType;
        userCode: User;
        laborRate: string;
        isActive: boolean;
        site: Site;
        workCenter: string;
        workCenterGroup: WorkCenterGroup;
    }
    export interface EmployeeId$Lookups {
        userCode: QueryOperation<User>;
        site: QueryOperation<Site>;
        workCenterGroup: QueryOperation<WorkCenterGroup>;
    }
    export interface EmployeeId$Operations {
        query: QueryOperation<EmployeeId>;
        read: ReadOperation<EmployeeId>;
        aggregate: {
            read: AggregateReadOperation<EmployeeId>;
            query: AggregateQueryOperation<EmployeeId>;
        };
        lookups(dataOrId: string | { data: EmployeeIdInput }): EmployeeId$Lookups;
        getDefaults: GetDefaultsOperation<EmployeeId>;
    }
    export interface TeamEmployee extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        teamId: EmployeeId;
        teamLine: integer;
        employeeId: EmployeeId;
        startDate: string;
    }
    export interface TeamEmployeeInput extends ClientNodeInput {
        teamId?: integer | string;
        teamLine?: integer | string;
        employeeId?: integer | string;
        startDate?: string;
    }
    export interface TeamEmployeeBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        teamId: EmployeeId;
        teamLine: integer;
        employeeId: EmployeeId;
        startDate: string;
    }
    export interface TeamEmployee$Lookups {
        teamId: QueryOperation<EmployeeId>;
        employeeId: QueryOperation<EmployeeId>;
    }
    export interface TeamEmployee$Operations {
        query: QueryOperation<TeamEmployee>;
        read: ReadOperation<TeamEmployee>;
        aggregate: {
            read: AggregateReadOperation<TeamEmployee>;
            query: AggregateQueryOperation<TeamEmployee>;
        };
        lookups(dataOrId: string | { data: TeamEmployeeInput }): TeamEmployee$Lookups;
        getDefaults: GetDefaultsOperation<TeamEmployee>;
    }
    export interface Team extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        teamId: integer;
        description: string;
        employeeShortDesignation: string;
        teamType: EmployeeType;
        userCode: User;
        laborRate: string;
        isActive: boolean;
        site: Site;
        workCenter: string;
        workCenterGroup: WorkCenterGroup;
        teamEmployees: ClientCollection<TeamEmployee>;
    }
    export interface TeamInput extends ClientNodeInput {
        teamId?: integer | string;
        description?: string;
        employeeShortDesignation?: string;
        teamType?: EmployeeType;
        userCode?: string;
        laborRate?: decimal | string;
        isActive?: boolean | string;
        site?: string;
        workCenter?: string;
        workCenterGroup?: string;
    }
    export interface TeamBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        teamId: integer;
        description: string;
        employeeShortDesignation: string;
        teamType: EmployeeType;
        userCode: User;
        laborRate: string;
        isActive: boolean;
        site: Site;
        workCenter: string;
        workCenterGroup: WorkCenterGroup;
        teamEmployees: ClientCollection<TeamEmployee>;
    }
    export interface Team$Lookups {
        userCode: QueryOperation<User>;
        site: QueryOperation<Site>;
        workCenterGroup: QueryOperation<WorkCenterGroup>;
    }
    export interface Team$Operations {
        query: QueryOperation<Team>;
        read: ReadOperation<Team>;
        aggregate: {
            read: AggregateReadOperation<Team>;
            query: AggregateQueryOperation<Team>;
        };
        lookups(dataOrId: string | { data: TeamInput }): Team$Lookups;
        getDefaults: GetDefaultsOperation<Team>;
    }
    export interface WorkCenterGroup extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        code: string;
        description: string;
    }
    export interface WorkCenterGroupInput extends ClientNodeInput {
        code?: string;
        description?: string;
    }
    export interface WorkCenterGroupBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        code: string;
        description: string;
    }
    export interface WorkCenterGroup$Operations {
        query: QueryOperation<WorkCenterGroup>;
        read: ReadOperation<WorkCenterGroup>;
        aggregate: {
            read: AggregateReadOperation<WorkCenterGroup>;
            query: AggregateQueryOperation<WorkCenterGroup>;
        };
        getDefaults: GetDefaultsOperation<WorkCenterGroup>;
    }
    export interface WorkCenter extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        code: string;
        manufacturingSite: Site;
        workCenterGroup: WorkCenterGroup;
        costingDimension: string;
        weeklyStructure: WeeklyStructure;
        efficiencyInPercentage: string;
        shrinkageInPercentage: string;
        numberOfResources: integer;
        automaticClosingPercentage: string;
        qualificationLevel: string;
        totalExpectedTimeInHours: string;
        totalTimeCompleteInHours: string;
        isConstraint: boolean;
        isRccp: boolean;
        isRunDuringEmployeeBreak: boolean;
        description: string;
    }
    export interface WorkCenterInput extends ClientNodeInput {
        code?: string;
        manufacturingSite?: string;
        workCenterGroup?: string;
        costingDimension?: string;
        weeklyStructure?: string;
        efficiencyInPercentage?: decimal | string;
        shrinkageInPercentage?: decimal | string;
        numberOfResources?: integer | string;
        automaticClosingPercentage?: decimal | string;
        qualificationLevel?: string;
        totalExpectedTimeInHours?: decimal | string;
        totalTimeCompleteInHours?: decimal | string;
        isConstraint?: boolean | string;
        isRccp?: boolean | string;
        isRunDuringEmployeeBreak?: boolean | string;
        description?: string;
    }
    export interface WorkCenterBinding extends ClientNode {
        _updateUser: SysUser;
        _createUser: SysUser;
        code: string;
        manufacturingSite: Site;
        workCenterGroup: WorkCenterGroup;
        costingDimension: string;
        weeklyStructure: WeeklyStructure;
        efficiencyInPercentage: string;
        shrinkageInPercentage: string;
        numberOfResources: integer;
        automaticClosingPercentage: string;
        qualificationLevel: string;
        totalExpectedTimeInHours: string;
        totalTimeCompleteInHours: string;
        isConstraint: boolean;
        isRccp: boolean;
        isRunDuringEmployeeBreak: boolean;
        description: string;
    }
    export interface WorkCenter$Lookups {
        manufacturingSite: QueryOperation<Site>;
        workCenterGroup: QueryOperation<WorkCenterGroup>;
        weeklyStructure: QueryOperation<WeeklyStructure>;
    }
    export interface WorkCenter$Operations {
        query: QueryOperation<WorkCenter>;
        read: ReadOperation<WorkCenter>;
        aggregate: {
            read: AggregateReadOperation<WorkCenter>;
            query: AggregateQueryOperation<WorkCenter>;
        };
        lookups(dataOrId: string | { data: WorkCenterInput }): WorkCenter$Lookups;
        getDefaults: GetDefaultsOperation<WorkCenter>;
    }
    export interface Package {
        '@sage/x3-manufacturing-data/Assignment': Assignment$Operations;
        '@sage/x3-manufacturing-data/EmployeeId': EmployeeId$Operations;
        '@sage/x3-manufacturing-data/TeamEmployee': TeamEmployee$Operations;
        '@sage/x3-manufacturing-data/Team': Team$Operations;
        '@sage/x3-manufacturing-data/WorkCenterGroup': WorkCenterGroup$Operations;
        '@sage/x3-manufacturing-data/WorkCenter': WorkCenter$Operations;
    }
    export interface GraphApi
        extends Package,
            SageX3MasterData$Package,
            SageX3ProjectManagementData$Package,
            SageX3StockData$Package,
            SageX3Structure$Package,
            SageX3System$Package,
            SageXtremX3SystemUtils$Package {}
}
declare module '@sage/x3-manufacturing-data-api' {
    export type * from '@sage/x3-manufacturing-data-api-partial';
}
declare module '@sage/x3-master-data-api-partial' {
    import type { GraphApi as GraphApiExtension } from '@sage/x3-manufacturing-data-api';
    export interface GraphApi extends GraphApiExtension {}
}
declare module '@sage/x3-project-management-data-api-partial' {
    import type { GraphApi as GraphApiExtension } from '@sage/x3-manufacturing-data-api';
    export interface GraphApi extends GraphApiExtension {}
}
declare module '@sage/x3-stock-data-api-partial' {
    import type { GraphApi as GraphApiExtension } from '@sage/x3-manufacturing-data-api';
    export interface GraphApi extends GraphApiExtension {}
}
declare module '@sage/x3-structure-api-partial' {
    import type { GraphApi as GraphApiExtension } from '@sage/x3-manufacturing-data-api';
    export interface GraphApi extends GraphApiExtension {}
}
declare module '@sage/x3-system-api-partial' {
    import type { GraphApi as GraphApiExtension } from '@sage/x3-manufacturing-data-api';
    export interface GraphApi extends GraphApiExtension {}
}
declare module '@sage/xtrem-x3-system-utils-api-partial' {
    import type { GraphApi as GraphApiExtension } from '@sage/x3-manufacturing-data-api';
    export interface GraphApi extends GraphApiExtension {}
}
