import * as React from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { localize } from '../service/standalone-i18n-service';
import IconButton from 'carbon-react/esm/components/icon-button';
import Icon from 'carbon-react/esm/components/icon';
import * as tokens from '@sage/design-tokens/js/base/common';
import { ChatbotIcon } from './chatbot-icon';
import { setChatbotOpen } from '../standalone-redux/actions';
import { GmsChatWindowWrapper } from './gms-chat-window-wrapper';
import './chatbot.scss';
export function Chatbot() {
    const dispatch = useDispatch();
    const translations = useSelector(s => s.translations);
    const isOpen = useSelector(s => !!s.isChatbotOpen);
    const chatbotConfig = useSelector(s => s.chatbotConfig);
    const chatbotBackendUrl = useSelector(s => s.config?.chatbotBackendUrl || null);
    const userId = useSelector(s => s.user?.uuid || null);
    const locale = useSelector(s => s.user?.locale || null);
    const [isCollapsed, setCollapsed] = React.useState(false);
    const onClose = React.useCallback(() => {
        dispatch(setChatbotOpen(false));
    }, [dispatch]);
    const onCollapse = React.useCallback(() => {
        setCollapsed(!isCollapsed);
    }, [isCollapsed]);
    React.useEffect(() => { }, [isOpen]);
    if (!isOpen || !chatbotConfig || !chatbotBackendUrl || !userId || !locale) {
        return null;
    }
    const classNames = ['xe-chatbot'];
    if (isCollapsed) {
        classNames.push('xe-chatbot-collapsed');
    }
    const collapseLabel = !isCollapsed
        ? localize('@sage/xtrem-standalone/sage-copilot-collapse', 'Collapse Sage Copilot dialog', {}, translations, locale)
        : localize('@sage/xtrem-standalone/sage-copilot-expand', 'Expand Sage Copilot dialog', {}, translations, locale);
    const closeLabel = localize('@sage/xtrem-standalone/sage-copilot-close', 'Close Sage Copilot dialog', {}, translations, locale);
    return (React.createElement("div", { "aria-labelledby": "chatbot_dialog_label", "aria-modal": "true", className: classNames.join(' '), "data-testid": "xe-chatbot", id: "xe-chatbot", role: "dialog" },
        React.createElement("div", { className: "xe-chatbot-header" },
            React.createElement(ChatbotIcon, null),
            React.createElement("div", { className: "xe-chatbot-header-label", id: "chatbot_dialog_label" }, localize('@sage/xtrem-standalone/sage-copilot', 'Sage Copilot', {}, translations, locale)),
            React.createElement(IconButton, { "aria-controls": "chat-ui-component", "aria-expanded": isCollapsed ? 'false' : 'true', "aria-label": collapseLabel, "data-testid": "xe-chatbot-collapse", mr: "8px", onClick: onCollapse },
                React.createElement(Icon, { type: isCollapsed ? 'chevron_up' : 'chevron_down', color: tokens.colorsYang100, fontSize: "medium", tooltipMessage: collapseLabel })),
            React.createElement(IconButton, { onClick: onClose, "aria-label": closeLabel, "data-testid": "xe-chatbot-close" },
                React.createElement(Icon, { type: "close", color: tokens.colorsYang100, fontSize: "medium", tooltipMessage: closeLabel }))),
        React.createElement("div", { className: "xe-chatbot-body", id: "chat-ui-component", role: "region", "aria-labelledby": "chatbot_dialog_label" },
            React.createElement(GmsChatWindowWrapper, { authToken: `${chatbotConfig.aiToken}|${chatbotConfig.graphQL}`, backendUrl: chatbotBackendUrl, userId: userId }))));
}
//# sourceMappingURL=chatbot.js.map