import type { Dict } from '@sage/xtrem-shared';
import * as React from 'react';
import type { PageArticleItem } from '../../../service/layout-service';
import { ContextType } from '../../../types';
import type { LabelControlObject, PageActionControlObject, SectionProperties } from '../../control-objects';
import type { MenuSeparatorType, PageMode } from './page-types';
import type { CollectionValue } from '../../../service/collection-data-service';
export type StepStatus = 'complete' | 'current' | 'incomplete';
export interface XtremHeaderExternalProps {
    activeSection: string | null;
    areNavigationTabsHidden: boolean;
    availableColumns: number;
    contextType?: ContextType;
    hasNavigationPanel: boolean;
    headerLineBlock: Partial<PageArticleItem> | null;
    isRecordCreationPage?: boolean;
    navigationPanelValue?: CollectionValue;
    pageBodyRef: React.RefObject<HTMLDivElement>;
    screenId: string;
    setActiveSection: (sectionId: string) => void;
}
export interface XtremHeaderProps extends XtremHeaderExternalProps {
    canToggleNavigationPanel: boolean;
    hasDropdownOrQuickActions: boolean;
    headerDropdownMenu?: Array<PageActionControlObject | MenuSeparatorType>;
    headerLabelField?: LabelControlObject;
    headerSection: Partial<PageArticleItem> | null;
    hierarchyParentPage?: () => string | null;
    idFieldValue?: string | null;
    isNavigationPanelHeaderHidden: boolean;
    isNavigationPanelOpened: boolean;
    isTitleHidden?: boolean;
    objectTypePlural?: string | null;
    objectTypeSingular?: string | null;
    pageMode: PageMode;
    sections: Partial<PageArticleItem>[];
    sectionsProperties: Dict<SectionProperties>;
    sectionValidationErrors: Dict<string | null>;
    setNavigationPanelIsOpened: (isOpened: boolean) => void;
    shouldDisplayNavigationArrows: boolean;
    subtitle?: string;
    title: string;
}
export interface HeaderState {
    isHeaderSectionClosed?: boolean;
}
export declare class XtremHeader extends React.Component<XtremHeaderProps, HeaderState> {
    private readonly activeIndicator;
    private readonly tabContainer;
    private readonly tabDictionary;
    private readonly hotkeySubscriptions;
    private readonly parentRef;
    constructor(props: XtremHeaderProps);
    componentDidMount(): void;
    componentDidUpdate(prevProps: XtremHeaderProps): void;
    componentWillUnmount(): void;
    private setIndicatorPosition;
    private readonly getActiveSectionIndex;
    private readonly setActiveSectionByIndex;
    private readonly setActiveSection;
    private readonly hasTabs;
    private readonly getClasses;
    private readonly getVisibleTabs;
    private readonly onRecordClose;
    private readonly renderTabs;
    private readonly onHeaderSectionToggle;
    renderCloseIcon: () => React.ReactNode;
    renderHeaderToggleButton: () => React.ReactNode;
    renderQuickActionMenu: () => React.ReactNode;
    renderHeaderDropdownActionMenu: () => React.ReactNode;
    render(): React.ReactNode;
}
export declare const ConnectedXtremHeader: import("react-redux").ConnectedComponent<typeof XtremHeader, import("react-redux").Omit<React.ClassAttributes<XtremHeader> & XtremHeaderProps, "title" | "contextType" | "screenId" | "availableColumns" | "isTitleHidden" | "subtitle" | "areNavigationTabsHidden" | "hasNavigationPanel" | "isNavigationPanelOpened" | "sections" | "pageMode" | "activeSection" | "setActiveSection" | "headerLineBlock" | "setNavigationPanelIsOpened" | "headerSection" | "canToggleNavigationPanel" | "hasDropdownOrQuickActions" | "headerDropdownMenu" | "headerLabelField" | "hierarchyParentPage" | "idFieldValue" | "isNavigationPanelHeaderHidden" | "objectTypePlural" | "objectTypeSingular" | "sectionsProperties" | "sectionValidationErrors" | "shouldDisplayNavigationArrows" | "isRecordCreationPage" | "navigationPanelValue" | "pageBodyRef"> & XtremHeaderExternalProps>;
//# sourceMappingURL=xtrem-header.d.ts.map