/**
 * @packageDocumentation
 * @module root
 * */
import type { Extend } from '../../../service/page-extension';
import type { ScreenBase } from '../../../service/screen-base';
import type { ScreenExtension } from '../../../types';
import type { SectionProperties } from '../../control-objects';
import { SectionControlObject } from '../../control-objects';
import type { ExtensionField } from '../../field/traits';
export interface SectionDecoratorProperties<CT extends ScreenBase = ScreenBase> extends Omit<SectionProperties<CT>, '_controlObjectType'>, ExtensionField<CT, SectionControlObject<CT>> {
    /** Function that gets executed when the section becomes active */
    onActive?: (this: CT) => void;
    /** Function that gets executed when the section stops being active */
    onInactive?: (this: CT) => void;
}
/**
 * Initializes the decorated member as a [Section]{@link SectionControlObject} container with the provided properties
 *
 * @param properties The properties that the [Section]{@link SectionControlObject} container will be initialized with
 */
export declare function section<CT extends ScreenExtension<CT>>(properties: SectionDecoratorProperties<Extend<CT>>): (target: CT, name: string) => void;
//# sourceMappingURL=section-decorator.d.ts.map