import { Checkbox } from 'carbon-react/esm/components/checkbox';
import * as React from 'react';
import { resolveByValue } from '../../../utils/resolve-value-utils';
import { splitValueToMergedValue } from '../../../utils/transformers';
export const CheckboxCellRenderer = React.memo(props => {
    const { screenId, fieldProperties, isParentFieldDisabled, isTableReadOnly } = props;
    const isDisabled = isParentFieldDisabled ||
        resolveByValue({
            screenId,
            propertyValue: fieldProperties.isDisabled,
            rowValue: splitValueToMergedValue(props.data),
            fieldValue: props.value,
            skipHexFormat: true,
        });
    const isFieldReadOnly = resolveByValue({
        screenId,
        propertyValue: fieldProperties.isReadOnly,
        rowValue: splitValueToMergedValue(props.data),
        fieldValue: props.value,
        skipHexFormat: true,
    });
    const isColumnDisabled = !props.colDef.isEditable(props.data);
    const onChange = e => {
        const checked = e?.target?.checked;
        // Intended any cast to avoid type error accesing to colId property in AG-GRID
        // NOSONAR
        props.node.setDataValue(props.column.colId, checked);
    };
    return (React.createElement(fieldProperties.wrapper, { ...props },
        React.createElement("div", { style: {
                margin: '3px',
            } },
            React.createElement("div", { style: {
                    display: 'flex',
                    flex: 1,
                    justifyContent: 'center',
                } },
                React.createElement(Checkbox, { "aria-label": props.colDef.headerName, value: "checked", checked: props.value || false, disabled: isDisabled || isFieldReadOnly || isTableReadOnly || isColumnDisabled, onChange: onChange })))));
});
CheckboxCellRenderer.displayName = 'CheckboxCellRenderer';
//# sourceMappingURL=checkbox-cell-renderer.js.map