import React from 'react';
import { splitValueToMergedValue } from '../../../utils/transformers';
import { Select } from '../../ui/select/select-component';
import { createSelectItemFromOption, getItemsFromProps, SELECT_EMPTY_VALUE } from '../select/select-utils';
import { manageOnBlurFocus } from '../../ui/table-shared/cell/cell-editor-utils';
import { AgGridCellEditorComponent } from '../table/table-component-types';
import { setDefaultAgGridInputStyles } from '../../../utils/ag-grid/ag-grid-cell-editor-utils';
import { TAB, SHIFT_TAB, KEY_BACKSPACE, KEY_DELETE, KEY_F2 } from '../../../utils/keyboard-event-utils';
export class DropdownListCellEditor extends AgGridCellEditorComponent {
    constructor(props) {
        super(props);
        this.isSelecting = false;
        this.onKeyDown = (event) => {
            if (event.key === TAB) {
                if (event.shiftKey) {
                    this.setState({ endAction: SHIFT_TAB });
                }
                else {
                    this.setState({ endAction: TAB });
                }
            }
        };
        this.onBlur = () => manageOnBlurFocus(this.isSelecting, this.props.api, this.props.column, this.props.rowIndex, this.props.node.isRowPinned() ? 'top' : null, this.props.stopEditing, this.state.endAction);
        this.onItemSelected = (item) => {
            this.isSelecting = true;
            this.setState({ item: item ?? undefined }, () => {
                this.isSelecting = false;
                this.onBlur();
            });
        };
        this.getItems = () => {
            const items = getItemsFromProps(this.props, '', splitValueToMergedValue(this.props.data));
            return Promise.resolve(items);
        };
        this.getTestId = () => {
            const allColumns = this.props.api.getColumns() || [];
            return `${this.props.tableElementId}-${this.props.rowIndex}-${allColumns.indexOf(this.props.column) + 1}`;
        };
        this.inputRef = React.createRef();
        this.state = this.getInitState(props);
    }
    componentDidMount() {
        const input = this.inputRef.current;
        if (!input) {
            return;
        }
        setDefaultAgGridInputStyles(input);
        const inputDiv = input.parentNode;
        inputDiv.style.width = '100%';
        inputDiv.style.height = '100%';
        inputDiv.style.border = 'none';
        input.focus();
        if (this.state.highlightAllOnFocus) {
            input.select();
            this.setState({ highlightAllOnFocus: false });
        }
        else {
            // when we started editing, we want the caret at the end, not the start.
            // this comes into play in two scenarios: a) when user hits F2 and b)
            // when user hits a printable character, then on IE (and only IE) the caret
            // was placed after the first character, thus 'apply' would end up as 'pplea'
            const length = input.value ? input.value.length : 0;
            if (length > 0) {
                input.setSelectionRange(length, length);
            }
        }
    }
    getCellWidth() {
        return { width: this.props.eGridCell?.style?.width || '200px' };
    }
    getInitState(props) {
        let initValue;
        let highlightAllOnFocus = true;
        if (props.keyPress === KEY_BACKSPACE || props.keyPress === KEY_DELETE) {
            // if backspace or delete pressed, we clear the cell
            initValue = '';
        }
        else if (props.charPress) {
            // if a letter was pressed, we start with the letter
            initValue = props.charPress;
            highlightAllOnFocus = false;
        }
        else {
            // otherwise we start with the current value
            initValue = props.value;
            if (props.keyPress === KEY_F2) {
                highlightAllOnFocus = false;
            }
        }
        const item = initValue ? createSelectItemFromOption(initValue, this.props) : undefined;
        return { highlightAllOnFocus, initValue, item };
    }
    getValue() {
        if (this.state.item?.value === SELECT_EMPTY_VALUE) {
            return null;
        }
        return this.state.item?.id ?? null;
    }
    render() {
        return (React.createElement("div", { className: "e-dropdown-list-cell-editor", "data-testid": this.getTestId(), style: this.getCellWidth() },
            React.createElement(Select, { elementId: this.props.elementId, getItems: this.getItems, hasInputSearch: false, initialInputValue: "", isSortedAlphabetically: this.props.fieldProperties.isSortedAlphabetically, minLookupCharacters: 0, onBlur: this.onBlur, onKeyDown: this.onKeyDown, onSelected: this.onItemSelected, ref: this.inputRef, screenId: this.props.screenId, selectedItem: this.state.item, testId: `${this.getTestId()}-input`, variant: "plain" })));
    }
}
//# sourceMappingURL=dropdown-list-cell-editor.js.map