import { isEqual, set } from 'lodash';
import * as React from 'react';
import { connect } from 'react-redux';
import * as xtremRedux from '../../../redux';
import { getScreenElement } from '../../../service/screen-base-definition';
import { handleChange } from '../../../utils/abstract-fields-utils';
import { convertDeepBindToPathNotNull } from '../../../utils/nested-field-utils';
import { calculateContainerWidth } from '../../../utils/responsive-utils';
import { Pod } from '../../ui/pod/pod-component';
import { EditableFieldBaseComponent, mapDispatchToProps, mapStateToProps } from '../field-base-component';
export class DynamicPodComponent extends EditableFieldBaseComponent {
    constructor(props) {
        super(props);
        this.onChange = async (bind, value) => {
            const newValue = { ...this.props.value };
            set(newValue, bind, value);
            handleChange(this.props.elementId, newValue, this.props.setFieldValue, this.props.validate, this.triggerChangeListener);
        };
        this.onRemove = () => handleChange(this.props.elementId, null, this.props.setFieldValue, this.props.validate, this.triggerChangeListener);
        this.onNewPod = async () => {
            const columns = this.props.fieldProperties.columns;
            let value = columns?.reduce((prev, curr) => {
                return set(prev, convertDeepBindToPathNotNull(curr.properties.bind), null);
            }, {});
            if (this.props.fieldProperties.onAddButtonClick) {
                const state = xtremRedux.getStore().getState();
                const screenDefinition = state.screenDefinitions[this.props.screenId];
                const newValue = await this.props.fieldProperties.onAddButtonClick.apply(getScreenElement(screenDefinition));
                value = { ...value, ...newValue };
            }
            handleChange(this.props.elementId, value, this.props.setFieldValue, this.props.validate, this.triggerChangeListener);
        };
        this.checkOptionTypes(props);
    }
    componentDidUpdate(prevProps) {
        if (!isEqual(prevProps.fieldProperties.columns, this.props.fieldProperties.columns)) {
            this.checkOptionTypes(this.props);
        }
    }
    checkOptionTypes(props) {
        const enumTypes = props.fieldProperties.columns
            .filter(c => !!c.properties.optionType)
            .map(c => c.properties.optionType);
        props.loadOptionTypes(enumTypes);
    }
    render() {
        const { fieldProperties, browser, availableColumns, value, elementId, screenId } = this.props;
        const podWidth = browser && calculateContainerWidth(browser.is, availableColumns || 12, 'small');
        const podProps = {
            value,
            fieldProperties,
            browser,
            elementId,
            screenId,
            availableColumns: podWidth,
            isDisabled: this.isDisabled(),
            isReadOnly: this.isReadOnly(),
            onBlockClick: this.getClickHandler(),
            onChange: this.onChange,
            baseAttributesDivWrapper: this.getBaseAttributesDivWrapper('dyamic-pod', 'e-dyamic-pod-field', this.props.contextType, this.props.handlersArguments?.rowValue, this.props.isNested),
            onNewPod: this.onNewPod,
            contextType: this.props.contextType,
            onRemove: this.onRemove,
            validationErrors: this.props.validationErrors,
        };
        return React.createElement(Pod, { ...podProps });
    }
}
const extendedMapStateToProps = (state, props) => {
    const componentProperties = mapStateToProps()(state, props);
    const screenDefinition = state.screenDefinitions[props.screenId];
    if (componentProperties.fieldProperties?.onAddButtonClick) {
        componentProperties.fieldProperties.onAddButtonClick =
            componentProperties.fieldProperties.onAddButtonClick.bind(getScreenElement(screenDefinition));
    }
    return componentProperties;
};
const extendedMapDispatchToProps = (dispatch, props) => {
    const defaultMapDispatchToProps = mapDispatchToProps()(dispatch, props);
    return {
        ...defaultMapDispatchToProps,
        loadOptionTypes: (optionTypes) => {
            dispatch(xtremRedux.actions.loadEnumType(optionTypes));
        },
    };
};
export const ConnectedDynamicPodComponent = connect(extendedMapStateToProps, extendedMapDispatchToProps)(DynamicPodComponent);
export default ConnectedDynamicPodComponent;
//# sourceMappingURL=dynamic-pod-component.js.map