import * as React from 'react';
import * as xtremRedux from '../../../redux';
import { REG_EXP_URL_PATTERN } from '../../../utils/constants';
import { triggerNestedFieldEvent } from '../../../utils/events';
import { resolveByValue } from '../../../utils/resolve-value-utils';
import { splitValueToMergedValue } from '../../../utils/transformers';
import { getPage, getQueryParameters, getTextLink } from './link-utils';
export const LinkCellRenderer = React.memo(props => {
    const { screenId, fieldProperties, isParentFieldDisabled } = props;
    const isDisabled = isParentFieldDisabled ||
        resolveByValue({
            screenId,
            propertyValue: fieldProperties.isDisabled,
            rowValue: splitValueToMergedValue(props.data),
            fieldValue: props.value,
            skipHexFormat: true,
        });
    const onClick = async (e) => {
        e.preventDefault();
        e.stopPropagation();
        const modifierKeyPushed = e.metaKey || e.ctrlKey;
        const page = getPage(screenId, fieldProperties, props.value, props.data);
        if (!page) {
            await triggerNestedFieldEvent(screenId, props.colDef?.cellRendererParams.tableElementId, fieldProperties, 'onClick', props.data._id, splitValueToMergedValue(props.data));
            return;
        }
        if (page.match(REG_EXP_URL_PATTERN)) {
            // External link, opening in a new tab
            window.open(page, '_blank', 'noopener=true');
        }
        else if (modifierKeyPushed) {
            window.open(getTextLink(screenId, fieldProperties, props.value, props.data), '_blank', 'noopener=true');
        }
        else {
            await xtremRedux.getStore().dispatch(xtremRedux.actions.navigate(page, getQueryParameters(screenId, fieldProperties, props.value, props.data)));
        }
    };
    return (React.createElement(fieldProperties.wrapper, { ...props },
        !isDisabled && (React.createElement("a", { href: getTextLink(screenId, fieldProperties, props.value, props.data), onClick: onClick }, props.value)),
        isDisabled && React.createElement("span", null, props.value)));
});
//# sourceMappingURL=link-cell-renderer.js.map