/**
 * @packageDocumentation
 * @module root
 * */
import type { ClientNode } from '@sage/xtrem-client';
import type { IconType } from 'carbon-react/esm/components/icon/icon-type';
import type { GraphQLFilter } from '../../../service/graphql-utils';
import type { ScreenBase } from '../../../service/screen-base';
import { EditableFieldControlObject } from '../../editable-field-control-object';
import type { FieldComponentProps, FieldKey, PartialCollectionValue } from '../../types';
import type { MultiReferenceDecoratorProperties } from './multi-reference-types';
/**
 * [Field]{@link EditableFieldControlObject} that holds a reference to an existing GraphQL object. The type of GraphQL object
 * must be specified through the 'node' property, while the 'valueField' and 'helperTextField'
 * properties define which properties of the GraphQL object will be displayed in the field
 * and will be matched against the user provided text
 */
export declare class MultiReferenceControlObject<MultiReferencedItemType extends ClientNode = any, CT extends ScreenBase = ScreenBase> extends EditableFieldControlObject<CT, FieldKey.MultiReference, FieldComponentProps<FieldKey.MultiReference>> {
    static readonly defaultUiProperties: Partial<MultiReferenceDecoratorProperties>;
    /** Graphql filter that will restrict the results of the reference field */
    get filter(): GraphQLFilter<MultiReferencedItemType> | undefined;
    /** Graphql filter that will restrict the results of the reference field */
    set filter(filter: GraphQLFilter<MultiReferencedItemType> | undefined);
    /** The GraphQL node property that will be displayed below the reference field */
    get helperTextField(): string | undefined;
    /** The GraphQL node property that will be used to display an image in front of the values. t*/
    get imageField(): string | undefined;
    /** The GraphQL node that the field suggestions will be fetched from */
    get node(): string;
    /** The helper text underneath the field */
    helperText?: string;
    /** Icon of the input field. It will be placed on the right side. */
    icon?: IconType;
    /** Color of the icon, only supported in tile containers */
    iconColor?: string;
    /** Indicator, whether sounds play on successful/erroneous selection */
    isSoundDisabled?: boolean;
    /** Placeholder to be displayed in the field body */
    placeholder?: string;
    /**  The minimum number of items that has to be selected*/
    minItems?: number;
    /**  The maximum number of items that has to be selected*/
    maxItems?: number;
    /** Field's value */
    get value(): PartialCollectionValue<MultiReferencedItemType>[];
    /** Field's value */
    set value(newValues: PartialCollectionValue<MultiReferencedItemType & {
        $id: string;
    }>[]);
    /** The GraphQL node property that will be used as the reference field value */
    get valueField(): string | undefined;
    refresh(): Promise<void>;
    focus(): void;
    openDialog(): void;
    fetchSuggestions(searchText: string): Promise<PartialCollectionValue<MultiReferencedItemType>[]>;
}
//# sourceMappingURL=multi-reference-control-object.d.ts.map