import * as React from 'react';
import { connect } from 'react-redux';
import { handleChange } from '../../../utils/abstract-fields-utils';
import { calculateContainerWidth } from '../../../utils/responsive-utils';
import LookupDialog from '../../ui/lookup-dialog/lookup-dialog-component';
import { Pod } from '../../ui/pod/pod-component';
import { EditableFieldBaseComponent, mapDispatchToProps, mapStateToProps } from '../field-base-component';
export class PodComponent extends EditableFieldBaseComponent {
    constructor() {
        super(...arguments);
        this.onChange = (collectionItem, isOrganicChange) => {
            if (isOrganicChange) {
                handleChange(this.props.elementId, collectionItem ?? null, this.props.setFieldValue, this.props.validate, this.triggerChangeListener);
            }
        };
        this.onRemove = () => handleChange(this.props.elementId, null, this.props.setFieldValue, this.props.validate, this.triggerChangeListener);
        this.onNewPod = async () => {
            if (this.props.setFieldProperties) {
                this.props.setFieldProperties(this.props.elementId, {
                    ...this.props.fieldProperties,
                    isReferenceDialogOpen: true,
                });
            }
        };
        this.isLookupDialogOpen = () => !!this.props.fieldProperties.isReferenceDialogOpen && !!this.props.fieldProperties.columns;
        this.onLookupDialogSelectionFinished = ([selectedRecord]) => {
            this.closeLookupDialog();
            this.onChange(selectedRecord, true);
        };
        this.closeLookupDialog = () => {
            if (this.props.setFieldProperties) {
                this.props.setFieldProperties(this.props.elementId, {
                    ...this.props.fieldProperties,
                    isReferenceDialogOpen: false,
                });
            }
        };
    }
    render() {
        const { fieldProperties, browser, availableColumns, value, elementId, screenId } = this.props;
        const podWidth = browser && calculateContainerWidth(browser.is, availableColumns || 12, 'small');
        const podProps = {
            value,
            fieldProperties,
            browser,
            elementId,
            screenId,
            availableColumns: podWidth,
            isDisabled: this.isDisabled(),
            isReadOnly: true,
            baseAttributesDivWrapper: this.getBaseAttributesDivWrapper('pod', 'e-pod-field', this.props.contextType, this.props.handlersArguments?.rowValue, this.props.isNested),
            contextType: this.props.contextType,
            onBlockClick: this.getClickHandler(),
            onNewPod: this.onNewPod,
            onRemove: this.onRemove,
        };
        return (React.createElement(React.Fragment, null,
            React.createElement(Pod, { ...podProps }),
            React.createElement(LookupDialog, { isOpen: this.isLookupDialogOpen(), fieldProperties: this.props.fieldProperties, screenId: this.props.screenId, onSelectionFinished: this.onLookupDialogSelectionFinished, fieldId: this.props.elementId, closeLookupDialog: this.closeLookupDialog, parentElementId: this.props.parentElementId, recordContext: this.props.recordContext, contextNode: this.props.contextNode, valueField: this.props.elementId })));
    }
}
export const ConnectedPodComponent = connect(mapStateToProps(), mapDispatchToProps())(PodComponent);
//# sourceMappingURL=pod-component.js.map