import { get, isEqual } from 'lodash';
import React from 'react';
import { convertDeepBindToPathNotNull } from '../../../utils/nested-field-utils';
import { AUTO_COLUMN_ID } from '../../../utils/table-component-utils';
import { getReferenceValueFieldPath } from './reference-utils';
import { localize } from '../../../service/i18n-service';
export default class ReferenceRenderer extends React.Component {
    constructor() {
        super(...arguments);
        /**
         * Searches for the reference field image from the row using the the dot path, first using the bind path of the reference column, then the path of the `imageField`;
         * @returns
         */
        this.getImageFromProps = () => {
            if (!this.props.fieldProperties.imageField) {
                return undefined;
            }
            return (get(this.props.data, `${this.props.colDef.field}.${convertDeepBindToPathNotNull(this.props.fieldProperties.imageField)}`) || null);
        };
    }
    shouldComponentUpdate(nextProps) {
        const isMandatory = this.props.fieldProperties.isMandatory ?? false;
        const validationErrors = this.props
            .validationErrors ?? false;
        if (!isEqual(this.props.value, nextProps.value)) {
            return true;
        }
        // Trigger updates when validation is updated:
        if (isMandatory && !this.props.value) {
            return true;
        }
        if (!isEqual(validationErrors, nextProps
            .validationErrors)) {
            return true;
        }
        return false;
    }
    render() {
        if (!this.props.data ||
            (!this.props.isTree && !this.props.data.__isGroup && this.props.colDef.colId === AUTO_COLUMN_ID)) {
            return null;
        }
        // If group append children count
        const displayValue = !this.props.isTree && this.props.colDef.colId === AUTO_COLUMN_ID
            ? `${get(this.props.data, this.props.data.__groupKey, localize('@sage/xtrem-ui/no-value', 'No value')) ?? localize('@sage/xtrem-ui/no-value', 'No value')} (${this.props.data.__groupCount})`
            : get(this.props.data, `${this.props.colDef.field}.${convertDeepBindToPathNotNull(this.props.fieldProperties.valueField)}`, null);
        const image = this.getImageFromProps();
        return (React.createElement(this.props.fieldProperties.wrapper, { ...this.props },
            React.createElement("div", { style: { display: 'flex', alignItems: 'center' } },
                image && (React.createElement("img", { src: `data:image;base64,${image.value}`, style: { width: '24px', height: '24px', paddingRight: '10px' }, alt: displayValue })),
                React.createElement("span", { "data-testid": `${this.props.tableElementId}-${this.props.rowIndex}-${this.props.api.getColumns().indexOf(this.props.column) + 1}`, style: { textOverflow: 'ellipsis', overflow: 'hidden' } }, this.props.data.__isGroup &&
                    this.props.colDef.colId !== AUTO_COLUMN_ID &&
                    this.props.data.__groupKey === getReferenceValueFieldPath(this.props.fieldProperties)
                    ? ''
                    : displayValue))));
    }
}
//# sourceMappingURL=reference-cell-renderer.js.map