import type { ClientNode } from '@sage/xtrem-client';
import type { IsStrictlyAny } from '@sage/xtrem-shared';
import type { ScreenBase } from '../../../service/screen-base';
import type { ScreenBaseGenericType, ScreenExtension } from '../../../types';
import type { BlockControlObject, TileControlObject } from '../../control-objects';
import type { EditableFieldProperties } from '../../editable-field-control-object';
import type { GridNestedFieldTypes, NestedField } from '../../nested-fields';
import type { ClientCollectionRecursiveBind, FieldControlObjectInstance, Id, PropertyRecursiveBind, ReferenceRecursiveBind, ReferenceRecursiveOrderBy } from '../../types';
import type { BaseEditableComponentProperties, NestedFieldsAdditionalProperties } from '../field-base-component-types';
import type { Changeable, Clickable, ExtensionField, HasDynamicLookupSuggestions, HasFilter, HasIcon, HasInputValueChangeListener, HasLookupDialogTitle, HasNestedFilter, HasParent, HasSound, Nested, NestedChangeable, NestedClickable, NestedValidatable, Sizable, Validatable } from '../traits';
import type { CellParams } from '../../../utils/ag-grid/ag-grid-column-config';
import type { TAB, SHIFT_TAB } from '../../../utils/keyboard-event-utils';
import type { SelectItem } from '../../ui/select/select-component';
export type PropertyValueType<T extends ClientNode = any> = IsStrictlyAny<T> extends true ? any : (keyof T & string) | Id<PropertyRecursiveBind<T>>;
export type ClientCollectionValueType<T extends ClientNode = any> = IsStrictlyAny<T> extends true ? any : (keyof T & string) | Id<ClientCollectionRecursiveBind<T>>;
export type ReferenceValueType<T extends ClientNode = any> = IsStrictlyAny<T> extends true ? any : (keyof T & string) | Id<ReferenceRecursiveBind<T>>;
export interface ReferenceProperties<CT extends ScreenExtension<CT> = ScreenBase, ReferencedItemType extends ClientNode = any> extends EditableFieldProperties<CT>, HasDynamicLookupSuggestions<CT, ReferencedItemType>, HasFilter<CT, ReferencedItemType>, HasIcon, HasLookupDialogTitle, HasSound<CT>, Sizable {
    /** Whether the rows of the reference lookup can be filtered or not. Defaults to true */
    canFilter?: boolean;
    /** Column definitions for the lookup dialog */
    columns?: NestedField<CT, GridNestedFieldTypes, ReferencedItemType>[];
    /** The GraphQL node property that will be displayed below the reference field.
     * This value will override the one provided through helperText*/
    helperTextField?: PropertyValueType<ReferencedItemType>;
    /** The GraphQL node property that will be used to display an image in front of the values. t*/
    imageField?: PropertyValueType<ReferencedItemType>;
    /** Minimum number of characters to trigger server lookup. If `0` supplied, the first page of suggestions will be fetched on focus. Defaults to 3 */
    minLookupCharacters?: number;
    /** The GraphQL node that the field suggestions will be fetched from */
    node: keyof ScreenBaseGenericType<CT>;
    /** The column or the set of columns which the table should be sorted by */
    orderBy?: ReferenceRecursiveOrderBy<ReferencedItemType>;
    /** Placeholder to be displayed in the field body */
    placeholder?: string;
    /** The GraphQL node property that will be used as the reference field value */
    valueField: PropertyValueType<ReferencedItemType>;
    /** Function to be executed when the reference's dialog is opened */
    onOpenReferenceDialog?: (this: CT, _id: string) => void;
    /** Function to be executed when the reference's dialog is closed */
    onCloseReferenceDialog?: (this: CT, _id: string) => void;
    /** Auto-select item if search matches only one element */
    isReferenceDialogOpen?: boolean;
    /** Auto-select item if search matches only one element */
    isAutoSelectEnabled?: boolean;
    /** Should auto select and suggestion be based on all known columns? */
    shouldSuggestionsIncludeColumns?: boolean;
    /** Button label for the create new button at the end of the dropdown list and the top of the lookup button. */
    createTunnelLinkText?: string;
}
export declare enum ReferenceDecoratorPropertiesKeys {
    isDropdownDisabled = "isDropdownDisabled",
    isFilterLimitedToDataset = "isFilterLimitedToDataset",
    minLookupCharacters = "minLookupCharacters",
    onCloseReferenceDialog = "onCloseReferenceDialog",
    onInputValueChange = "onInputValueChange",
    onOpenReferenceDialog = "onOpenReferenceDialog"
}
export interface ReferenceDecoratorProperties<CT extends ScreenBase = ScreenBase, ReferencedItemType extends ClientNode = any> extends Omit<ReferenceProperties<CT, ReferencedItemType>, '_controlObjectType'>, Changeable<CT>, Clickable<CT>, HasInputValueChangeListener<CT>, ExtensionField<CT, FieldControlObjectInstance<any>>, HasLookupDialogTitle, HasParent<CT, BlockControlObject<CT> | TileControlObject<CT>>, HasSound<CT>, Sizable, Validatable<CT, ReferencedItemType> {
    /** Function to be executed when the reference's dialog is opened */
    [ReferenceDecoratorPropertiesKeys.onOpenReferenceDialog]?: (this: CT) => void;
    /** Function to be executed when the reference's dialog is closed */
    [ReferenceDecoratorPropertiesKeys.onCloseReferenceDialog]?: (this: CT) => void;
    /** Minimum number of characters to trigger server lookup */
    [ReferenceDecoratorPropertiesKeys.minLookupCharacters]?: number;
    /** Whether the dropdown is disabled or not. If disabled the lookup dialog will be forcefully enabled. */
    [ReferenceDecoratorPropertiesKeys.isDropdownDisabled]?: boolean;
    /** Path reference to an other page. The user can use this page to view the details or modify the selected record.
     * When no value is selected, the user can create a new record using this page.
     * */
    tunnelPage?: string;
}
export interface NestedReferenceProperties<CT extends ScreenBase = ScreenBase, ContextNodeType extends ClientNode = any, ReferencedNode extends ClientNode = any> extends Omit<ReferenceProperties<CT, ReferencedNode>, 'bind' | 'filter'>, NestedChangeable<CT>, NestedClickable<CT>, Nested<ContextNodeType, ReferenceValueType<ContextNodeType>>, Sizable, HasLookupDialogTitle, HasNestedFilter<CT, ContextNodeType, ReferencedNode>, NestedValidatable<CT, ReferencedNode, ContextNodeType> {
    /** Minimum number of characters to trigger server lookup */
    [ReferenceDecoratorPropertiesKeys.minLookupCharacters]?: number;
    /** Whether the dropdown is disabled or not. If disabled the lookup dialog will be set to true. */
    [ReferenceDecoratorPropertiesKeys.isDropdownDisabled]?: boolean;
    /** Limit the values to the ones used in the existing dataset */
    [ReferenceDecoratorPropertiesKeys.isFilterLimitedToDataset]?: boolean;
    /** Path reference to an other page. The user can use this page to view the details or modify the selected record.
     * When no value is selected, the user can create a new record using this page.
     * */
    tunnelPage?: string;
}
export type BaseReferenceExtensionDecoratorProperties<CT extends ScreenBase = ScreenBase> = {
    onCloseReferenceDialogAfter?: (this: CT, _id: any) => void;
    onOpenReferenceDialogAfter?: (this: CT, _id: any) => void;
    onInputValueChangeAfter?: (this: CT, inputValue: string, isBulkChange: boolean) => void;
};
export type ReferenceComponentProps<T extends ClientNode = any> = BaseEditableComponentProperties<ReferenceDecoratorProperties<any, T>, T, NestedFieldsAdditionalProperties>;
export interface ConnectedReferenceComponentProps<T extends ClientNode = any> extends ReferenceComponentProps<T> {
    openTunnel: (fieldProperties: ReferenceDecoratorProperties, value: any) => Promise<any | null>;
}
export interface ReferenceComponentState {
    id: string;
    isNestedLookupDialogOpen?: boolean;
}
export interface ReferenceCellEditorState {
    id: string;
    endAction?: typeof TAB | typeof SHIFT_TAB;
    highlightAllOnFocus: boolean;
    isLookupPanelOpen: boolean;
    selectedRecord?: SelectItem;
    startValue: string;
    currentValue: string;
}
export interface ReferenceCellEditorProps extends CellParams<NestedReferenceProperties> {
}
//# sourceMappingURL=reference-types.d.ts.map