import Switch from 'carbon-react/esm/components/switch';
import React from 'react';
import { resolveByValue } from '../../../utils/resolve-value-utils';
import { splitValueToMergedValue } from '../../../utils/transformers';
export const SwitchRenderer = React.memo(props => {
    const { fieldProperties, tableElementId, screenId, isParentFieldDisabled, isTableReadOnly } = props;
    const isChecked = typeof props.value === 'boolean' ? props.value : props.value === 'true';
    const isDisabled = isParentFieldDisabled ||
        resolveByValue({
            screenId,
            propertyValue: fieldProperties.isDisabled,
            rowValue: splitValueToMergedValue(props.data),
            fieldValue: props.value,
            skipHexFormat: true,
        });
    const isReadOnly = resolveByValue({
        screenId,
        propertyValue: fieldProperties.isReadOnly,
        rowValue: splitValueToMergedValue(props.data),
        fieldValue: props.value,
        skipHexFormat: true,
    });
    const isColumnDisabled = !props.colDef.isEditable(props.data);
    const labelHelp = fieldProperties.title ? fieldProperties.titleHelp : undefined;
    const onChange = (event) => {
        const checked = event.target.checked;
        if (isChecked !== checked) {
            props.onChange(checked);
        }
    };
    const testId = `${tableElementId}-${props.rowIndex}-${props.api.getColumns().indexOf(props.column) + 1}`;
    return (React.createElement(fieldProperties.wrapper, { ...props },
        React.createElement("div", { className: "e-switch-cell-renderer", "data-testid": testId },
            React.createElement(Switch, { "aria-label": props.colDef.headerName, checked: isChecked, disabled: isDisabled || isReadOnly || isTableReadOnly || isColumnDisabled, labelHelp: labelHelp, onChange: onChange, reverse: true, size: "small", value: props.value }))));
});
//# sourceMappingURL=switch-cell-renderer.js.map