import { localize } from '../service/standalone-i18n-service';
import * as React from 'react';
import { RadioButton, RadioButtonGroup } from 'carbon-react/lib/components/radio-button';
import Button from 'carbon-react/esm/components/button';
import Icon from 'carbon-react/esm/components/icon';
import './profile-settings.scss';
import Link from 'carbon-react/esm/components/link';
var ProfileSettingsTab;
(function (ProfileSettingsTab) {
    ProfileSettingsTab["MyProfileTab"] = "MyProfile";
    ProfileSettingsTab["LanguageTab"] = "Language";
})(ProfileSettingsTab || (ProfileSettingsTab = {}));
const getProfileMenuItems = (user, translations) => {
    return [
        {
            key: ProfileSettingsTab.MyProfileTab,
            text: localize('@sage/xtrem-standalone/my-profile', 'My profile', {}, translations, user?.locale),
        },
        {
            key: ProfileSettingsTab.LanguageTab,
            text: localize('@sage/xtrem-standalone/language', 'Language', {}, translations, user?.locale),
        },
    ];
};
const getSupportedLocales = (user, translations) => {
    return [
        {
            key: 'en-US',
            text: localize('@sage/xtrem-standalone/language-en-us', 'English (United States)', {}, translations, user?.locale),
        },
        {
            key: 'en-GB',
            text: localize('@sage/xtrem-standalone/language-en-gb', 'English (United Kingdom)', {}, translations, user?.locale),
        },
        {
            key: 'de-DE',
            text: localize('@sage/xtrem-standalone/language-de-de', 'German (Germany)', {}, translations, user?.locale),
        },
        {
            key: 'fr-FR',
            text: localize('@sage/xtrem-standalone/language-fr-fr', 'French (France)', {}, translations, user?.locale),
        },
        {
            key: 'es-ES',
            text: localize('@sage/xtrem-standalone/language-es-es', 'Spanish (Spain)', {}, translations, user?.locale),
        },
    ].sort((a, b) => a.text.localeCompare(b.text));
};
function MyProfile({ user, translations, }) {
    return (React.createElement(React.Fragment, null,
        React.createElement("div", { className: "xe-profile-photo-container" },
            user?.photo && React.createElement("img", { src: `data:image;base64,${user.photo}`, className: "xe-profile-photo" }),
            !user?.photo && React.createElement("div", { className: "xe-profile-picture-large xe-profile-picture-empty" })),
        React.createElement("div", { className: "xe-profile-text-container" },
            React.createElement("div", { className: "xe-profile-text-hello" }, localize('@sage/xtrem-standalone/hello', 'Hello', {}, translations, user?.locale)),
            React.createElement("div", { className: "xe-profile-text-name" }, user?.firstName),
            React.createElement("div", { className: "xe-profile-text-name" }, user?.lastName),
            React.createElement("div", { className: "xe-profile-text-email" }, user?.email))));
}
const LanguageSelector = ({ user, translations, localeOnChange }) => {
    const [selectedLocale, setSelectedLocale] = React.useState(user?.locale);
    return (React.createElement(React.Fragment, null,
        React.createElement("div", { className: "xe-profile-language-selector-radio-button-container" },
            React.createElement(RadioButtonGroup, { value: selectedLocale, name: "locales", onChange: e => setSelectedLocale(e.target.value) }, getSupportedLocales(user, translations).map(locale => (React.createElement(RadioButton, { color: "colorsYang100", className: "xe-profile-language-selector-radio-button", key: locale.key, value: locale.key, label: locale.text, fieldHelp: locale.key, fieldHelpInline: true }))))),
        React.createElement("div", { className: "xe-profile-language-apply" },
            React.createElement(Button, { buttonType: "primary", onClick: () => localeOnChange(selectedLocale) }, localize('@sage/xtrem-standalone/apply-locale-selection', 'Apply', {}, translations, user?.locale)))));
};
const renderProfileContent = (tab, user, translations, localeOnChange) => {
    switch (tab) {
        case ProfileSettingsTab.MyProfileTab:
            return (React.createElement("div", { className: "xe-profile-my-profile-content" },
                React.createElement(MyProfile, { user: user, translations: translations })));
        case ProfileSettingsTab.LanguageTab:
            return (React.createElement("div", { className: "xe-profile-language-content" },
                React.createElement(LanguageSelector, { user: user, translations: translations, localeOnChange: localeOnChange })));
        default:
            return null;
    }
};
export const ProfileSettingsPanel = (props) => {
    const [currentTab, setTab] = React.useState(ProfileSettingsTab.MyProfileTab);
    return (React.createElement("div", { className: "xe-profile-container" },
        React.createElement("div", { className: "xe-profile-header" },
            React.createElement("span", null, localize('@sage/xtrem-standalone/personal-settings', 'Personal settings', {}, props.translations, props.user?.locale))),
        React.createElement("div", { className: "xe-profile-body" },
            React.createElement("div", { className: "xe-profile-menu" },
                React.createElement("div", { className: "xe-profile-menu-items-container" }, getProfileMenuItems(props.user, props.translations).map(item => (React.createElement("button", { type: "button", key: item.key, onClick: () => setTab(item.key), className: item.key === currentTab
                        ? 'xe-profile-menu-item xe-profile-menu-item-selected'
                        : 'xe-profile-menu-item' },
                    React.createElement("span", null, item.text))))),
                React.createElement("div", { className: "xe-profile-menu-logout" },
                    React.createElement(Icon, { color: "#FFFF", type: "logout" }),
                    React.createElement("a", { "data-component": "link", href: `${props.loginService}/logout?fromUrl=${document.location.href}`, className: "xe-profile-menu-logout-text" }, localize('@sage/xtrem-standalone/logout', 'Logout', {}, props.translations, props.user?.locale)))),
            React.createElement("div", { className: "xe-profile-content" },
                renderProfileContent(currentTab, props.user, props.translations, props.localeOnChange),
                React.createElement("div", { className: "xe-profile-links" },
                    React.createElement("div", { className: "xe-profile-menu-privacy-preferences-link" },
                        React.createElement(Link, { href: props.tenantItem.oneTrustMagicLink }, localize('@sage/xtrem-standalone/privacy-preferences', 'Privacy Preferences', {}, props.translations, props.user?.locale))))))));
};
//# sourceMappingURL=profile-settings.js.map