import { connect } from 'react-redux';
import { getSidebarLayoutDefinitionFromState } from '../../utils/state-utils';
import { XtremTabs } from '../ui/tabs/xtrem-tabs';
import React from 'react';
import { ConnectedTableSidebarSection } from './table-sidebar-section';
import { ConnectedTableSidebarCard } from './table-sidebar-card';
import { resolveByValue } from '../../utils/resolve-value-utils';
import { withCollectionValueItemSubscription } from '../connected-collection';
export function TableSidebarBody({ sidebarLayoutDefinition, screenId, recordId, recordValue, }) {
    const sections = Object.keys(sidebarLayoutDefinition).reduce((prevValue, currentKey) => {
        const sectionDefinition = sidebarLayoutDefinition[currentKey];
        const isHidden = (!!screenId &&
            resolveByValue({
                propertyValue: sectionDefinition.isHidden,
                rowValue: recordValue,
                fieldValue: recordId,
                screenId,
                skipHexFormat: true,
            })) ||
            false;
        if (isHidden) {
            return prevValue;
        }
        return [...prevValue, { id: currentKey, title: sectionDefinition.title }];
    }, []);
    const [currentTab, setCurrentTab] = React.useState(sections[0]?.id || '');
    return (React.createElement("div", { className: "e-table-sidebar-body" },
        screenId && React.createElement(ConnectedTableSidebarCard, null),
        React.createElement(XtremTabs, { tabs: sections, selectedTabId: currentTab, onTabChange: setCurrentTab, inSidebar: true }),
        currentTab && screenId && React.createElement(ConnectedTableSidebarSection, { section: currentTab })));
}
export const mapStateToProps = (state) => {
    const sidebarLayoutDefinition = getSidebarLayoutDefinitionFromState(state);
    let value;
    if (state.sidebar?.screenId) {
        const screenDefinition = state.screenDefinitions[state.sidebar.screenId];
        value = screenDefinition.values[state.sidebar.elementId];
    }
    return {
        sidebarLayoutDefinition,
        value,
        recordId: state.sidebar?.recordId || undefined,
        screenId: state.sidebar?.screenId,
        isUncommitted: true,
    };
};
export const ConnectedTableSidebarBody = connect(mapStateToProps)(withCollectionValueItemSubscription(TableSidebarBody));
//# sourceMappingURL=table-sidebar-body.js.map