import * as React from 'react';
import { connect } from 'react-redux';
import Icon from 'carbon-react/esm/components/icon';
import IconButton from 'carbon-react/esm/components/icon-button';
import { camelCase } from 'lodash';
import * as tokens from '@sage/design-tokens/js/base/common';
import { withCollectionValueItemSubscription } from '../connected-collection';
import { cleanMetadataFromRecord, splitValueToMergedValue } from '../../utils/transformers';
import { resolveByValue } from '../../utils/resolve-value-utils';
import Typography from 'carbon-react/esm/components/typography';
import XtremActionPopover from '../ui/xtrem-action-popover';
import { triggerHandledEvent } from '../../utils/events';
import NavigationArrows from '../ui/navigation-arrows/navigation-arrows';
import { selectSidebarNextRecord, selectSidebarPreviousRecord } from '../../redux/actions';
import { localize } from '../../service/i18n-service';
import { calculateActionMenu } from '../../utils/action-menu-utils';
import { getPageDefinitionFromState } from '../../utils/state-utils';
export function TableSidebarHeader({ elementId, headerDropdownActions, headerQuickActions, onError, onNextRecord, onPreviousRecord: onPrevRecord, accessBindings, recordValue, screenDefinition, screenId, sidebarGetTitle, tableTitle, hasPreviousRecord, hasNextRecord, isLoading, }) {
    if (!screenDefinition) {
        return null;
    }
    const rowValue = splitValueToMergedValue(recordValue);
    const title = isLoading
        ? localize('@sage/xtrem-ui/table-loadingOoo', 'Loading...')
        : resolveByValue({
            propertyValue: sidebarGetTitle,
            fieldValue: recordValue?._id,
            rowValue: recordValue,
            screenId,
            skipHexFormat: true,
        }) ||
            tableTitle ||
            elementId;
    const resolvedPopoverItems = calculateActionMenu({
        screenId,
        accessBindings,
        actions: headerDropdownActions,
        rowValue,
        onTriggerMenuItem: (onClick, onActionError) => triggerHandledEvent(screenId, elementId, { onClick, onError: onActionError || onError }, recordValue?._id, cleanMetadataFromRecord(splitValueToMergedValue(recordValue))),
    });
    const resolvedHeaderQuickActions = calculateActionMenu({
        screenId,
        accessBindings,
        actions: headerQuickActions,
        rowValue,
        onTriggerMenuItem: (onClick, onActionError) => triggerHandledEvent(screenId, elementId, { onClick, onError: onActionError || onError }, recordValue?._id, cleanMetadataFromRecord(splitValueToMergedValue(recordValue))),
    });
    return (React.createElement(Typography, { variant: "h3", mb: "16px", className: "e-sidebar-header", "data-testid": "e-sidebar-header" },
        React.createElement(NavigationArrows, { hasNextRecord: !isLoading && hasNextRecord, hasPreviousRecord: !isLoading && hasPreviousRecord, onNextRecord: onNextRecord, onPreviousRecord: onPrevRecord }),
        React.createElement("div", { className: "e-sidebar-title" }, title),
        !isLoading && resolvedHeaderQuickActions?.length > 0 && (React.createElement("div", { className: "e-sidebar-quick-action-container", "data-testid": "e-sidebar-quick-action-container" }, resolvedHeaderQuickActions.map(a => {
            if (!a.icon) {
                throw new Error('Icon is missing from sidebar quick action definition.');
            }
            if (a.isHidden) {
                return null;
            }
            return (React.createElement(IconButton, { key: a.icon, onAction: () => a.onClick(), disabled: a.isDisabled, "aria-label": a.title, ml: "16px", "data-testid": `e-sidebar-quick-action-label-${camelCase(a.title)}` },
                React.createElement(Icon, { type: a.icon, tooltipMessage: a.title, color: tokens.colorsUtilityMajor400 })));
        }))),
        !isLoading && resolvedPopoverItems?.length > 0 && (React.createElement("span", { className: "e-sidebar-dropdown-action-container", "data-testid": "e-sidebar-dropdown-action-container" },
            React.createElement(XtremActionPopover, { items: resolvedPopoverItems, noIconSupport: false, color: tokens.colorsUtilityMajor450 })))));
}
export const mapDispatchToProps = (dispatch) => ({
    onNextRecord: () => dispatch(selectSidebarNextRecord()),
    onPreviousRecord: () => dispatch(selectSidebarPreviousRecord()),
});
export const mapStateToProps = (state) => {
    let screenDefinition;
    let accessBindings = {};
    let tableProperties;
    let value;
    let tableTitle;
    let sidebarGetTitle;
    if (state.sidebar?.screenId) {
        screenDefinition = getPageDefinitionFromState(state.sidebar?.screenId, state);
        tableProperties = screenDefinition.metadata.uiComponentProperties[state.sidebar.elementId];
        value = screenDefinition.values[state.sidebar.elementId];
        sidebarGetTitle = tableProperties.sidebar?.title;
        accessBindings = screenDefinition.accessBindings;
        tableTitle = resolveByValue({
            propertyValue: tableProperties?.title,
            screenId: state.sidebar?.screenId,
            rowValue: null,
            fieldValue: null,
            skipHexFormat: true,
        });
    }
    return {
        screenDefinition,
        accessBindings,
        tableTitle,
        sidebarGetTitle,
        headerQuickActions: tableProperties?.sidebar?.headerQuickActions,
        headerDropdownActions: tableProperties?.sidebar?.headerDropdownActions,
        onError: tableProperties?.onError,
        recordId: state.sidebar?.recordId || undefined,
        elementId: state.sidebar?.elementId,
        screenId: state.sidebar?.screenId,
        hasPreviousRecord: state.sidebar?.hasPreviousRecord,
        hasNextRecord: state.sidebar?.hasNextRecord,
        isLoading: state.sidebar?.isLoading,
        value,
        isUncommitted: true,
    };
};
export const ConnectedTableSidebarHeader = connect(mapStateToProps, mapDispatchToProps)(withCollectionValueItemSubscription(TableSidebarHeader));
//# sourceMappingURL=table-sidebar-header.js.map