import React from 'react';
import IconButton from 'carbon-react/esm/components/icon-button';
import Icon from 'carbon-react/esm/components/icon';
import { localize } from '../../../service/i18n-service';
import Textbox from 'carbon-react/esm/components/textbox';
import { fetchNodeDetails } from '../../../service/node-information-service';
import { chain } from 'lodash';
import { getArtifactDescription } from '../../../utils/transformers';
import { Tree } from '@sage/xtrem-ui-components';
import { textStreams } from '@sage/xtrem-shared';
export const NodeBrowserTree = React.memo(props => {
    const { node, onCheckedItemsUpdated, filter, checkedItems, isDisabled, isReadOnly } = props;
    const rootElement = React.useMemo(() => node
        ? {
            id: '',
            labelPath: '',
            key: '',
            labelKey: '',
            label: '',
            canBeExpanded: true,
            canBeSelected: false,
            data: {
                kind: 'OBJECT',
                name: '',
                label: '',
                type: getArtifactDescription(node?.toString() || '').name,
                canFilter: false,
                canSort: false,
                node: '',
                enumType: null,
                isCustom: false,
                dataType: '',
                targetNode: '',
                isOnInputType: false,
                isOnOutputType: false,
                isMutable: false,
            },
        }
        : null, [node]);
    const fetchItems = React.useCallback(async (treeNode) => {
        const allNodeInfo = await fetchNodeDetails({ nodeName: treeNode.data.type });
        let filteredNodes = chain(allNodeInfo).values();
        if (filter) {
            filteredNodes = filteredNodes.thru(filter);
        }
        return filteredNodes
            .map(nodeInfo => ({
            data: nodeInfo,
            key: treeNode.key ? `${treeNode.key}.${nodeInfo.name}` : nodeInfo.name,
            id: treeNode.key ? `${treeNode.key}.${nodeInfo.name}` : nodeInfo.name,
            labelKey: treeNode.label ? `${treeNode.label}.${nodeInfo.label}` : nodeInfo.label,
            labelPath: treeNode.label ? `${treeNode.label}.${nodeInfo.label}` : nodeInfo.label,
            label: nodeInfo.label,
            canBeExpanded: (nodeInfo.kind === 'OBJECT' && !textStreams.includes(nodeInfo.type)) ||
                nodeInfo.kind === 'INTERFACE',
            canBeSelected: (nodeInfo.kind !== 'OBJECT' || textStreams.includes(nodeInfo.type)) &&
                nodeInfo.kind !== 'INTERFACE',
        }))
            .value();
    }, [filter]);
    const [searchText, setSearchText] = React.useState('');
    const [inputRef, setInputRef] = React.useState(null);
    const [listOpenedItems, setListOpenedItems] = React.useState({
        key: '',
        children: [],
    });
    const handleOpenChild = React.useCallback((key, children) => {
        setListOpenedItems({ ...listOpenedItems, [key]: children });
    }, [listOpenedItems]);
    const handleCloseChild = React.useCallback((key) => {
        const updatedOpenedItems = { ...listOpenedItems };
        delete updatedOpenedItems[key];
        setListOpenedItems(updatedOpenedItems);
    }, [listOpenedItems]);
    const onClearButtonClicked = React.useCallback(() => {
        setSearchText('');
        if (inputRef?.current) {
            inputRef.current.focus();
        }
    }, [setSearchText, inputRef]);
    const onSearchTextChanged = React.useCallback((ev) => {
        setSearchText(ev.target.value);
    }, []);
    return (rootElement && (React.createElement(React.Fragment, null,
        React.createElement("div", { "data-testid": "e-data-step-search" },
            React.createElement(Textbox, { "data-testid": "e-node-browser-filter", inputRef: setInputRef, onKeyDown: (e) => {
                    // On hitting the enter key the component reloads the page for some reason
                    if (e.key === 'Enter') {
                        e.preventDefault();
                    }
                }, disabled: isDisabled, onChange: onSearchTextChanged, placeholder: localize('@sage/xtrem-ui/reference-lookup-dialog-search-placeholder', 'Search...'), "aria-label": localize('@sage/xtrem-ui/reference-lookup-dialog-search-placeholder', 'Search...'), leftChildren: React.createElement(Icon, { type: "search", bgSize: "large" }), value: searchText, mb: 1 }, !!searchText && (React.createElement(IconButton, { onAction: onClearButtonClicked, "aria-label": localize('@sage/xtrem-ui/clear-filter-text', 'Clear filter text') },
                React.createElement(Icon, { type: "cross" }))))),
        React.createElement("div", { className: "e-data-step-tree-container" },
            React.createElement("div", { className: "e-data-step-tree-wrapper" }, rootElement && (React.createElement(Tree, { checkedItems: checkedItems || {}, element: rootElement, fetchItems: fetchItems, isDisabled: isDisabled, level: 0, listOpenedItems: listOpenedItems, onCheckedItemsUpdated: onCheckedItemsUpdated, onCloseChild: handleCloseChild, onOpenChild: handleOpenChild, searchText: searchText, isReadOnly: isReadOnly })))))));
});
NodeBrowserTree.displayName = 'NodeBrowserTree';
//# sourceMappingURL=node-browser-tree.js.map