import React from 'react';
import { defaultCellEditorStyles } from '../../../../utils/ag-grid/ag-grid-cell-editor-utils';
import { KEY_BACKSPACE, KEY_DELETE, KEY_F2 } from '../../../../utils/keyboard-event-utils';
export class DefaultCellEditor extends React.Component {
    constructor(props) {
        super(props);
        this.inputRef = React.createRef();
        this.state = this.createInitialState(props);
    }
    componentDidMount() {
        const input = this.inputRef.current;
        if (!input) {
            return;
        }
        input.focus();
        if (this.state.highlightAllOnFocus) {
            input.select();
            this.setState({
                highlightAllOnFocus: false,
            });
        }
        else {
            // when we started editing, we want the caret at the end, not the start.
            // this comes into play in two scenarios: a) when user hits F2 and b)
            // when user hits a printable character, then on IE (and only IE) the caret
            // was placed after the first character, thus 'apply' would end up as 'pplea'
            const length = input.value ? input.value.length : 0;
            if (length > 0) {
                input.setSelectionRange(length, length);
            }
        }
    }
    handleChange(event) {
        this.setState({ value: event.target.value });
    }
    createInitialState(props) {
        let startValue;
        let highlightAllOnFocus = true;
        if (props.keyPress === KEY_BACKSPACE || props.keyPress === KEY_DELETE) {
            // if backspace or delete pressed, we clear the cell
            startValue = '';
        }
        else if (props.charPress) {
            // if a letter was pressed, we start with the letter
            startValue = props.charPress;
            highlightAllOnFocus = false;
        }
        else {
            // otherwise we start with the current value
            startValue = props.value;
            if (props.keyPress === KEY_F2) {
                highlightAllOnFocus = false;
            }
        }
        return {
            value: startValue,
            highlightAllOnFocus,
        };
    }
    render() {
        return (React.createElement("div", { className: "ag-cell-edit-wrapper" },
            React.createElement("input", { ref: this.inputRef, type: "text", value: this.state.value, onChange: this.handleChange, style: defaultCellEditorStyles })));
    }
}
//# sourceMappingURL=default-cell-editor.js.map