import React, { forwardRef, useImperativeHandle, useState } from 'react';
import { isEqual } from 'lodash';
import styled from 'styled-components';
import { Checkbox } from 'carbon-react/esm/components/checkbox';
import CarbonIcon from 'carbon-react/esm/components/icon';
import { SET, FieldKey } from '../../../../types';
import { localize } from '../../../../../service/i18n-service';
import { useUpdateEffect } from '../../../../../utils/hooks/effects/use-update-effect';
export const BooleanFilter = forwardRef((props, ref) => {
    const [origin, setOrigin] = useState('view');
    const [filter, setFilter] = useState([]);
    const { filterChangedCallback } = props;
    useUpdateEffect(() => {
        if (origin === 'view') {
            setTimeout(() => filterChangedCallback(), 100);
        }
        else {
            filterChangedCallback();
        }
    }, [filter, origin, filterChangedCallback]);
    useImperativeHandle(ref, () => {
        return {
            doesFilterPass() {
                return true;
            },
            isFilterActive() {
                return filter.length > 0;
            },
            getModel() {
                return filter.length > 0 ? { filterType: SET, values: filter } : null;
            },
            setModel(model) {
                if (model && model.values && !isEqual(model.values, filter)) {
                    setOrigin('view');
                    setFilter(model.values);
                }
            },
        };
    }, [filter]);
    const Container = styled.div `
        padding: 16px;
        display: grid;
        grid-template-columns: 1fr 5fr;
        grid-template-rows: repeat(2, 1fr);
        grid-column-gap: 0px;
        grid-row-gap: 16px;
        align-items: center;
    `;
    const Icon = styled(CarbonIcon) `
        &:before {
            font-weight: bold;
            font-size: var(--sizing200);
            line-height: var(--sizing200);
        }
    `;
    const trueChecked = filter.length === 1 && filter[0] === true;
    const falseChecked = filter.length === 1 && filter[0] === false;
    const isSwitch = props.controlObjectType === FieldKey.Switch;
    return (React.createElement(Container, { className: "e-boolean-custom-filter" },
        React.createElement(Checkbox, { checked: trueChecked, className: "e-boolean-custom-filter-checkbox-true", onChange: () => {
                setOrigin('user');
                if (trueChecked) {
                    setFilter([]);
                }
                else {
                    setFilter([true]);
                }
            } }),
        isSwitch ? React.createElement("span", null, localize('@sage/xtrem-ui/switch-on-caps', 'ON')) : React.createElement(Icon, { type: "tick" }),
        React.createElement(Checkbox, { checked: falseChecked, className: "e-boolean-custom-filter-checkbox-false", onChange: () => {
                setOrigin('user');
                if (falseChecked) {
                    setFilter([]);
                }
                else {
                    setFilter([false]);
                }
            } }),
        isSwitch ? React.createElement("span", null, localize('@sage/xtrem-ui/switch-off-caps', 'OFF')) : React.createElement(Icon, { type: "close" })));
});
BooleanFilter.displayName = 'BooleanFilter';
//# sourceMappingURL=boolean-filter.js.map