import React, { useState } from 'react';
import CarbonDate from 'carbon-react/esm/components/date';
import { EQUALS, RANGE } from '@sage/xtrem-shared';
import { localize } from '../../../../../service/i18n-service';
const DateFloatingFilter = React.forwardRef((props, ref) => {
    // FormattedValue is the value that is displayed in the input field, rawValue is the value that is used for filtering
    const [formattedValue, setFormattedValue] = useState('');
    const [disabled, setDisabled] = useState(false);
    const handleChange = (event) => {
        const newValue = event.target.value.rawValue;
        const newFormattedValue = event.target.value.formattedValue;
        if (disabled)
            return;
        if (newFormattedValue === '') {
            props.parentFilterInstance(instance => {
                instance.onFloatingFilterChanged(EQUALS, { rawValue: '', formattedValue: '' });
            });
        }
        else {
            props.parentFilterInstance(instance => {
                instance.onFloatingFilterChanged(EQUALS, { rawValue: newValue, formattedValue: newFormattedValue });
            });
        }
        setFormattedValue(newFormattedValue);
    };
    React.useImperativeHandle(ref, () => {
        return {
            onParentModelChanged(parentModel) {
                // In Range mode the floating filter is disabled
                if (parentModel && parentModel.type === RANGE) {
                    setDisabled(true);
                    setFormattedValue(`${parentModel.formattedValue} - ${parentModel.formattedValueTo}`);
                    return;
                }
                if (parentModel && parentModel.operator === 'AND') {
                    setDisabled(true);
                    setFormattedValue(`${parentModel.condition1?.formattedValue} AND ${parentModel.condition2?.formattedValue}`);
                    return;
                }
                if (parentModel && parentModel.type !== RANGE) {
                    setDisabled(false);
                    setFormattedValue(parentModel.formattedValue);
                    return;
                }
                // Defaults
                setFormattedValue('');
                setDisabled(false);
            },
        };
    });
    const filterName = props.column.getColDef().headerName;
    const floatingFilterLabel = localize('@sage/xtrem-ui/floating-filter-label', '{{ filterName }} filter input', {
        filterName,
    });
    return (React.createElement("div", { className: "e-filter-date-floating-container" },
        React.createElement(CarbonDate, { disabled: disabled, allowEmptyValue: true, onChange: handleChange, value: formattedValue, size: "small", autoComplete: "off", inputWidth: 100, "aria-label": floatingFilterLabel })));
});
DateFloatingFilter.displayName = 'DateFloatingFilter';
export default DateFloatingFilter;
//# sourceMappingURL=date-floating-filter.js.map