import type { ClientNode } from '@sage/xtrem-client';
import type { NestedRecordId, ScreenExtension } from '../../../../types';
import type { MenuSeparatorType } from '../../../control-objects';
import type { CollectionItem, PartialCollectionValueWithIds } from '../../../types';
import type { CollectionActionAccessConfiguration, HasGenericErrorHandler, HasIcon } from '../../../field/traits';
export interface CollectionPropertiesWithActions extends HasGenericErrorHandler<any> {
    dropdownActions?: Array<CollectionItemAction<any> | MenuSeparatorType>[];
    inlineActions?: Array<InlineCollectionItemAction<any>>[];
    levels?: {
        dropdownActions: any[];
        inlineActions: any;
    }[];
}
export interface CollectionItemAction<CT extends ScreenExtension<CT>, NestedRecordType = CollectionItem> extends HasIcon, HasGenericErrorHandler<CT> {
    title: string;
    access?: CollectionActionAccessConfiguration;
    onClick: (this: CT, recordId: NestedRecordId, rowItem: PartialCollectionValueWithIds<NestedRecordType>) => void;
    isDisabled?: (this: CT, recordId: NestedRecordId, rowItem: PartialCollectionValueWithIds<NestedRecordType>) => boolean;
    isHidden?: (this: CT, recordId: NestedRecordId, rowItem: PartialCollectionValueWithIds<NestedRecordType>) => boolean;
    isDestructive?: boolean;
}
export interface CollectionItemActionGroup<CT extends ScreenExtension<CT>, NestedRecordType = CollectionItem> extends HasIcon, HasGenericErrorHandler<CT> {
    title: string;
    access?: CollectionActionAccessConfiguration;
    isDisabled?: (this: CT, recordId: NestedRecordId, rowItem: PartialCollectionValueWithIds<NestedRecordType>) => boolean;
    isHidden?: (this: CT, recordId: NestedRecordId, rowItem: PartialCollectionValueWithIds<NestedRecordType>) => boolean;
    children?: Array<CollectionItemAction<CT, NestedRecordType> | MenuSeparatorType | CollectionItemActionGroup<CT, NestedRecordType>>;
}
export interface InlineCollectionItemAction<CT extends ScreenExtension<CT>, NestedRecordType = CollectionItem> extends CollectionItemAction<CT, NestedRecordType> {
    buttonType?: string;
    isMajor?: boolean;
}
export interface NestedCollectionItemAction<CT extends ScreenExtension<CT>, NestedRecordType extends ClientNode = any> extends HasIcon, HasGenericErrorHandler<CT> {
    title: string;
    isDestructive?: boolean;
    access?: CollectionActionAccessConfiguration;
    onClick: (this: CT, recordId: NestedRecordId, rowItem: NestedRecordType, level?: number, parentIds?: NestedRecordId[]) => void;
    isDisabled?: (this: CT, recordId: NestedRecordId, rowItem: NestedRecordType, level?: number, parentIds?: NestedRecordId[]) => boolean;
    isHidden?: (this: CT, recordId: NestedRecordId, rowItem: NestedRecordType, level?: number, parentIds?: NestedRecordId[]) => boolean;
}
export interface NestedCollectionItemActionGroup<CT extends ScreenExtension<CT>, NestedRecordType extends ClientNode = any> extends HasIcon, HasGenericErrorHandler<CT> {
    title: string;
    access?: CollectionActionAccessConfiguration;
    isDisabled?: (this: CT, recordId: NestedRecordId, rowItem: NestedRecordType, level?: number, parentIds?: NestedRecordId[]) => boolean;
    isHidden?: (this: CT, recordId: NestedRecordId, rowItem: NestedRecordType, level?: number, parentIds?: NestedRecordId[]) => boolean;
    children?: Array<NestedCollectionItemAction<CT, NestedRecordType> | MenuSeparatorType | NestedCollectionItemActionGroup<CT, NestedRecordType>>;
}
//# sourceMappingURL=table-dropdown-action-types.d.ts.map