import * as React from 'react';
import { connect } from 'react-redux';
import { triggerHandledEvent } from '../../../../utils/events';
import { splitValueToMergedValue } from '../../../../utils/transformers';
import XtremActionPopover from '../../xtrem-action-popover';
import Icon from 'carbon-react/esm/components/icon';
import IconButton from 'carbon-react/esm/components/icon-button';
import { navigationPanelId } from '../../../container/navigation-panel/navigation-panel-types';
import { getPageDefinitionFromState } from '../../../../utils/state-utils';
import { calculateActionMenu } from '../../../../utils/action-menu-utils';
export class TableDropdownActions extends React.Component {
    constructor() {
        super(...arguments);
        this.isNestedGrid = () => Object.prototype.hasOwnProperty.call(this.props.fieldProperties, 'levels');
        this.calculateMenu = () => {
            const isNestedGrid = this.isNestedGrid();
            const actions = isNestedGrid && this.props.fieldProperties.levels
                ? this.props.fieldProperties.levels[this.props.level].dropdownActions
                : this.props.fieldProperties.dropdownActions;
            if (actions) {
                const rowValue = splitValueToMergedValue(this.props.tableData.getRawRecord({ id: this.props.recordId, level: this.props.level }));
                if (!rowValue) {
                    return [];
                }
                return calculateActionMenu({
                    screenId: this.props.screenId,
                    accessBindings: this.props.accessBindings,
                    actions,
                    rowValue,
                    onTriggerMenuItem: this.onClickMenu,
                });
            }
            return [];
        };
        this.onClickMenu = (onClick, onError) => {
            if (!onClick) {
                return;
            }
            const isNestedGrid = this.isNestedGrid();
            const ancestorIds = this.props.tableData.getAncestorIds({
                id: this.props.recordId,
                level: this.props.level,
            });
            if (isNestedGrid) {
                triggerHandledEvent(this.props.screenId, this.props.fieldId, { onClick, onError: onError || this.props.fieldProperties.onError }, this.props.recordId, splitValueToMergedValue(this.props.rowValue), this.props.level, ancestorIds);
            }
            else {
                triggerHandledEvent(this.props.screenId, this.props.fieldId, { onClick, onError: onError || this.props.fieldProperties.onError }, this.props.recordId, splitValueToMergedValue(this.props.rowValue));
            }
        };
    }
    renderPhantomRowRemoveButton(phantomRowIsDirty) {
        if (!phantomRowIsDirty) {
            return null;
        }
        const row = this.props.tableData.getRawRecord({
            id: this.props.recordId,
            level: this.props.level,
            cleanMetadata: false,
        });
        return (React.createElement(IconButton, { onAction: async () => {
                await this.props.tableData.resetRowToDefaults({
                    id: row._id,
                    level: row.__level,
                    parentId: row.__parentId,
                    isOrganicChange: true,
                    resetDirtiness: true,
                });
            }, disabled: false, "aria-label": "Cancel" },
            React.createElement(Icon, { tooltipMessage: "Cancel", type: "cross_circle", color: "--colorsUtilityYin030", fontSize: "small" })));
    }
    render() {
        if (this.props.tableData) {
            if (this.props.isPhantomRow) {
                return this.renderPhantomRowRemoveButton(this.props.phantomRowIsDirty ?? false);
            }
            const calculatedMenu = this.calculateMenu();
            return React.createElement(XtremActionPopover, { items: calculatedMenu, isDisabled: this.props.isDisabled });
        }
        return null;
    }
}
const mapStateToProps = (state, props) => {
    const screenDefinition = getPageDefinitionFromState(props.screenId, state);
    const fieldProperties = screenDefinition.metadata.uiComponentProperties[props.fieldId];
    const tableData = props.fieldId === navigationPanelId
        ? screenDefinition.navigationPanel?.value
        : screenDefinition.values[props.fieldId];
    const rowValue = tableData?.getRawRecord({
        id: props.recordId,
        level: props.level,
    }) || {};
    return {
        ...props,
        fieldProperties,
        accessBindings: screenDefinition.accessBindings,
        tableData,
        rowValue,
    };
};
export default connect(mapStateToProps)(TableDropdownActions);
//# sourceMappingURL=table-dropdown-actions.js.map