import React from 'react';
import styled from 'styled-components';
import { connect } from 'react-redux';
import ButtonMinor from 'carbon-react/esm/components/button-minor';
import Button from 'carbon-react/esm/components/button';
import { triggerHandledEvent } from '../../../utils/events';
import { splitValueToMergedValue } from '../../../utils/transformers';
import { navigationPanelId } from '../../container/navigation-panel/navigation-panel-types';
import { TABLE_INLINE_ACTION_CSS_CLASS } from '../../../utils/constants';
import { getPageDefinitionFromState } from '../../../utils/state-utils';
import { calculateActionMenu } from '../../../utils/action-menu-utils';
const StyledMinorButton = styled(ButtonMinor) `
    ${(props) => props.isHidden ? '.e-card-content && { display: none; }; visibility: hidden;' : 'visibility: visible;'}
`;
const StyledButton = styled(Button) `
    ${(props) => props.isHidden ? '.e-card-content && { display: none; }; visibility: hidden;' : 'visibility: visible;'}
`;
const TableInlineAction = React.memo(props => {
    const buttonProps = {
        tabIndex: props.isHidden || props.isDisabled ? '-1' : '0',
        className: TABLE_INLINE_ACTION_CSS_CLASS,
        'data-testid': TABLE_INLINE_ACTION_CSS_CLASS,
        buttonType: props.buttonType ?? 'tertiary',
        size: 'small',
        iconType: props.icon,
        'aria-label': props.title ?? '',
        iconTooltipMessage: props.title ?? '',
        onClick: props.onClick,
        disabled: props.isDisabled,
        isHidden: props.isHidden,
        destructive: props.isDestructive ?? false,
    };
    if (props.isMajor) {
        return React.createElement(StyledButton, { key: props.key, ...buttonProps });
    }
    return React.createElement(StyledMinorButton, { key: props.key, ...buttonProps });
}, (prev, next) => {
    return (prev.isHidden === next.isHidden &&
        prev.isDisabled === next.isDisabled &&
        prev.buttonType === next.buttonType &&
        prev.icon === next.icon &&
        prev.title === next.title &&
        prev.isDestructive === next.isDestructive);
});
TableInlineAction.displayName = 'TableInlineAction';
function TableInlineActions({ inlineActions }) {
    return (React.createElement(React.Fragment, null, inlineActions.map(inlineAction => {
        return React.createElement(TableInlineAction, { ...inlineAction, key: inlineAction.key });
    })));
}
const mapStateToProps = (state, props) => {
    const pageDefinition = getPageDefinitionFromState(props.screenId, state);
    const fieldProperties = pageDefinition.metadata.uiComponentProperties[props.fieldId];
    const tableData = props.fieldId === navigationPanelId
        ? pageDefinition.navigationPanel?.value
        : pageDefinition.values[props.fieldId];
    const rowValue = tableData?.getRawRecord({
        id: props.recordId,
        level: props.level,
    }) || {};
    const isNestedGrid = Object.prototype.hasOwnProperty.call(fieldProperties, 'levels');
    const inlineActionsSource = isNestedGrid
        ? fieldProperties.levels?.[props.level].inlineActions
        : fieldProperties.inlineActions;
    const inlineActions = calculateActionMenu({
        actions: inlineActionsSource,
        screenId: props.screenId,
        rowValue,
        accessBindings: pageDefinition.accessBindings,
        onTriggerMenuItem: (onClick, onError) => {
            state.applicationContext?.onTelemetryEvent?.('tableInlineActionTriggered', {
                screenId: props.screenId,
                elementId: props.fieldId,
            });
            if (!onClick) {
                return;
            }
            const args = [
                ...[
                    props.screenId,
                    props.fieldId,
                    { onClick, onError: onError || fieldProperties.onError },
                    props.recordId,
                    splitValueToMergedValue(rowValue),
                ],
                ...(isNestedGrid
                    ? [
                        props.level,
                        tableData.getAncestorIds({
                            id: props.recordId,
                            level: props.level,
                        }),
                    ]
                    : []),
            ];
            triggerHandledEvent(...args);
        },
    });
    return {
        inlineActions,
    };
};
export default connect(mapStateToProps)(TableInlineActions);
//# sourceMappingURL=table-inline-actions.js.map