import { ActionPopover, ActionPopoverDivider, ActionPopoverItem, ActionPopoverMenu, } from 'carbon-react/esm/components/action-popover';
import Button from 'carbon-react/esm/components/button';
import ButtonMinor from 'carbon-react/esm/components/button-minor';
import * as React from 'react';
import { connect } from 'react-redux';
import Icon from 'carbon-react/esm/components/icon';
import { localize } from '../../service/i18n-service';
import { noop, slice } from 'lodash';
import IconButton from 'carbon-react/esm/components/icon-button';
import * as tokens from '@sage/design-tokens/js/base/common';
import { MENU_SEPARATOR } from '../control-objects';
import * as ReactDom from 'react-dom';
import Hr from 'carbon-react/esm/components/hr';
import { ACTION_POPOVER_SUBMENUS_COMPAT_CSS_CLASS, SINGLE_INLINE_ACTION_CSS_CLASS } from '../../utils/constants';
function XtremMobilePopoverMenuItem({ item, level = 0, onSelect, isDisabled, }) {
    const [isOpen, setOpen] = React.useState(false);
    if (item === MENU_SEPARATOR) {
        return React.createElement(Hr, { m: 0 });
    }
    if (item.isHidden) {
        return null;
    }
    const props = {
        fullWidth: true,
        buttonType: 'tertiary',
        mt: '8px',
        mb: '8px',
        ml: 0,
        mr: 0,
        iconType: item.icon || 'none',
        'data-testid': item.testId,
        'aria-label': item.title,
        disabled: isDisabled || item.isDisabled,
        key: `${level}_${item.key}`,
        className: item.isDestructive
            ? `e-action-popover-item e-action-popover-item-level-${level} e-action-popover-item-destructive`
            : `e-action-popover-item e-action-popover-item-level-${level}`,
    };
    if (item.childrenProp && item.childrenProp.length > 0) {
        return (React.createElement(React.Fragment, null,
            React.createElement(ButtonMinor, { ...props, onClick: () => setOpen(!isOpen) },
                React.createElement("span", { className: "e-action-popover-item-mobile-label" }, item.title),
                React.createElement(Icon, { type: isOpen ? 'chevron_down' : 'chevron_up' })),
            isOpen &&
                item.childrenProp.map(c => (React.createElement(XtremMobilePopoverMenuItem, { key: `${level}_${item.key}`, item: c, level: level + 1, isDisabled: isDisabled, onSelect: onSelect })))));
    }
    return (React.createElement(ButtonMinor, { ...props, onClick: onSelect(item) },
        React.createElement("span", { className: "e-action-popover-item-mobile-label" }, item.title)));
}
export class XtremActionPopover extends React.Component {
    constructor(props) {
        super(props);
        this.getVisibleMenuItems = () => this.props.items.filter(item => item === MENU_SEPARATOR || !item.isHidden);
        this.onRecordClick = (item) => (event) => {
            this.toggleMobileMenu(event);
            if (item.onClick && !this.props.isDisabled) {
                item.onClick();
            }
        };
        this.getSingleActionIconButton = (item) => (React.createElement(IconButton, { onAction: () => item.onClick(), disabled: this.props.isDisabled || item.isDisabled, 
            // @ts-expect-error tabIndex not included in the carbon IconButton typings
            tabIndex: this.props.isDisabled ? -1 : 0, "aria-label": item.title, "data-testid": SINGLE_INLINE_ACTION_CSS_CLASS, className: SINGLE_INLINE_ACTION_CSS_CLASS },
            React.createElement(Icon, { tooltipMessage: item.title, type: item.icon, color: item.isDestructive ? tokens.colorsSemanticNegative500 : tokens.colorsActionMinor500 })));
        this.createActionPopoverChildren = () => {
            const reducerFn = (previousValue, item, index, items) => {
                if (item === MENU_SEPARATOR) {
                    // If all previous items are separators, we should not render it at all
                    if (!slice(items, 0, index).find(i => i !== MENU_SEPARATOR)) {
                        return previousValue;
                    }
                    // If the last visible item is a separator, we should not render it at all
                    if (index === items.length - 1) {
                        return previousValue;
                    }
                    if (items[index + 1] === MENU_SEPARATOR) {
                        // If there are multiple separators after each other, we should not render it
                        return previousValue;
                    }
                    previousValue.push(this.props.isDeviceLessThanSmall ? (React.createElement("div", { className: "e-action-popover-divider", key: index },
                        React.createElement(ActionPopoverDivider, null))) : (React.createElement(ActionPopoverDivider, { key: index })));
                    return previousValue;
                }
                const props = {
                    icon: item.icon,
                    disabled: this.props.isDisabled || item.isDisabled,
                    onClick: this.onRecordClick(item),
                    children: React.createElement("span", { "data-testid": item.testId }, item.title),
                    key: item.key,
                };
                if (item.childrenProp && item.childrenProp.length > 0) {
                    const submenu = (React.createElement(ActionPopoverMenu, { key: item.key }, item.childrenProp.reduce(reducerFn, [])));
                    props.submenu = submenu;
                    props.onClick = noop;
                }
                props.className = item.isDestructive ? 'e-action-popover-item-destructive' : undefined;
                const actionPopoverItem = React.createElement(ActionPopoverItem, { ...props });
                previousValue.push(actionPopoverItem);
                return previousValue;
            };
            return this.getVisibleMenuItems().reduce(reducerFn, []);
        };
        this.createActionPopoverChildrenMobile = () => {
            return (React.createElement("div", { className: "e-action-popover-item-list-wrapper" }, this.getVisibleMenuItems().map((item, index) => (React.createElement(XtremMobilePopoverMenuItem, { key: item === MENU_SEPARATOR ? `SEP_${index}` : item.key, item: item, isDisabled: this.props.isDisabled, level: 0, onSelect: this.onRecordClick })))));
        };
        this.toggleMobileMenu = (event) => {
            event.preventDefault();
            event.stopPropagation();
            if (this.props.onOpen) {
                this.props.onOpen();
            }
            this.setState(state => ({ isOpen: !state.isOpen }));
        };
        this.itemHasNoIcon = (item) => {
            return !item.icon || item.icon === 'none';
        };
        this.state = { isOpen: false };
    }
    componentWillUnmount() {
        document.body.classList.remove(ACTION_POPOVER_SUBMENUS_COMPAT_CSS_CLASS);
    }
    getMobileActionButton() {
        const visibleItems = this.getVisibleMenuItems();
        const hasChildren = (item) => {
            return (item !== MENU_SEPARATOR &&
                !!item.childrenProp &&
                Array.isArray(item.childrenProp) &&
                item.childrenProp.length > 0);
        };
        if (this.props.noIconSupport ||
            (visibleItems.length === 1 && hasChildren(visibleItems[0])) ||
            visibleItems.length > 1) {
            return (React.createElement(IconButton, { onAction: this.toggleMobileMenu, "data-component": "action-popover-button", "data-element": "action-popover-button" },
                React.createElement(Icon, { type: "ellipsis_vertical", color: this.props.color })));
        }
        if (visibleItems.length === 1 && visibleItems[0] !== MENU_SEPARATOR) {
            return this.getSingleActionIconButton(visibleItems[0]);
        }
        return null;
    }
    renderDesktop() {
        const message = localize('@sage/xtrem-ui/action-button-more', 'More Actions');
        const visibleItems = this.getVisibleMenuItems();
        const visibleItemsNoSeparator = visibleItems.filter(i => i !== MENU_SEPARATOR);
        if (this.props.noIconSupport ||
            (visibleItemsNoSeparator.length === 1 &&
                visibleItemsNoSeparator[0].childrenProp &&
                visibleItemsNoSeparator[0].childrenProp.length > 0) ||
            visibleItemsNoSeparator.length > 1 ||
            (visibleItemsNoSeparator.length === 1 && this.itemHasNoIcon(visibleItemsNoSeparator[0]))) {
            if (this.props.isDisabled) {
                return (React.createElement(Button, { iconType: "ellipsis_vertical", disabled: true, "aria-label": message, buttonType: "tertiary", onClick: noop, "data-testid": "e-popover-open" }));
            }
            return (React.createElement(ActionPopover, { renderButton: () => (React.createElement("div", { "data-component": "action-popover-button" },
                    React.createElement(Icon, { "aria-label": message, type: "ellipsis_vertical", tooltipMessage: message, color: this.props.color }))), onOpen: () => {
                    /* This timeout is necessary as the carbon ActionPopover submenus are buggy and flickering in first render */
                    document.body.classList.add(ACTION_POPOVER_SUBMENUS_COMPAT_CSS_CLASS);
                    setTimeout(() => {
                        this.setState({
                            isOpen: true,
                        }, () => {
                            document.body.classList.remove(ACTION_POPOVER_SUBMENUS_COMPAT_CSS_CLASS);
                            if (this.props.onOpen) {
                                this.props.onOpen();
                            }
                        });
                    }, 50);
                }, onClose: () => {
                    this.setState({ isOpen: false });
                } }, this.createActionPopoverChildren()));
        }
        if (visibleItemsNoSeparator.length === 1) {
            return this.getSingleActionIconButton(visibleItemsNoSeparator[0]);
        }
        return null;
    }
    renderMobile() {
        return (React.createElement(React.Fragment, null,
            this.state.isOpen &&
                ReactDom.createPortal(React.createElement("div", { className: "e-action-popover-mobile" },
                    React.createElement("div", { className: "e-action-popover-mobile-background", onClick: this.toggleMobileMenu }),
                    React.createElement("div", { className: "e-action-popover-mobile-content", "data-component": "action-popover" }, this.createActionPopoverChildrenMobile())), window.document.body),
            React.createElement("div", { className: "e-action-popover-mobile" },
                React.createElement("div", { className: "e-action-popover-mobile-button" }, this.getMobileActionButton()))));
    }
    render() {
        if (this.getVisibleMenuItems().length === 0) {
            return null;
        }
        if (this.props.isDeviceLessThanSmall) {
            return this.renderMobile();
        }
        return this.renderDesktop();
    }
}
const mapStateToProps = (state, props) => ({
    ...props,
    isDeviceLessThanSmall: state.browser.lessThan.s,
});
export default connect(mapStateToProps)(XtremActionPopover);
//# sourceMappingURL=xtrem-action-popover.js.map