import Button from 'carbon-react/esm/components/button';
import Dialog from 'carbon-react/esm/components/dialog';
import Form from 'carbon-react/esm/components/form';
import Typography from 'carbon-react/esm/components/typography';
import React from 'react';
import { FiltersComponent } from './filter/filters-component';
import { getContextObjectType, getSelectedItemsFromProperties } from '../plugins/utils';
export function ConditionDialog({ conditionRequest, contextProvider, editorRef, locale, localize, localizeEnumMember, onClose, }) {
    const [filters, setFilters] = React.useState([]);
    const [properties, setProperties] = React.useState(null);
    // when conditional block button is clicked fetch & set relevant properties depending on the active context
    React.useEffect(() => {
        if (!conditionRequest) {
            return;
        }
        const contextObjectType = getContextObjectType(editorRef?.model.document.selection.getFirstPosition()?.parent);
        if (!contextObjectType || contextObjectType === '$root') {
            return;
        }
        const root = editorRef?.model.document.selection.getFirstRange()?.start.root.rootName || 'body';
        contextProvider.getObjectDetails(contextObjectType, root).then(setProperties);
    }, [conditionRequest, contextProvider, editorRef]);
    const isOpen = React.useMemo(() => Boolean(conditionRequest) && properties != null, [conditionRequest, properties]);
    const selectedItems = React.useMemo(() => getSelectedItemsFromProperties(properties), [properties]);
    const onConfirmed = React.useCallback(() => {
        if (conditionRequest?.onFinished) {
            conditionRequest?.onFinished(filters);
            onClose();
        }
    }, [conditionRequest, filters, onClose]);
    return (React.createElement(Dialog, { className: "document-editor-condition-dialog", onCancel: onClose, open: isOpen, size: "extra-large", title: localize('@sage/xtrem-document-editor/conditional-block-title', 'Conditional block') },
        React.createElement(Form, { stickyFooter: true, height: "500px", leftSideButtons: React.createElement(Button, { onClick: onClose }, localize('@sage/xtrem-document-editor/cancel', 'Cancel')), saveButton: React.createElement(Button, { buttonType: "primary", type: "button", onClick: onConfirmed }, localize('@sage/xtrem-document-editor/apply-button', 'Apply')) },
            React.createElement(Typography, null, localize('@sage/xtrem-document-editor/conditional-block-description', 'A new block will be inserted and its content will be displayed only if all the following conditions are satisfied.')),
            React.createElement(FiltersComponent, { contextProvider: contextProvider, filters: filters, locale: locale, localize: localize, localizeEnumMember: localizeEnumMember, objectType: conditionRequest?.objectType, onChange: setFilters, selectedItems: selectedItems }))));
}
//# sourceMappingURL=condition-dialog.js.map