import * as React from 'react';
import { connect } from 'react-redux';
import * as xtremRedux from '../redux';
import { DASHBOARD_SCREEN_ID, getWidgetsFromDashboardItems } from '../service/dashboard-service';
import Typography from 'carbon-react/esm/components/typography';
import localeText from './dashboard-strings';
import AsyncDragDropCanvasWrapper from './async-drag-drop-canvas-wrapper';
import Heading from 'carbon-react/esm/components/heading';
import Button from 'carbon-react/esm/components/button';
import { ActionPopover, ActionPopoverDivider, ActionPopoverItem } from 'carbon-react/esm/components/action-popover';
import { localize } from '../service/i18n-service';
import { ConnectedDashboardEditorDialog } from './dashboard-editor-dialog';
import { ConnectedDashboardSelectionTabs } from './dashboard-selection-tabs';
import { ConnectedDashboardCreateDialog } from './dashboard-create-dialog';
import { confirmationDialog } from '../service/dialog-service';
import { xtremConsole } from '../utils/console';
import { showToast } from '../service/toast-service';
import { DashboardPlaceholder } from './dashboard-placeholder';
export class DashboardComponent extends React.Component {
    constructor(props) {
        super(props);
        this.fetchDashboards = () => {
            if (!this.props.dashboardDefinition && this.props.hasInstalledPackagesLoaded && !this.state.startedFetching) {
                this.setState({ startedFetching: true }, this.props.fetchUserDashboardDefinition);
            }
        };
        this.onCreateDialogOpen = () => this.setState({ dialogMode: 'CREATE_DASHBOARD' });
        this.onCreateDialogClose = (success = false) => {
            this.setState({ dialogMode: 'NONE' });
            if (success) {
                this.props.openDashboardEditorDialog();
            }
        };
        this.onDeleteDashboard = async () => {
            if (this.props.dashboardDefinition) {
                try {
                    await confirmationDialog(DASHBOARD_SCREEN_ID, 'warn', localize('@sage/xtrem-ui/dashboard-delete-dashboard-dialog-title', 'Delete dashboard'), localize('@sage/xtrem-ui/dashboard-delete-dashboard-dialog-message', 'Are you sure you want to delete this dashboard?'));
                    try {
                        await this.props.deleteDashboard(String(this.props.dashboardDefinition._id));
                        showToast(localize('@sage/xtrem-ui/dashboard-deleted', 'Dashboard deleted.'), {
                            type: 'success',
                        });
                    }
                    catch (err) {
                        xtremConsole.error(err);
                        showToast(localize('@sage/xtrem-ui/dashboard-failed-to-delete', 'The dashboard could not be deleted.'), { type: 'error' });
                    }
                }
                catch {
                    // Do nothing
                }
            }
        };
        this.onDuplicateDashboard = async () => {
            if (this.props.dashboardDefinition) {
                try {
                    await this.props.cloneDashboard(String(this.props.dashboardDefinition._id));
                    showToast(localize('@sage/xtrem-ui/dashboard-duplicated', 'Dashboard duplicated.'), {
                        type: 'success',
                    });
                }
                catch (err) {
                    xtremConsole.error(err);
                    showToast(localize('@sage/xtrem-ui/dashboard-failed-to-duplicate', 'The dashboard could not be duplicated.'), { type: 'error' });
                }
            }
        };
        this.renderNoDashboards = () => {
            return (React.createElement("div", { className: "e-dashboard-empty", "data-testid": "e-dashboard-empty-no-dashboard" },
                React.createElement(Heading, { "data-testid": "e-dashboard-empty-no-dashboard-title", divider: false, title: localize('@sage/xtrem-ui/no-dashboard-title', 'Drive your business') }),
                React.createElement("div", { className: "e-dashboard-empty-center-wrapper" },
                    React.createElement("img", { width: 300, height: 300, src: "/images/dashboard-create.svg", alt: "Create dashboard logo" }),
                    React.createElement("div", { className: "e-dashboard-empty-right-wrapper" },
                        React.createElement(Heading, { "data-testid": "e-dashboard-empty-no-dashboard-heading", divider: false, title: localize('@sage/xtrem-ui/no-dashboard-heading', 'This page has no dashboard.') }),
                        React.createElement("span", { className: "e-dashboard-empty-right-subtitle", "data-testid": "e-dashboard-empty-no-dashboard-subtitle" }, localize('@sage/xtrem-ui/no-dashboard-subtitle', 'Create a dashboard to get started.')),
                        React.createElement(Button, { "data-testid": "e-dashboard-create", iconType: "plus", onClick: this.onCreateDialogOpen, buttonType: "primary" }, localize('@sage/xtrem-ui/dashboard-create-dashboard', 'Create dashboard'))))));
        };
        this.renderEmptyDashboard = () => {
            return (React.createElement("div", { className: "e-dashboard-empty", "data-testid": "e-dashboard-empty-no-widgets" },
                React.createElement("div", { className: "e-dashboard-empty-center-wrapper" },
                    React.createElement("img", { width: 300, height: 300, src: "/images/dashboard-create.svg", alt: "Create dashboard logo" }),
                    React.createElement("div", { className: "e-dashboard-empty-right-wrapper" },
                        React.createElement(Heading, { "data-testid": "e-dashboard-empty-no-widgets-heading", divider: false, title: localize('@sage/xtrem-ui/dashboard-empty-heading', 'This dashboard is empty.') }),
                        React.createElement("span", { className: "e-dashboard-empty-right-subtitle", "data-testid": "e-dashboard-empty-no-widgets-subtitle" }, localize('@sage/xtrem-ui/dashboard-empty-subtitle', 'Add a widget to customize your dashboard.')),
                        React.createElement(Button, { "data-testid": "e-dashboard-create", iconType: "plus", onClick: this.props.openDashboardEditorDialog, buttonType: "primary" }, localize('@sage/xtrem-ui/dashboard-add-widget', 'Add widget'))))));
        };
        this.renderKebabMenu = () => {
            if (!this.props.dashboardDefinition) {
                return null;
            }
            const destructiveIconClassName = {
                className: 'e-action-popover-item-destructive',
            };
            return (React.createElement(Typography, { variant: "h1", mt: 3, mr: 3, ml: 3, mb: 0 },
                React.createElement("span", { className: "e-dashboard-title", "data-testid": "e-dashboard-title" }, this.props.dashboardDefinition.title),
                React.createElement("span", { className: "e-dashboard-title-menu" },
                    React.createElement(ActionPopover, { "data-testid": "e-dashboard-actions" },
                        React.createElement(ActionPopoverItem, { icon: "edit", onClick: this.props.openDashboardEditorDialog, "data-testid": "e-dashboard-action-edit" }, localize('@sage/xtrem-ui/dashboard-edit', 'Edit')),
                        React.createElement(ActionPopoverItem, { icon: "duplicate", onClick: this.onDuplicateDashboard, "data-testid": "e-dashboard-action-duplication" }, localize('@sage/xtrem-ui/dashboard-duplicate', 'Duplicate')),
                        React.createElement(ActionPopoverItem, { icon: "plus_large", onClick: this.onCreateDialogOpen, "data-testid": "e-dashboard-action-create" }, localize('@sage/xtrem-ui/dashboard-create', 'Create')),
                        React.createElement(ActionPopoverDivider, null),
                        React.createElement(ActionPopoverItem, { icon: "delete", onClick: this.onDeleteDashboard, "data-testid": "e-dashboard-action-delete", ...destructiveIconClassName }, localize('@sage/xtrem-ui/dashboard-delete', 'Delete'))))));
        };
        this.getWidgets = () => {
            return this.props.dashboardDefinition
                ? getWidgetsFromDashboardItems(String(this.props.dashboardDefinition._id), this.props.dashboardDefinition.children, this.props.widgets)
                : [];
        };
        this.renderDashboard = () => {
            const widgets = this.getWidgets();
            const isLoading = !this.state.startedFetching || !this.state.verticalSpaceReady;
            const isEmptyDashboard = !isLoading &&
                !this.props.loadingDashboards &&
                !this.props.globalLoading &&
                this.state.verticalSpaceReady &&
                this.props.dashboardDefinition !== undefined &&
                widgets.length === 0;
            return (React.createElement(React.Fragment, null,
                !this.props.loadingDashboards && this.renderKebabMenu(),
                !this.props.loadingDashboards &&
                    (isEmptyDashboard ? (this.renderEmptyDashboard()) : (React.createElement(AsyncDragDropCanvasWrapper, { json: {
                            isHeaderHidden: true,
                            isEditMode: false,
                            locale: this.props.locale,
                            layout: {
                                cols: 12,
                                rowHeight: 120,
                                width: 1200,
                                isDraggable: false,
                            },
                            widgets,
                            stringLiterals: localeText(),
                        } }))),
                this.props.loadingDashboards && React.createElement(DashboardPlaceholder, null),
                React.createElement(ConnectedDashboardEditorDialog, null)));
        };
        this.state = {
            dialogMode: 'NONE',
            startedFetching: this.props.dashboardDefinition !== undefined,
            verticalSpaceReady: false,
        };
    }
    componentDidMount() {
        this.fetchDashboards();
        setTimeout(() => {
            this.setState({ verticalSpaceReady: true });
        }, 100);
    }
    componentDidUpdate() {
        this.fetchDashboards();
    }
    render() {
        const isLoading = !this.state.startedFetching || !this.state.verticalSpaceReady;
        const hasNoDashboards = !isLoading &&
            !this.props.loadingDashboards &&
            !this.props.globalLoading &&
            this.state.verticalSpaceReady &&
            this.props.dashboardDefinition === undefined;
        return (React.createElement("main", { className: "e-dashboard" },
            React.createElement(ConnectedDashboardSelectionTabs, { onCreateDialogOpen: this.onCreateDialogOpen }),
            hasNoDashboards && this.renderNoDashboards(),
            this.props.dashboardDefinition !== undefined &&
                this.state.verticalSpaceReady &&
                this.renderDashboard(),
            React.createElement(ConnectedDashboardCreateDialog, { isOpen: this.state.dialogMode === 'CREATE_DASHBOARD', onClose: this.onCreateDialogClose, onNextClicked: this.onCreateDialogClose })));
    }
}
const mapStateToProps = (state) => {
    const activeDashboard = Object.keys(state.dashboard.dashboards).find(d => state.dashboard.dashboards[d].isSelected);
    return {
        cloneDashboard: xtremRedux.actions.actionStub,
        dashboardDefinition: activeDashboard ? state.dashboard.dashboards[activeDashboard] : undefined,
        deleteDashboard: xtremRedux.actions.actionStub,
        fetchUserDashboardDefinition: xtremRedux.actions.actionStub,
        globalLoading: state.loading.globalLoading,
        hasInstalledPackagesLoaded: !!state.applicationPackages,
        loadingDashboards: state.loading.loadingDashboards,
        locale: (state.applicationContext?.locale || 'en-US'),
        openDashboardEditorDialog: xtremRedux.actions.actionStub,
        widgets: state.dashboard.widgets,
    };
};
const mapDispatchToProps = (dispatch) => {
    return {
        fetchUserDashboardDefinition: () => {
            dispatch(xtremRedux.actions.fetchUserDashboardDefinition());
        },
        cloneDashboard: (dashboardId) => dispatch(xtremRedux.actions.cloneDashboard(dashboardId)),
        deleteDashboard: (dashboardId) => dispatch(xtremRedux.actions.deleteDashboard(dashboardId)),
        openDashboardEditorDialog: () => {
            dispatch(xtremRedux.actions.openDashboardEditorDialog());
        },
    };
};
export const ConnectedDashboardComponent = connect(mapStateToProps, mapDispatchToProps)(DashboardComponent);
//# sourceMappingURL=dashboard-component.js.map