import { FilterTableComponent, GridColumn, GridRow } from '@sage/xtrem-ui-components';
import Typography from 'carbon-react/esm/components/typography';
import * as React from 'react';
import { connect } from 'react-redux';
import * as xtremRedux from '../../redux';
import { addTranslations } from '../../redux/actions/common-actions';
import { addEnumTypes } from '../../redux/actions/enum-types-actions';
import { buildEnumQuery } from '../../service/graphql-query-builder';
import * as graphqlService from '../../service/graphql-service';
import { executeGraphqlQuery } from '../../service/graphql-utils';
import { localize, localizeEnumMember } from '../../service/i18n-service';
import { carbonLocale } from '../../utils/carbon-locale';
import { getGutterSize } from '../../utils/responsive-utils';
import { isEqual } from 'lodash';
export function FilterStep({ stepIndex, browserIs, widgetDefinition, onWidgetDefinitionUpdated, locale, enumTypes, addEnumTypes: addEnumTypesToStore, addTranslations: addTranslationsToStore, nodeNames, }) {
    const { selectedProperties, node } = widgetDefinition;
    const gridGutter = getGutterSize(browserIs);
    React.useEffect(() => {
        if (!node) {
            return;
        }
        const nodesToFetch = Object.keys(selectedProperties ?? {})
            .map(key => selectedProperties?.[key]?.data?.node)
            .filter(Boolean);
        if (nodesToFetch.length === 0 ||
            nodesToFetch.map(n => n?.split('/')[2]).every(n => n && enumTypes[n] != null)) {
            return;
        }
        const query = nodesToFetch
            .filter(nodeName => !!nodeName)
            .map(nodeName => buildEnumQuery(nodeName))
            .reduce((optionsQuery, nextQuery) => ({ ...optionsQuery, ...nextQuery }), {});
        executeGraphqlQuery({ query }).then(response => {
            const enums = Object.keys(response.data)
                .filter(k => Object.keys(query).indexOf(k) !== -1)
                .reduce((currentValue, key) => {
                return { ...currentValue, [key]: response.data[key] };
            }, {});
            addEnumTypesToStore(enums);
            graphqlService
                .fetchEnumTranslations(Object.keys(enums), locale)
                .then(stringLiterals => addTranslationsToStore(locale, stringLiterals));
        });
    }, [selectedProperties, node, locale, addEnumTypesToStore, addTranslationsToStore, enumTypes]);
    const onFilterTableUpdate = React.useCallback((filters = []) => {
        const currentFilters = widgetDefinition.filters || [];
        if (!isEqual(currentFilters, filters)) {
            onWidgetDefinitionUpdated({ ...widgetDefinition, filters });
        }
    }, [onWidgetDefinitionUpdated, widgetDefinition]);
    return (React.createElement("div", null,
        React.createElement(Typography, { variant: "h2", "data-testid": "e-widget-editor-step-title" }, localize('@sage/xtrem-ui/widget-editor-filter-step-title', '{{stepIndex}}. Add your filters', {
            stepIndex,
        })),
        React.createElement("div", { className: "e-widget-editor-section" },
            React.createElement(GridRow, { columns: 8, gutter: gridGutter, margin: 0, verticalMargin: 0 },
                React.createElement(GridColumn, { columnSpan: 8 },
                    React.createElement(FilterTableComponent, { onChange: onFilterTableUpdate, carbonLocale: carbonLocale, locale: locale, localize: localize, localizeEnumMember: localizeEnumMember, node: widgetDefinition.node, nodeNames: nodeNames, selectedProperties: selectedProperties, value: widgetDefinition.filters || [] }))))));
}
const mapStateToProps = (state, props) => {
    return {
        ...props,
        browserIs: state.browser.is,
        locale: state.applicationContext?.locale || 'base',
        enumTypes: state.enumTypes,
        addEnumTypes: xtremRedux.actions.actionStub,
        addTranslations: xtremRedux.actions.actionStub,
    };
};
const mapDispatchToProps = (dispatch) => ({
    addEnumTypes: (enums) => {
        dispatch(addEnumTypes(enums));
    },
    addTranslations: (locale, stringLiterals) => {
        dispatch(addTranslations(locale, stringLiterals));
    },
});
export const ConnectedFilterStep = connect(mapStateToProps, mapDispatchToProps)(FilterStep);
//# sourceMappingURL=filters-step.js.map