import { getStore } from '../../redux';
import { DASHBOARD_SCREEN_ID } from '../../service/dashboard-service';
import { BaseDeveloperApi } from '../../service/screen-base';
export var WidgetCacheLifespan;
(function (WidgetCacheLifespan) {
    WidgetCacheLifespan[WidgetCacheLifespan["hour"] = 3600000] = "hour";
    WidgetCacheLifespan[WidgetCacheLifespan["day"] = 86400000] = "day";
    WidgetCacheLifespan[WidgetCacheLifespan["noCache"] = -1] = "noCache";
})(WidgetCacheLifespan || (WidgetCacheLifespan = {}));
export var WidgetType;
(function (WidgetType) {
    WidgetType["barChart"] = "barChart";
    WidgetType["gauge"] = "gauge";
    WidgetType["indicatorTile"] = "indicatorTile";
    WidgetType["lineChart"] = "lineChart";
    WidgetType["staticContent"] = "staticContent";
    WidgetType["table"] = "table";
    WidgetType["visualProcess"] = "visualProcess";
})(WidgetType || (WidgetType = {}));
export class WidgetDeveloperApi extends BaseDeveloperApi {
    constructor(parentWidget, widgetId, dashboardId) {
        super(DASHBOARD_SCREEN_ID);
        this.parentWidget = parentWidget;
        this.widgetId = widgetId;
        this.dashboardId = dashboardId;
    }
    get data() {
        if (this.parentWidget.constructor.prototype.__data) {
            return this.parentWidget.constructor.prototype.__data;
        }
        const state = getStore().getState();
        const widgetDefinition = state.dashboard.widgets[this.widgetId];
        return widgetDefinition?.data || null;
    }
    get settings() {
        const state = getStore().getState();
        // If the dashboard editor is open, we use the settings from the working copy of the dashboard editor
        const dashboardDefinition = state.dashboard.dashboardEditor.isOpen && state.dashboard.dashboardEditor.currentDashboardDefinition
            ? state.dashboard.dashboardEditor.currentDashboardDefinition
            : state.dashboard.dashboards?.[this.dashboardId];
        const widgetConfiguration = dashboardDefinition?.children?.find(c => String(c._id) === String(this.widgetId));
        return widgetConfiguration?.settings || {};
    }
    get options() {
        const state = getStore().getState();
        const widgetDefinition = state.dashboard.widgets[this.widgetId];
        return widgetDefinition.options || {};
    }
}
export class AbstractWidget {
    constructor() {
        const widgetId = this.constructor.prototype.__id;
        const dashboardId = this.constructor.prototype.__dashboardId;
        this._$ = new WidgetDeveloperApi(this, widgetId, dashboardId);
    }
    get $() {
        return this._$;
    }
}
//# sourceMappingURL=abstract-widget.js.map