import type { Constructible } from '../../types';
import type { AbstractWidget, AbstractWidgetDecorator } from './abstract-widget';
import type { WidgetValueOrCallback, WidgetValueOrCallbackWithId } from './widget-utils';
import type { RenderAsType, TableDataRow, ValueFormatType } from '@sage/bms-dashboard';
import type { Dict } from '@sage/xtrem-shared';
export interface WidgetDisplayOptions<W extends AbstractWidget> {
    colorVariant?: WidgetValueOrCallbackWithId<W, 'neutral' | 'negative' | 'positive' | 'warning'>;
    tooltipText?: WidgetValueOrCallbackWithId<W, string>;
}
export interface ColumnDefinitionOptions<W extends AbstractWidget> {
    title: string;
    onClick?: (this: W, _id: string) => void;
    displayOptions?: WidgetDisplayOptions<W>;
    renderedAs?: RenderAsType;
    valueFormat?: ValueFormatType;
    decimalDigits?: number;
}
export interface RowDefinition<W extends AbstractWidget> {
    title: ColumnDefinitionOptions<W>;
    titleRight?: ColumnDefinitionOptions<W>;
    line2?: ColumnDefinitionOptions<W>;
    line2Right?: ColumnDefinitionOptions<W>;
    line3?: ColumnDefinitionOptions<W>;
    line3Right?: ColumnDefinitionOptions<W>;
    image?: ColumnDefinitionOptions<W>;
    icon?: ColumnDefinitionOptions<W>;
    [key: string]: ColumnDefinitionOptions<W> | undefined;
}
export type TableDropDownOption = Dict<{
    title: string;
}>;
export type TableDropDownMenu = Dict<TableDropDownOption>;
export interface TableWidgetRow extends Omit<TableDataRow, 'i'> {
    _id: number | string;
}
export interface TableWidgetProperties<W extends AbstractWidget> extends AbstractWidgetDecorator<W> {
    content?: WidgetValueOrCallback<W, TableWidgetRow[]>;
    canSelect?: WidgetValueOrCallback<W, boolean>;
    displayMode?: WidgetValueOrCallback<W, 'card' | 'table'>;
    canSwitchViewMode?: WidgetValueOrCallback<W, boolean>;
    rowDefinition: WidgetValueOrCallback<W, RowDefinition<W>>;
    dataDropdownMenu?: WidgetValueOrCallback<W, TableDropDownMenu>;
}
/**
 * A widget that displays tabular data as a table or card view.
 */
export declare function table<W extends AbstractWidget>(properties: TableWidgetProperties<W>): (ctor: Constructible<AbstractWidget>) => void;
//# sourceMappingURL=table-widget-decorator.d.ts.map