"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FilterTableTypeColumn = void 0;
const react_1 = __importDefault(require("react"));
const filter_table_types_1 = require("./filter-table-types");
const xtrem_shared_1 = require("@sage/xtrem-shared");
const select_1 = require("carbon-react/esm/components/select");
const lodash_1 = require("lodash");
const box_1 = __importDefault(require("carbon-react/esm/components/box"));
const typography_1 = __importDefault(require("carbon-react/esm/components/typography"));
const isDateOrDateTimeProperty = (property) => property?.data?.type === 'Date' || property?.data?.type === 'DateTime';
function FilterTableTypeColumn({ isDisabled, localize, onCellChange, rowData, }) {
    if (rowData.property?.data?.type &&
        (0, lodash_1.includes)([xtrem_shared_1.GraphQLTypes.Boolean, xtrem_shared_1.GraphQLTypes.ID, xtrem_shared_1.GraphQLTypes.IntOrString, xtrem_shared_1.GraphQLTypes.IntReference], rowData.property.data.type)) {
        return (react_1.default.createElement("div", { "data-testid": `e-widget-editor-filter-type-${rowData._id}` },
            react_1.default.createElement(box_1.default, { display: "flex", alignItems: "center", justifyContent: "flex-start" },
                react_1.default.createElement(typography_1.default, { variant: "p", m: 0, paddingLeft: "8px" }, localize('@sage/xtrem-ui-components/equals', 'Equals')))));
    }
    return (react_1.default.createElement(select_1.FilterableSelect, { disabled: !rowData.property || isDisabled, openOnFocus: true, "data-testid": `e-widget-editor-filter-type-${rowData._id}`, onChange: ({ target: { value } }) => {
            onCellChange({
                columnId: 'filterType',
                rowId: rowData._id,
                value: value,
                rowData,
            });
        }, placeholder: localize('@sage/xtrem-ui-components/select-filter-type', 'Select filter type...'), size: "small", value: rowData.filterType ?? '' }, rowData.property?.data?.type !== undefined &&
        xtrem_shared_1.filterGraphqlMapping[rowData.property.data.type] !== undefined &&
        xtrem_shared_1.filterGraphqlMapping[rowData.property.data.type]
            ?.map((filterType) => {
            return (react_1.default.createElement(select_1.Option, { text: (0, filter_table_types_1.filterTranslations)(localize)[filterType] ?? '', value: filterType ?? '', key: filterType ?? '' }));
        })
            .concat(isDateOrDateTimeProperty(rowData.property)
            ? [
                react_1.default.createElement(select_1.Option, { text: (0, filter_table_types_1.filterTranslations)(localize).timeFrame, value: "timeFrame", key: "timeframe" }),
            ]
            : [])));
}
exports.FilterTableTypeColumn = FilterTableTypeColumn;
//# sourceMappingURL=filter-table-type-column.js.map