import React, { useState, useCallback } from 'react';
import { ExternalLinkConfirmationDialog } from '../component/external-link-confirmation/exterrnal-link-confirmation-dialog';
import { createPromise } from './create-promise';
import { useSkipExternalLinkConfirmation } from './use-local-storage';
export const useExternalLinkConfirmation = (locale, translations) => {
    const [confirmationResolver, setConfirmationResolver] = useState();
    const [isOpen, setOpen] = useState(false);
    const [isSkipExternalLinkConfirmation, setSkipExternalLinkConfirmation] = useSkipExternalLinkConfirmation();
    const storeSkipExternalLinkConfirmation = useCallback((isSkipConfirmationChecked) => {
        if (isSkipConfirmationChecked && !isSkipExternalLinkConfirmation) {
            setSkipExternalLinkConfirmation(true);
        }
    }, [isSkipExternalLinkConfirmation, setSkipExternalLinkConfirmation]);
    const getConfirmation = useCallback(async () => {
        setOpen(true);
        const [promise, resolver] = createPromise();
        setConfirmationResolver(resolver);
        return promise;
    }, [setConfirmationResolver]);
    const onCancel = useCallback(async (isSkipConfirmationChecked) => {
        storeSkipExternalLinkConfirmation(isSkipConfirmationChecked);
        setOpen(false);
        confirmationResolver?.reject();
    }, [storeSkipExternalLinkConfirmation, setOpen, confirmationResolver]);
    const onConfirm = useCallback(async (isSkipConfirmationChecked) => {
        storeSkipExternalLinkConfirmation(isSkipConfirmationChecked);
        setOpen(false);
        confirmationResolver?.resolve();
    }, [storeSkipExternalLinkConfirmation, setOpen, confirmationResolver]);
    const ConfirmationDialog = useCallback(() => {
        return isSkipExternalLinkConfirmation ? null : (React.createElement(ExternalLinkConfirmationDialog, { isOpen: isOpen, locale: locale, onCancel: onCancel, onConfirm: onConfirm, translations: translations }));
    }, [isSkipExternalLinkConfirmation, isOpen, locale, onCancel, onConfirm, translations]);
    return [getConfirmation, ConfirmationDialog];
};
//# sourceMappingURL=use-external-link-confirmation.js.map