/// <reference types="node" />
import { Dict } from '@sage/xtrem-core';
import { Cluster, Worker } from 'cluster';
export declare class XtremWorker {
    #private;
    readonly workerId: string;
    readonly cluster: Cluster;
    promise: Promise<void>;
    /**
     *
     * @param workerId the identifier of the worker
     * @param cluster the cluster instance used to manage(fork/spawn) a worker
     */
    constructor(workerId: string, cluster: Cluster);
    init(): this;
    /**
     * reset the current worker instance with newly forked one.
     */
    fork(): void;
    /**
     * The current Worker instance that is alive
     */
    get worker(): Worker;
    /**
     * The index of the worker in the cluster instance workers dictionary
     */
    get index(): number;
    /**
     * Is the worker ready to use, this set when the worker process sends a message back to the main process with the port
     */
    get isReady(): boolean;
    /**
     * Is the worker set and is the worker alive
     */
    get workerExists(): boolean;
    /**
     * Port of the current worker
     */
    get port(): number;
    static workers: Dict<XtremWorker[]>;
    static counters: Dict<number>;
    /**
     * Add a worker to the workers list
     * @param cluster
     * @param startIndex
     * @param stopIndex
     */
    static addWorkers(cluster: Cluster, requestSource: string, startIndex: number, stopIndex: number): void;
    /**
     * Initialize the list of workers
     * @param cluster
     * @param maxWorkers
     */
    static initializeWorkers(cluster: Cluster, requestSource: string, maxWorkers?: number): void;
    /**
     * sleep for the supplied number of ms
     */
    static sleep(ms: number): Promise<void>;
    /**
     * Get the next worker that is ready from the workers list
     * @param cluster
     * @param requestSource
     * @param count
     * @returns
     */
    static getNextWorker(cluster: Cluster, requestSource: string): Promise<XtremWorker | undefined>;
}
//# sourceMappingURL=worker.d.ts.map