import { ServiceOption } from '../service-option';
import { AnyValue, AsyncResponse } from '../set-sort-values';
import { type Dict } from '../util';
declare const columnTypeNames: readonly ["boolean", "enum", "short", "integer", "reference", "integerRange", "decimalRange", "date", "dateRange", "datetimeRange", "time", "datetime", "float", "decimal", "double", "binaryStream", "textStream", "string", "uuid", "byte", "binary", "json", "integerArray", "enumArray", "referenceArray", "stringArray"];
export type ColumnTypeName = (typeof columnTypeNames)[number];
export declare function isColumnTypeName(name: string | undefined): boolean;
export declare enum ValidationSeverity {
    test = 0,
    info = 1,
    warn = 2,
    error = 3,
    exception = 4
}
export interface ValidationContextInterface {
    path: string[];
    addDiagnose(severity: ValidationSeverity, message: string): void;
}
export interface Context {
    localizeEnumMember(enumName: string, memberName: string): string;
}
export interface DataTypeOptions {
    serviceOptions?: () => ServiceOption[];
}
export type DataTypeLocalize<TitleT> = (localizationKey: string, name: string) => TitleT;
export interface FieldBinding<TitleT> {
    bind: string;
    title?: TitleT;
    type?: string;
    enumType?: string | null;
}
export interface DataTypeMetadata<TitleT> {
    name: string;
    title: TitleT;
    type: string;
    isDefault: boolean;
}
export interface MetaDataOptions<TitleT, ApplicationT extends any, ContextT extends any> {
    localize: DataTypeLocalize<TitleT>;
    application: ApplicationT;
    context?: ContextT;
}
export declare abstract class DataType<ValT extends AnyValue, T, OptionsT extends DataTypeOptions = DataTypeOptions> {
    readonly type: ColumnTypeName;
    protected readonly options: OptionsT;
    name?: string;
    pack?: string;
    constructor(type: ColumnTypeName, options: OptionsT);
    get serviceOptions(): ServiceOption[];
    defaultValue<FullT extends T>(_node: FullT): AsyncResponse<ValT | undefined>;
    controlValue<FullT extends T>(_node: FullT, _cx: ValidationContextInterface, _val: any): AsyncResponse<void>;
    adaptValue<FullT extends T>(_node: FullT, _val: ValT): AsyncResponse<ValT>;
    dataTypeOptions(): OptionsT;
    getLocalizedTitleKey(): string;
    getMetaData<TitleT extends string | Dict<string>>(options: MetaDataOptions<TitleT, any, any>): DataTypeMetadata<TitleT>;
}
export declare const MAX_INT_32: number;
export declare const MIN_INT_32: number;
export declare const isInt32: (val: any) => boolean;
export {};
//# sourceMappingURL=data-type.d.ts.map