"use strict";
/* eslint-disable @typescript-eslint/no-unused-vars */
/* eslint-disable class-methods-use-this */
Object.defineProperty(exports, "__esModule", { value: true });
exports.isInt32 = exports.MIN_INT_32 = exports.MAX_INT_32 = exports.DataType = exports.ValidationSeverity = exports.isColumnTypeName = void 0;
const _ = require("lodash");
const columnTypeNames = [
    'boolean',
    'enum',
    'short',
    'integer',
    'reference',
    'integerRange',
    'decimalRange',
    'date',
    'dateRange',
    'datetimeRange',
    'time',
    'datetime',
    'float',
    'decimal',
    'double',
    'binaryStream',
    'textStream',
    'string',
    'uuid',
    'byte',
    'binary',
    'json',
    'integerArray',
    'enumArray',
    'referenceArray',
    'stringArray',
];
function isColumnTypeName(name) {
    return columnTypeNames.includes(name);
}
exports.isColumnTypeName = isColumnTypeName;
var ValidationSeverity;
(function (ValidationSeverity) {
    ValidationSeverity[ValidationSeverity["test"] = 0] = "test";
    ValidationSeverity[ValidationSeverity["info"] = 1] = "info";
    ValidationSeverity[ValidationSeverity["warn"] = 2] = "warn";
    ValidationSeverity[ValidationSeverity["error"] = 3] = "error";
    ValidationSeverity[ValidationSeverity["exception"] = 4] = "exception";
})(ValidationSeverity || (exports.ValidationSeverity = ValidationSeverity = {}));
class DataType {
    constructor(type, options) {
        this.type = type;
        this.options = options;
    }
    get serviceOptions() {
        return this.options.serviceOptions?.() || [];
    }
    defaultValue(_node) {
        return undefined;
    }
    controlValue(_node, _cx, _val) {
        return undefined;
    }
    adaptValue(_node, _val) {
        return _val;
    }
    dataTypeOptions() {
        return this.options;
    }
    getLocalizedTitleKey() {
        if (!this.name)
            throw new Error('Data type name is missing');
        if (!this.pack)
            throw new Error('Data type package name is missing');
        return `${this.pack}/data_types__${_.snakeCase(this.name).replace(/[.-]/g, '_')}__name`;
    }
    getMetaData(options) {
        let title;
        try {
            title = options.localize(this.getLocalizedTitleKey(), this.name || '');
        }
        catch {
            title = this.name; // Fallback to name if localization is not available (should not happen in production)
        }
        return {
            name: this.name,
            title,
        };
    }
}
exports.DataType = DataType;
// GraphQL has a limit to use 32-bit max and min Integer:
exports.MAX_INT_32 = 2 ** 31 - 1;
exports.MIN_INT_32 = -(2 ** 31);
// eslint-disable-next-line no-bitwise
const isInt32 = (val) => {
    // eslint-disable-next-line no-bitwise
    return val === (val | 0);
};
exports.isInt32 = isInt32;
//# sourceMappingURL=data-type.js.map