"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StringArrayDataType = exports.StringDataType = void 0;
const data_type_1 = require("./data-type");
class StringDataType extends data_type_1.DataType {
    constructor(options) {
        super('string', options);
    }
    get maxLength() {
        return this.options.maxLength ?? Infinity;
    }
    get isLocalized() {
        return this.options.isLocalized ?? false;
    }
    async controlValue(node, cx, val) {
        await super.controlValue(node, cx, val);
        if (this.maxLength && val && !this.isLocalized && val.length > this.maxLength) {
            cx.addDiagnose(data_type_1.ValidationSeverity.error, `${val} exceeds the maximum length allowed for this field: ${this.maxLength} characters.`);
        }
    }
    adaptValue(_node, val) {
        let adaptedValue = val;
        if (!this.options.doNotTrim) {
            adaptedValue = adaptedValue?.trim();
        }
        if (this.options.truncate && adaptedValue && adaptedValue?.length > this.maxLength) {
            return `${adaptedValue?.substring(0, this.maxLength - 3)}...`;
        }
        return adaptedValue;
    }
    defaultValue(node) {
        return this.options.defaultValue ? this.options.defaultValue.call(node) : super.defaultValue(node);
    }
    getMetaData(options) {
        const commonDataTypeMetaData = super.getMetaData(options);
        return {
            ...commonDataTypeMetaData,
            type: 'string',
            isDefault: false,
            maxLength: this.maxLength === Infinity ? null : this.maxLength,
            isLocalized: this.isLocalized,
            doNotTrim: !!this.dataTypeOptions().doNotTrim,
            truncate: !!this.dataTypeOptions().truncate,
        };
    }
}
exports.StringDataType = StringDataType;
class StringArrayDataType extends data_type_1.DataType {
    constructor(options) {
        super('stringArray', options);
    }
    get maxLength() {
        return this.options.maxLength ?? Infinity;
    }
    async controlValue(node, cx, val) {
        await super.controlValue(node, cx, val);
        val.forEach(v => {
            if (this.maxLength && v && v.length > this.maxLength) {
                cx.addDiagnose(data_type_1.ValidationSeverity.error, `${v} exceeds the maximum length allowed for this field: ${this.maxLength} characters.`);
            }
        });
    }
    getMetaData(options) {
        const commonDataTypeMetaData = super.getMetaData(options);
        return {
            name: commonDataTypeMetaData.name,
            title: commonDataTypeMetaData.title,
            type: 'stringArray',
            isDefault: false,
            maxLength: this.maxLength,
            isLocalized: !!this.dataTypeOptions().isLocalized,
            doNotTrim: !!this.dataTypeOptions().doNotTrim,
            truncate: !!this.dataTypeOptions().truncate,
        };
    }
}
exports.StringArrayDataType = StringArrayDataType;
//# sourceMappingURL=string-data-type.js.map