import { AnyRecord, AnyValue, AsyncReader, AsyncResponse } from '@sage/xtrem-async-helper';
import { ColumnTypeName, DataType, DataTypeOptions, Dict, ServiceOption } from '@sage/xtrem-shared';
import { Context } from '../runtime/index';
import { Aggregate, AggregateGroup, Extend, Node, NodeQueryFilter, OrderBy, ValidationContext } from '../ts-api';
import { NodeSelector } from '../ts-api/node-select-types';
import { FilterTag, StaticThis, TypeName } from './decorator-utils';
import { PropertyFilterTag } from './property-decorators/base-property-decorator';
export interface NodeExternalQueryOptions<T extends Node> {
    filters: NodeQueryFilter<T>[];
    orderBy?: OrderBy<T>;
    first?: number;
    after?: string;
    last?: number;
    before?: string;
    locale?: string;
    forUpdate?: boolean;
    aggregate?: Aggregate;
    count?: boolean;
    /** The query expects a single record in the result */
    singleResultRequest?: boolean;
    /** Selector, for low level context.select(...) queries */
    selector?: NodeSelector<T>;
}
export type ExternalProperty = {
    name: string;
    type: TypeName;
    isStored?: boolean;
    columnName?: string;
    columnType?: ColumnTypeName;
    join?: any;
    node?: {
        new (): Node;
    };
    isLocalized?: boolean;
    isInherited?: boolean;
    isNullable?: boolean;
    isPublished?: boolean;
    provides?: PropertyFilterTag[];
    dataType?: DataType<AnyValue, unknown, DataTypeOptions>;
    getValue?: any;
    serviceOptions: ServiceOption[];
    isVital?: boolean;
    isMutable?: boolean;
    isVitalParent?: boolean;
};
export interface ExternalApplication {
    dir: string;
    name: string;
    getExternalFactory(nodeConstructor: StaticThis<Node>): ExternalFactory | undefined;
}
export interface ExternalPackage {
    packageName: string;
    dir: string;
}
export type ExternalFactory = {
    name: string;
    tableName?: string;
    isSharedByAllTenants?: boolean;
    baseFactory?: ExternalFactory;
    rootFactory?: ExternalFactory;
    externalStorageManager?: ExternalStorageManager<Node>;
    properties: ExternalProperty[];
    keyProperties: ExternalProperty[];
    package: ExternalPackage;
    application: ExternalApplication;
    nodeConstructor: typeof Node;
    serviceOptions: ServiceOption[];
    uniqueKeyProperties: string[][];
    parseNodeId: (val: string | number | undefined) => Dict<AnyValue>;
    isVitalChild: boolean;
};
export interface ExternalOrderByClause {
    path: string[];
    property: ExternalProperty;
    direction: -1 | 1;
    sql: string;
    columnAlias?: string;
    group?: AggregateGroup;
}
export interface ExternalPropertyAndValue {
    value: any;
    property: ExternalProperty;
}
export interface ExternalStorageManagerExtension<This extends Node = Node> {
}
export interface AnyRecordWithId extends AnyRecord {
    _id: string;
}
export interface ExternalStorageManager<This extends Node> {
    factory?: ExternalFactory;
    /** insert hook - not called if storage is 'sql'
     * Mandatory if persistency not handled by framework
     */
    insert?: (node: Extend<This>, cx: ValidationContext) => AsyncResponse<AnyRecordWithId>;
    /** update hook - not called if storage is 'sql'
     * Mandatory if persistency not handled by framework
     */
    update?: (node: Extend<This>, cx: ValidationContext) => AsyncResponse<AnyRecord[]>;
    /**
     *  delete hook - not called if storage is 'sql'
     * Mandatory if persistency not handled by framework
     */
    delete?: (node: Extend<This>, cx: ValidationContext) => AsyncResponse<number>;
    canCreate?: (canCreate: boolean) => boolean;
    canUpdate?: (canUpdate: boolean) => boolean;
    canDelete?: (canDelete: boolean) => boolean;
    canDeleteMany?: (canDeleteMany: boolean) => boolean;
    getAllowedAccessCodes?: (context: Context, tag: FilterTag, allowedAccessCodes: string[] | null) => AsyncResponse<string[] | null>;
    /**
     * query and read - hooks getRawReader in SqlQuery
     **/
    query?: (context: Context, options: NodeExternalQueryOptions<This>) => AsyncReader<any>;
    getCollectionJoin: (propertyName: string) => Dict<string | ((this: Extend<This>) => any)>;
    getReferenceJoin: (propertyName: string) => Dict<string | ((this: Extend<This>) => any)>;
    mapRecordIn?: (record: any) => any;
    mapAggregateRecordIn?: (record: any) => any;
    parseOrderBy(context: Context, orderBy: OrderBy<Node> | undefined): ExternalOrderByClause[];
    parseCursor(orderByClauses: ExternalOrderByClause[], value: string): ExternalPropertyAndValue[];
    getKeyValues(context: Context, values: any, options?: {
        allocateTransient: boolean;
    }): AnyRecord;
    getJoinValues(node: Extend<This>, data: any, propertyName: string): AsyncResponse<Dict<any>>;
    defaultOrderBy: OrderBy<Node>;
    skipValidation?: boolean;
    getId(context: Context, values: Dict<any>): string;
    isKeyPropertyTransient(propertyName: string, value: any): boolean;
    isReverseReferenceProperty(propertyName: string): boolean;
}
//# sourceMappingURL=external-storage-manager.d.ts.map