"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.updateContext = exports.serviceOptions = exports.nodes = exports.getSizingFromActivityCode = exports.enums = exports.datatypes = exports.allowedAccessCodes = void 0;
const xtrem_cli_1 = require("@sage/xtrem-cli");
const xtrem_core_1 = require("@sage/xtrem-core");
const xtrem_x3_syracuse_1 = require("@sage/xtrem-x3-syracuse");
const datatypes = require("./data-types");
exports.datatypes = datatypes;
const enums = require("./enums");
exports.enums = enums;
const nodes = require("./nodes");
exports.nodes = nodes;
const serviceOptions = require("./service-options");
exports.serviceOptions = serviceOptions;
const services = require("./services");
const services_1 = require("./services");
Object.defineProperty(exports, "allowedAccessCodes", { enumerable: true, get: function () { return services_1.allowedAccessCodes; } });
Object.defineProperty(exports, "getSizingFromActivityCode", { enumerable: true, get: function () { return services_1.getSizingFromActivityCode; } });
/**
 * Get the secret from the config
 * @returns
 */
function getSecret() {
    const { security } = (xtrem_core_1.ConfigManager.current || {});
    const { syracuse } = security || {};
    if (!syracuse.secret)
        throw new Error('xtrem.security.secret config value must be set');
    return syracuse.secret;
}
/**
 * Get the workerId from the request headers
 * For X3 we use the folder name passed in the header or the folder name in the config when we are in development mode
 * @param request
 * @returns
 */
function getRequestSource(request) {
    const base64 = request.headers['x-etna-config'];
    const x3Config = xtrem_core_1.ConfigManager.current.x3;
    if (!base64) {
        if (x3Config && x3Config.development && x3Config.development.folderName) {
            return x3Config.development.folderName;
        }
        throw new xtrem_core_1.SystemError('Missing folder name');
    }
    if (Array.isArray(base64)) {
        throw new xtrem_core_1.SystemError('multiple x-etna-config headers not allowed');
    }
    const secret = getSecret();
    const parsed = (0, xtrem_x3_syracuse_1.decrypt)(base64, secret);
    if (parsed.folderName) {
        return parsed.folderName;
    }
    throw new xtrem_core_1.SystemError('x-etna-config missing folder name');
}
function updateContext() {
    xtrem_core_1.Context.accessRightsManager = new services.XtremX3AccessRightsManager();
    xtrem_core_1.Context.localizationManager = new services.XtremX3LocalizationManager();
    xtrem_core_1.CoreHooks.createServiceOptionManager = application => new services.XtremX3ServiceOptionManager(application);
    xtrem_core_1.CoreHooks.sysManager = {
        getUserNode: () => nodes.SysUser,
    };
    xtrem_cli_1.CliHooks.startManager = {
        ...xtrem_cli_1.CliHooks.startManager,
        startGraphqlService: xtrem_x3_syracuse_1.startX3Service,
        startServices: () => Promise.resolve(),
        getRequestSource,
    };
    xtrem_core_1.CoreHooks.createPackageManager = application => new services_1.X3PackageManager(application);
}
exports.updateContext = updateContext;
updateContext();
//# sourceMappingURL=index.js.map