import { Logger } from '@sage/xtrem-log';
import { AnyValue, Dict } from '@sage/xtrem-shared';
import { AxiosResponse } from 'axios';
import { ExecutionPatchResult, ExecutionResult } from 'graphql';
import { Context } from '../runtime/context';
export declare const logger: Logger;
/** Options passed to the App constructor. */
export interface AppConstructOptions {
    /** The name of the app */
    name: string;
    /** The version of the app (semver) */
    version: string;
}
export interface AppInteropToken {
    tenantId: string;
    appName: string;
    scope: string;
    sourceUserEmail: string;
}
export interface GraphQlResponse<ResponseDataT = unknown, RequestDataT = {}> extends AxiosResponse<ResponseDataT, RequestDataT> {
}
export interface GraphQlRequestOptions {
    appName: string;
    scope: string;
    query: string;
    variables?: Dict<AnyValue>;
    config?: Dict<AnyValue>;
}
/**
 * Class for App artifacts
 *
 * An App artifact provides basic information about an "app" which which the current app is integrated.
 * This artifact is used in the definition of synchronization targets and notifications.
 */
export declare class App {
    /** Returns a bearer token for a tenant id (INSECURE) */
    static getBearerToken({ appName, tenantId, scope, sourceUserEmail, }: {
        appName: string;
        tenantId: string;
        scope: string;
        sourceUserEmail: string;
    }): string;
    static parseBearerToken(token: string): AppInteropToken;
    static getScopeUserEmail(scope: string): string;
    /**
     * Sends a GraphQL request to this app.
     * @param context the context which provides the tenant id and the user's email
     * @param options a { query, variables } object
     * @returns the GraphQl response
     */
    private static sendAnyGraphqlRequest;
    static sendGraphqlRequest<ResponseDataT>(context: Context, options: GraphQlRequestOptions): Promise<GraphQlResponse<ExecutionResult<ResponseDataT>>>;
    static sendStreamGraphqlRequest<FirstResultT, PatchResultT>(context: Context, options: GraphQlRequestOptions): Promise<GraphQlResponse<AsyncGenerator<ExecutionResult<FirstResultT> | ExecutionPatchResult<PatchResultT>>>>;
}
//# sourceMappingURL=app.d.ts.map