import { AnyRecord, AnyValue, AsyncResponse } from '@sage/xtrem-async-helper';
import { ColumnTypeName, Dict } from '@sage/xtrem-shared';
import { Package } from '../application';
import { CollectionPropertyDecorator, CollectionPropertyOverrideDecorator, ReferenceArrayPropertyDecorator, ReferencePropertyDecorator, ReferencePropertyOverrideDecorator, TypeName } from '../decorators';
import { NodeFactory } from '../runtime/node-factory';
import { Node, NodeQueryFilter, ValidationContext } from '../ts-api';
import { Property } from './property';
export declare abstract class ForeignNodeProperty extends Property {
    #private;
    protected _decorator: ReferencePropertyDecorator | CollectionPropertyDecorator;
    constructor(factory: NodeFactory, _decorator: ReferencePropertyDecorator | CollectionPropertyDecorator, definingPackage: Package);
    abstract get join(): any;
    get decorator(): ReferencePropertyDecorator | CollectionPropertyDecorator;
    verify(): void;
    needsJoin(): boolean;
    verifyJoin(): void;
    get reverseReference(): string | undefined;
    get isVital(): boolean;
    get isMutable(): boolean;
    get targetFactory(): NodeFactory;
    get node(): any;
    overrideAttributes(extension: ReferencePropertyOverrideDecorator | CollectionPropertyOverrideDecorator): void;
}
export declare class ReferenceProperty extends ForeignNodeProperty {
    #private;
    protected _decorator: ReferencePropertyDecorator;
    private _isSelfReference;
    constructor(factory: NodeFactory, _decorator: ReferencePropertyDecorator, definingPackage: Package);
    get isVitalParent(): boolean;
    get canLookup(): boolean;
    get isSelfReference(): boolean;
    get isRequired(): boolean;
    private verifyExternalStorage;
    /**
     * @returns `true` if this property is a reference that is not nullable or explicitly allowed in indexes
     * by the `allowedInUniqueIndex` attribute and that is not a self reference
     */
    get isHardDependency(): boolean;
    get isToposortDependency(): boolean;
    get ignoreIsActive(): boolean | ((this: Node) => AsyncResponse<boolean>) | undefined;
    verifyDelegatedToProperty(toProperty: Property): void;
    verify(): void;
    get join(): any;
    get columnType(): ColumnTypeName | undefined;
    get filters(): any;
    isValueTypeValid(value: AnyValue): boolean;
    getTargetIsActivePropertyName(): string | undefined;
    addExtension(extension: ReferencePropertyOverrideDecorator): void;
    overrideAttributes(extension: ReferencePropertyOverrideDecorator): void;
}
export declare class JsonReferenceProperty extends ReferenceProperty {
    protected _decorator: ReferencePropertyDecorator;
    constructor(factory: NodeFactory, _decorator: ReferencePropertyDecorator, definingPackage: Package);
    get type(): TypeName;
    get columnType(): ColumnTypeName | undefined;
}
export declare class ReferenceArrayProperty extends ReferenceProperty {
    protected _decorator: ReferenceArrayPropertyDecorator;
    constructor(factory: NodeFactory, _decorator: ReferenceArrayPropertyDecorator, definingPackage: Package);
    get type(): TypeName;
    get columnType(): ColumnTypeName | undefined;
    isValueTypeValid(value: AnyValue): boolean;
    needsTypeConversion(value: AnyValue): boolean;
    mapInputValue(value: AnyValue): AnyValue;
}
export declare class CollectionProperty extends ForeignNodeProperty {
    protected _decorator: CollectionPropertyDecorator;
    private _controlBegin?;
    private _controlEnd?;
    private _saveBegin?;
    private _saveEnd?;
    constructor(factory: NodeFactory, _decorator: CollectionPropertyDecorator, definingPackage: Package);
    get decorator(): CollectionPropertyDecorator;
    verify(): void;
    addExtension(extension: CollectionPropertyOverrideDecorator): void;
    overrideAttributes(extension: CollectionPropertyOverrideDecorator): void;
    private verifyExternalStorage;
    get join(): Dict<JoinMember> | undefined;
    get orderBy(): AnyRecord | undefined;
    get controlBegin(): ((this: Node, cx: ValidationContext) => AsyncResponse<void>) | undefined;
    set controlBegin(controlBegin: ((this: Node, cx: ValidationContext) => AsyncResponse<void>) | undefined);
    get controlEnd(): ((this: Node, cx: ValidationContext) => AsyncResponse<void>) | undefined;
    set controlEnd(controlEnd: ((this: Node, cx: ValidationContext) => AsyncResponse<void>) | undefined);
    get saveBegin(): ((this: Node) => void) | undefined;
    set saveBegin(saveBegin: ((this: Node) => void) | undefined);
    get saveEnd(): ((this: Node) => void) | undefined;
    set saveEnd(saveEnd: ((this: Node) => void) | undefined);
    get getFilter(): ((this: Node) => AsyncResponse<NodeQueryFilter<Node>>) | undefined;
    needsJoin(): boolean;
    isValueTypeValid(value: AnyValue): boolean;
}
//# sourceMappingURL=foreign-node-property.d.ts.map