"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildComputeValueNotCompliantWarning = void 0;
/**
 * @fileoverview Check property decorators
 * @author Sage
 */
const xtrem_ts_to_sql_1 = require("@sage/xtrem-ts-to-sql");
function buildComputeValueNotCompliantWarning(propertyName) {
    return `The function ${propertyName}.computeValue() can be parsed to SQL: rename it to getValue()`;
}
exports.buildComputeValueNotCompliantWarning = buildComputeValueNotCompliantWarning;
function getErrorWhenConverting(fn) {
    try {
        new xtrem_ts_to_sql_1.Converter({}).convertFunctionExpression(fn);
        return undefined;
    }
    catch (ex) {
        return ex;
    }
}
function checkComputeValueFunction(context, fnToTest) {
    // 'computeValue' functions should not be "ts-to-sql" compliant
    const propertyName = fnToTest.parent.parent.parent.parent.parent.key.name;
    const error = getErrorWhenConverting(fnToTest);
    if (error)
        return;
    context.report({
        node: fnToTest.parent,
        messageId: 'error',
        data: {
            error: buildComputeValueNotCompliantWarning(propertyName),
        },
        fix: (fixer) => {
            // fnToTest.parent.key is the name of the function
            return fixer.replaceText(fnToTest.parent.key, 'getValue');
        },
    });
}
const rule = {
    defaultOptions: [],
    meta: {
        type: 'problem',
        docs: {
            url: '',
            description: 'Check property decorators',
            recommended: 'recommended',
        },
        fixable: 'code',
        schema: [
        // fill in your schema
        ],
        messages: {
            error: '{{error}}',
        },
    },
    create(context) {
        // Retrieve all the property decorators
        const decoratorsSelector = 'PropertyDefinition > Decorator > CallExpression > ObjectExpression';
        return {
            [`${decoratorsSelector} > Property[key.name="computeValue"][value.type='FunctionExpression'] > FunctionExpression`](getValueFunction) {
                checkComputeValueFunction(context, getValueFunction);
            },
        };
    },
};
exports.default = rule;
//# sourceMappingURL=property-decorators-warnings.js.map