import { AnyValue, Context, ExternalFactory, ExternalProperty, TypeName } from '@sage/xtrem-core';
import { Dict } from '@sage/xtrem-shared';
import { GenericResolved, PropertyType } from '@sage/xtrem-ts-to-sql';
import { Pool } from '@sage/xtrem-x3-sql';
import { ConversionResult, SqlConverter } from './sql-converter';
type Resolved = GenericResolved<ExternalFactory, ExternalProperty>;
export declare const systemProperties: Dict<ExternalProperty>;
export declare const systemColumns: (string | undefined)[];
export declare class SqlResolver {
    static readonly denormalizedConcatenator = "  ,  ";
    static getX3Pool<T extends AnyValue>(context: Context): Pool<T>;
    private static getNumericAggregateValueType;
    private static getAggregateValueType;
    private static checkDateOrDatetimeType;
    private static castIfBoolean;
    static nullValue(context: Context, type: TypeName | undefined): string;
    /**
     * Get a dummy value for the specified type
     * @param context
     * @param type
     * @returns
     */
    static placeholderValue(context: Context, type: TypeName | undefined): string;
    /**
     * Get the column/scalar type of a property
     * @param object
     * @returns
     */
    static getType(object: ConversionResult): TypeName;
    /**
     * Get the column/scalar type of a property
     * @param object
     * @returns
     */
    static getPropertyType(property: ExternalProperty): TypeName;
    static orderByDirections(context?: any): {
        asc: string;
        desc: string;
    };
    static convertToConversionPair(context: Context, sql: string, type: TypeName | undefined, conversionPair: string[]): string;
    private static aggregateSql;
    static resolveAggregate(context: Context, object: ConversionResult, name: string): Resolved;
    static makeName30(name: string): string;
    static makeColumnAlias(sql: string, alias?: string): string;
    static resolveJson(object: ConversionResult, name: string): Resolved;
    static resolveRange(object: ConversionResult, name: string, type: PropertyType): Resolved;
    /**
     * Is the property a system property
     * @param propertyName
     * @returns
     */
    static isSystemOrTechnicalColumn(propertyName: string): boolean;
    static findProperty(factory: ExternalFactory, propertyName: string): ExternalProperty | undefined;
    static resolve(sqlConverter: SqlConverter, context: Context, object: ConversionResult, name: string): Resolved;
    private static propertyColumnSql;
    private static constructSql;
    private static getFieldName;
}
export {};
//# sourceMappingURL=sql-resolver.d.ts.map