"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.uselessFunctionV3 = exports.sum = exports.round = exports.min = exports.max = exports.pow = exports.floor = exports.ceil = exports.abs = exports.plus = exports.negated = exports.gte = exports.gt = exports.lte = exports.lt = exports.strictNe = exports.ne = exports.strictEq = exports.eq = exports.compare = exports.div = exports.mul = exports.sub = exports.add = exports.decimal = exports.Decimal = void 0;
/* eslint-disable no-console */
/**
Use http://mikemcl.github.io/decimal.js/
https://github.com/MikeMcl/decimal.js
*/
const decimal_js_1 = require("decimal.js");
class Decimal extends decimal_js_1.Decimal {
    static make(v) {
        return new Decimal(v);
    }
    static toNumber(v) {
        return typeof v === 'number' ? v : v == null ? NaN : v.toNumber();
    }
}
exports.Decimal = Decimal;
const valueIsANumber = (value) => typeof value === 'number';
const valueIsNotANumber = (value) => typeof value !== 'number';
function decimal(s) {
    return new Decimal(s);
}
exports.decimal = decimal;
function add(a, b) {
    // Allow string promotion for concatenation
    return (Number.isInteger(a) && Number.isInteger(b)) || typeof a === 'string' || typeof b === 'string'
        ? a + b
        : Decimal.add(a, b);
}
exports.add = add;
function sub(a, b) {
    return Number.isInteger(a) && Number.isInteger(b) ? a - b : Decimal.sub(a, b);
}
exports.sub = sub;
function mul(a, b) {
    return Number.isInteger(a) && Number.isInteger(b) ? a * b : Decimal.mul(a, b);
}
exports.mul = mul;
function div(a, b) {
    return Number.isInteger(a) && Number.isInteger(b) ? a / b : Decimal.div(a, b);
}
exports.div = div;
function toDecimal(a) {
    if (Decimal.isDecimal(a))
        return a;
    if (valueIsANumber(a))
        return new Decimal(a);
    return undefined;
}
// const compare = operation('comparedTo');
function compare(a, b) {
    if (a === b)
        return 0;
    // LATER: we should review the comparision with null to be aligned with the SQL behavior
    // // comparing undefined is always false
    // if (a === undefined || b === undefined) return undefined;
    // // everything is greater than null but any other comparison is false
    // if (a === null) return -1;
    // if (b === null) return 1;
    // To prevent from prototype pollution (https://portswigger.net/web-security/prototype-pollution, https://learn.snyk.io/lesson/prototype-pollution/),
    // some objects may have been created with a null prototype using Object.create(null),
    // those objects cannot be converted to a primitive type and thus are not comparable to anything
    if (a != null && typeof a === 'object' && (Object.getPrototypeOf(a) == null || Array.isArray(a)))
        return undefined;
    if (b != null && typeof b === 'object' && (Object.getPrototypeOf(b) == null || Array.isArray(b)))
        return undefined;
    const decimalA = toDecimal(a);
    const decimalB = toDecimal(b);
    if (decimalA && decimalB)
        return decimalA.comparedTo(decimalB);
    if (a < b)
        return -1;
    if (a > b)
        return 1;
    return undefined;
}
exports.compare = compare;
function sameTypes(a, b) {
    return (typeof a === typeof b ||
        ((valueIsANumber(a) || Decimal.isDecimal(a)) && (valueIsANumber(b) || Decimal.isDecimal(b))));
}
function eq(a, b) {
    // eslint-disable-next-line eqeqeq
    return a == b || compare(a, b) === 0;
}
exports.eq = eq;
function strictEq(a, b) {
    return a === b || (sameTypes(a, b) && eq(a, b));
}
exports.strictEq = strictEq;
function ne(a, b) {
    return !eq(a, b);
}
exports.ne = ne;
function strictNe(a, b) {
    return !strictEq(a, b);
}
exports.strictNe = strictNe;
function lt(a, b) {
    try {
        return compare(a, b) === -1;
    }
    catch (e) {
        console.error(`lt(${a} (${typeof a}) ${b} (${typeof b})) => ${e.message}`);
    }
    return false;
}
exports.lt = lt;
function lte(a, b) {
    try {
        const cmp = compare(a, b);
        return cmp !== undefined && cmp <= 0;
    }
    catch (e) {
        console.error(`lte(${a} (${typeof a}) ${b} (${typeof b})) => ${e.message}`);
    }
    return false;
}
exports.lte = lte;
function gt(a, b) {
    try {
        return compare(a, b) === 1;
    }
    catch (e) {
        console.error(`gt(${a} (${typeof a}) ${b} (${typeof b})) => ${e.message}`);
    }
    return false;
}
exports.gt = gt;
function gte(a, b) {
    try {
        const cmp = compare(a, b);
        return cmp !== undefined && cmp >= 0;
    }
    catch (e) {
        console.error(`gte(${a} (${typeof a}) ${b} (${typeof b})) => ${e.message}`);
    }
    return false;
}
exports.gte = gte;
function negated(a) {
    if (valueIsANumber(a))
        return -a;
    return ((Decimal.isDecimal(a) && a) || new Decimal(a)).negated();
}
exports.negated = negated;
function plus(a) {
    return typeof a === 'string' ? new Decimal(a) : a;
}
exports.plus = plus;
function abs(value) {
    return valueIsANumber(value) ? Math.abs(value) : Decimal.abs(value);
}
exports.abs = abs;
function ceil(value) {
    return valueIsANumber(value) ? Math.ceil(value) : Decimal.ceil(value).toNumber();
}
exports.ceil = ceil;
function floor(value) {
    return valueIsANumber(value) ? Math.floor(value) : Decimal.floor(value).toNumber();
}
exports.floor = floor;
function pow(base, exponent) {
    return valueIsANumber(base) && valueIsANumber(exponent) ? base ** exponent : Decimal.pow(base, exponent);
}
exports.pow = pow;
function max(...values) {
    return values.find(valueIsNotANumber) ? Decimal.max(...values) : Math.max(...values);
}
exports.max = max;
function min(...values) {
    return values.find(valueIsNotANumber) ? Decimal.min(...values) : Math.min(...values);
}
exports.min = min;
function round(value) {
    return valueIsANumber(value) ? Math.round(value) : Decimal.round(value).toNumber();
}
exports.round = round;
function sum(...values) {
    return values.find(valueIsNotANumber)
        ? Decimal.sum(...values)
        : values.reduce((prevValue, currentValue) => prevValue + currentValue, 0);
}
exports.sum = sum;
function uselessFunctionV3() { }
exports.uselessFunctionV3 = uselessFunctionV3;
//# sourceMappingURL=types-lib.js.map