// From file: /home/vsts/work/1/s/platform/back-end/xtrem-ts-to-sql/build/index.d.ts
declare module '@sage/xtrem-ts-to-sql/index' {
	export * from '@sage/xtrem-ts-to-sql/lib/converter';
	//# sourceMappingURL=index.d.ts.map
}
// From file: /home/vsts/work/1/s/platform/back-end/xtrem-ts-to-sql/build/lib/converter.d.ts
declare module '@sage/xtrem-ts-to-sql/lib/converter' {
	import { AnyValue, AsyncResponse, LoggerInterface, ServiceOption } from '@sage/xtrem-shared';
	import * as estree from 'estree';
	export function setLogger(logger?: LoggerInterface): void;
	export class ConversionError extends Error {
	    readonly node: estree.BaseNode;
	    constructor(node: estree.BaseNode, message: string);
	}
	export function quote(s: string): string;
	/**
	 * Convert numeric value `val` to a SQL string.
	 * Throws an error if `val` is not a valid number.
	 */
	export function sqlNumber<FactoryT extends ConverterFactory, PropertyT extends ConverterProperty>(slot: GenericConversionResult<FactoryT, PropertyT>, val: AnyValue): string;
	export function getColumnName(s: string): string;
	export const tableName: typeof getColumnName;
	export type PropertyType = 'boolean' | 'enum' | 'enumArray' | 'short' | 'byte' | 'integer' | 'integerRange' | 'integerArray' | 'decimalRange' | 'decimal' | 'float' | 'double' | 'string' | 'stringArray' | 'date' | 'dateRange' | 'datetimeRange' | 'time' | 'binaryStream' | 'binary' | 'textStream' | 'uuid' | 'datetime' | 'boolean' | 'json' | 'reference' | 'referenceArray' | 'collection' | 'instance' | 'jsonReference';
	export interface ConverterFactory {
	    name: string;
	    table?: {
	        sqlTableName: string;
	    };
	    isSharedByAllTenants?: boolean;
	    baseFactory?: this;
	    tableName?: string;
	}
	export type ConverterProperty = {
	    name: string;
	    type: PropertyType;
	    isNullable?: boolean;
	    isLocalized?: boolean;
	    serviceOptions?: ServiceOption[];
	};
	export interface Alias {
	    tableName: string;
	    alias: string;
	    join?: Join;
	}
	export interface GenericResolved<FactoryT extends ConverterFactory, PropertyT extends ConverterProperty> {
	    parent?: GenericConversionResult<FactoryT, PropertyT>;
	    type?: PropertyType;
	    isNullable?: boolean;
	    factory?: FactoryT;
	    property?: PropertyT;
	    targetFactory?: FactoryT;
	    tableName?: string;
	    reverseReferenceName?: string;
	    isInherited?: boolean;
	    aggregationOperator?: string;
	    sql: string;
	    columnAlias?: string;
	    aliases?: Alias[];
	}
	export interface JoinComponent {
	    alias: string;
	    columnOrValue: string[];
	}
	export interface Join {
	    left: JoinComponent;
	    right: JoinComponent;
	    condition: string;
	    isNullable: boolean;
	}
	export interface GenericConversionResult<FactoryT extends ConverterFactory, PropertyT extends ConverterProperty> extends GenericResolved<FactoryT, PropertyT> {
	    sql: string;
	    path?: string;
	    alias?: string;
	    join?: Join;
	    isNullable?: boolean;
	    collation?: string;
	}
	export interface CastOptions<PropertyT extends ConverterProperty> {
	    type?: PropertyType;
	    property?: PropertyT;
	}
	export interface Resolver<ContextT, FactoryT extends ConverterFactory, PropertyT extends ConverterProperty> {
	    resolveColumnName: (cx: ContextT, object: GenericConversionResult<FactoryT, PropertyT>, propertyName: string) => GenericResolved<FactoryT, PropertyT>;
	    resolveTableName: (name: string) => string;
	    resolveLiteral: (value: AnyValue) => string;
	}
	export class BasicResolver<ContextT, FactoryT extends ConverterFactory, PropertyT extends ConverterProperty> implements Resolver<ContextT, FactoryT, PropertyT> {
	    resolveColumnName(cx: ContextT, object: GenericConversionResult<FactoryT, PropertyT>, propertyName: string): GenericResolved<FactoryT, PropertyT>;
	    resolveTableName(name: string): string;
	    resolveLiteral(value: AnyValue): string;
	}
	export class Converter<ContextT, FactoryT extends ConverterFactory, PropertyT extends ConverterProperty> {
	    protected context: ContextT;
	    protected rootFactory: FactoryT;
	    protected resolver: Resolver<ContextT, FactoryT, PropertyT>;
	    constructor(context: ContextT, rootFactory?: FactoryT, resolver?: Resolver<ContextT, FactoryT, PropertyT>);
	    protected get scopeAlias(): Alias;
	    protected set scopeAlias(alias: Alias);
	    private didScopeAliasChange;
	    get results(): Map<string, GenericConversionResult<FactoryT, PropertyT>>;
	    get aliases(): Alias[];
	    get parameters(): Map<string, GenericConversionResult<FactoryT, PropertyT>>;
	    aliasIndex: number;
	    readonly allTableNames: string[];
	    private readonly joins;
	    private readonly thisResults;
	    private pushAlias;
	    private static createJoin;
	    protected createCollectionJoin(resolved: GenericConversionResult<FactoryT, PropertyT>, reverseResolved: GenericConversionResult<FactoryT, PropertyT> | null): void;
	    protected createReferenceJoin(resolved: GenericConversionResult<FactoryT, PropertyT>, reverseResolved: GenericConversionResult<FactoryT, PropertyT> | null): void;
	    makeAliasAndJoin(resolved: GenericConversionResult<FactoryT, PropertyT>): void;
	    protected walk(object: GenericConversionResult<FactoryT, PropertyT>, name: string, overrides?: {
	        targetFactory?: FactoryT;
	        tableName?: string;
	    }): GenericConversionResult<FactoryT, PropertyT>;
	    private static formatJoins;
	    getTableAliases(): string;
	    protected withSubQueryScope<T extends {}>(body: () => T, getJoinCondition?: () => string): T & {
	        aliases: string;
	        joinCondition: string;
	    };
	    private pushAliasAndJoin;
	    private walkToSuper;
	    cast(result: GenericConversionResult<FactoryT, PropertyT>, options: CastOptions<PropertyT>): GenericConversionResult<FactoryT, PropertyT>;
	    booleanResult(sql: string): GenericConversionResult<FactoryT, PropertyT>;
	    stringResult(sql: string): GenericConversionResult<FactoryT, PropertyT>;
	    convertThisExpression(isMemberOf?: boolean): GenericConversionResult<FactoryT, PropertyT>;
	    withThisResultScope<T>(result: GenericConversionResult<FactoryT, PropertyT>, body: () => T): T;
	    private convertStringMember;
	    private convertMemberExpression;
	    private convertChainExpression;
	    private convertToCommonType;
	    private convertConditionalExpression;
	    private convertNullEqualityExpression;
	    protected convertBinaryExpression(expression: estree.BinaryExpression): GenericConversionResult<FactoryT, PropertyT>;
	    private convertLogicalExpression;
	    private convertUnaryExpression;
	    protected concat(strings: string[]): string;
	    private convertTemplateLiteral;
	    convertTemplateElementString(str: string): string;
	    convertTemplateElement(expression: estree.TemplateElement): GenericConversionResult<FactoryT, PropertyT>;
	    convertLiteral(value: AnyValue | RegExp | bigint): GenericConversionResult<FactoryT, PropertyT>;
	    /**
	     * Converts an item of an object (see convertObject) a:'aaa' -> "a = 'aaa'" / c:d -> "c = t0.d"
	     */
	    private convertProperty;
	    /**
	     * Converts an object {a:'aaa', b:'bbb', c:d} into sth like "a='aaa', b='bbb', c=t0.d"
	     * Can be used for update ... set ... operations
	     */
	    private convertObject;
	    /**
	     * Mapping of typesLib.* functions to "classic" expressions
	     * For instance, typesLib.strictEq(a, b) will be mapped to a === b
	     */
	    private static mapTypesLibCallExpression;
	    protected getConfigurationValue(name: string): string;
	    private convertIdentifier;
	    private convertQuantifiedExpression;
	    private convertArrayIncludesCall;
	    private convertMathMethodCall;
	    private convertRegExpTestExpression;
	    private convertDateCallExpression;
	    private convertConfigurationValueCallExpression;
	    private convertStringMethodCall;
	    private convertMethodCall;
	    private convertCallExpression;
	    private convertTSNonNullExpression;
	    private convertAwaitExpression;
	    convertExpression(expression: estree.BaseExpression, isMemberOf?: boolean): GenericConversionResult<FactoryT, PropertyT>;
	    private static join;
	    static and(clauses: (string | undefined)[]): string;
	    static or(clauses: (string | undefined)[]): string;
	    convertFunctionExpression(expression: estree.FunctionExpression | estree.ArrowFunctionExpression): string;
	    convertArrowFunctionExpression(expression: estree.ArrowFunctionExpression): string;
	    convertFunction(fn: () => AsyncResponse<AnyValue>): string;
	}
	//# sourceMappingURL=converter.d.ts.map
}
declare module '@sage/xtrem-ts-to-sql' {
	export * from '@sage/xtrem-ts-to-sql/index';
}
