import { Command } from '@ckeditor/ckeditor5-core';
import { Position } from '@ckeditor/ckeditor5-engine';
import { getFilterObject } from '@sage/xtrem-filter-utils';
import { ATTR_CONTEXT_FILTER } from '@sage/xtrem-shared';
import { isNil } from 'lodash';
import { getContextObjectType } from '../utils';
import { getJsFilter } from './conditional-block-utils';
export default class InsertConditionalBlockCommand extends Command {
    get htmlCommentPlugin() {
        return this.editor.plugins.get('HtmlComment');
    }
    execute() {
        const selection = this.editor.model.document.selection;
        const contextObjectType = getContextObjectType(selection.focus?.parent);
        if (!contextObjectType) {
            return;
        }
        const reportEditorConfig = this.editor.config.get('reportEditorConfig');
        const conditionDialogRequest = {
            objectType: contextObjectType,
            existingCondition: {},
            onFinished: (condition) => {
                if (isNil(condition)) {
                    return;
                }
                this.editor.model.change(writer => {
                    const filters = condition.map(getJsFilter);
                    const jsCondition = filters.map(f => `(${f})`).join(' && ');
                    const conditionalBlockElement = writer.createElement('conditionalBlock', {
                        [ATTR_CONTEXT_FILTER]: JSON.stringify(getFilterObject(condition)),
                    });
                    const conditionalBlockBodyElement = writer.createElement('conditionalBlockBody');
                    const conditionalBlockFooterElement = writer.createElement('conditionalBlockFooter');
                    writer.append(conditionalBlockBodyElement, conditionalBlockElement);
                    writer.append(conditionalBlockFooterElement, conditionalBlockElement);
                    this.editor.model.insertObject(conditionalBlockElement);
                    this.htmlCommentPlugin.createHtmlComment(new Position(conditionalBlockElement.root, conditionalBlockFooterElement.getPath(), 'toNext'), '{{/if}}');
                    this.htmlCommentPlugin.createHtmlComment(new Position(conditionalBlockElement.root, conditionalBlockBodyElement.getPath(), 'toPrevious'), `{{#if ${jsCondition} }}`);
                });
            },
        };
        reportEditorConfig.onOpenConditionDialog(conditionDialogRequest);
    }
    refresh() {
        const model = this.editor.model;
        const selection = model.document.selection;
        const position = selection.getFirstPosition();
        if (position === null) {
            return;
        }
        const allowedIn = model.schema.findAllowedParent(position, 'conditionalBlock');
        this.isEnabled = allowedIn !== null;
    }
}
//# sourceMappingURL=insert-conditional-block-command.js.map