import { isEmpty, uniq, without } from 'lodash';
import { fetchEnumDefinitions } from '../../service/graphql-service';
import { ActionType } from '../action-types';
/** Remap server side enum type definition and returns an action to add the enum type definitions to the state */
export const addEnumTypes = (serverProvidedTypes) => {
    const remappedTypes = {};
    Object.keys(serverProvidedTypes).forEach(k => {
        if (!serverProvidedTypes[k]?.enumValues) {
            throw new Error(`The following enum type cannot be found on the GraphQL schema: ${k}`);
        }
        remappedTypes[k] = serverProvidedTypes[k].enumValues.map((v) => v.name);
    });
    return { type: ActionType.AddEnumType, value: remappedTypes };
};
export const loadEnumType = (enumNames) => async (dispatch, getState) => {
    const unloadedEnums = uniq(without(enumNames, ...Object.keys(getState().enumTypes))).filter(v => !!v);
    if (isEmpty(unloadedEnums)) {
        return;
    }
    const enumDefinition = await fetchEnumDefinitions(unloadedEnums);
    if (!isEmpty(enumDefinition)) {
        dispatch(addEnumTypes(enumDefinition));
    }
};
//# sourceMappingURL=enum-types-actions.js.map