import { createDictionary } from '@sage/xtrem-shared';
import { xtremConsole } from '../../utils/console';
import { isDevMode } from '../../utils/window';
import { ActionType } from '../action-types';
import { INPUT_NODE_POSTFIX } from '../../utils/constants';
let cache = createDictionary();
export const collectTypeDefinitions = (obj, nodeType) => {
    if (nodeType.indexOf('_') !== -1 && !nodeType.endsWith(INPUT_NODE_POSTFIX)) {
        return;
    }
    if (!Object.prototype.hasOwnProperty.call(obj, 'fields') &&
        !Object.prototype.hasOwnProperty.call(obj, 'inputFields')) {
        const enumValues = obj.type.enumValues?.map((v) => v.name) ?? undefined;
        const typeName = obj.type.name || obj.type.ofType.name;
        const name = typeName.replace('_Collection', '');
        if (!Object.prototype.hasOwnProperty.call(cache, nodeType)) {
            cache[nodeType] = createDictionary();
        }
        cache[nodeType][obj.name] = {
            type: name,
            kind: obj.type.kind,
            enumValues,
            isCollection: typeName.endsWith('_Collection'),
        };
    }
    const fields = nodeType.endsWith(INPUT_NODE_POSTFIX)
        ? obj.inputFields || obj.type?.inputFields
        : obj.fields || obj.type?.fields;
    if (!fields) {
        return;
    }
    fields.forEach((f) => {
        collectTypeDefinitions(f, obj.type?.name || nodeType);
    });
};
export const collectTypeDefinitionsAndReturn = (obj, nodeType) => {
    const tempCache = cache;
    cache = {};
    collectTypeDefinitions(obj, nodeType);
    const objType = cache[nodeType];
    cache = tempCache;
    return objType;
};
export const addNodeTypes = (types) => {
    Object.keys(types).forEach(k => {
        if (types[k]) {
            collectTypeDefinitions(types[k], k);
        }
        else if (isDevMode()) {
            // eslint-disable-next-line no-console
            xtremConsole.warn(`The type definitions for ${k} were not found on the schema.`);
        }
    });
    return { type: ActionType.AddNodeTypes, value: cache };
};
//# sourceMappingURL=node-type-actions.js.map