import { fetchWidgetCategories } from '../../service/dashboard-service';
import { fetchNodeNames } from '../../service/node-information-service';
import { GraphQLTypes } from '../../types';
import { deepFindPropertyValues } from '../../utils/common-util';
import { ActionType } from '../action-types';
export const openWidgetEditorDialog = (widgetId, widgetDefinition) => async (dispatch, getState) => {
    const state = getState();
    if (Object.keys(state.dashboard.widgetEditor.nodeNames).length === 0) {
        const nodeNames = await fetchNodeNames();
        dispatch({ type: ActionType.SetNodeNames, value: nodeNames });
    }
    if (Object.keys(state.dashboard.widgetEditor.widgetCategories).length === 0) {
        const widgetCategories = await fetchWidgetCategories();
        dispatch({ type: ActionType.SetWidgetCategories, value: widgetCategories });
    }
    dispatch({
        type: ActionType.SetWidgetEditorOpen,
        value: {
            isOpen: true,
            widgetId,
            widgetDefinition,
        },
    });
};
export const closeWidgetEditorDialog = () => ({
    type: ActionType.SetWidgetEditorOpen,
    value: { isOpen: false },
});
export const updateUserWidgetDefinition = (widgetDefinition) => {
    const copiedWidgetDefinition = { ...widgetDefinition };
    // Extract list of used enums so we can load them next time the dashboard is accessed.
    copiedWidgetDefinition.usedEnums = deepFindPropertyValues('node', widgetDefinition, (v) => v.type === GraphQLTypes.Enum);
    return {
        type: ActionType.UpdateUserWidgetDefinition,
        value: copiedWidgetDefinition,
    };
};
//# sourceMappingURL=widget-editor-actions.js.map