import { deepMerge } from '@sage/xtrem-shared';
import { ActionType } from '../action-types';
import { combineReducers } from 'redux';
import { uniqBy } from 'lodash';
import { dashboardEditor } from './dashboard-editor';
import { widgetEditor } from './widget-editor';
export const dashboards = (state = {}, action) => {
    if (action.type === ActionType.AddDashboard) {
        // Setting current dashboards unselected
        const newState = Object.keys(state).reduce((prevValue, currentValue) => {
            return { ...prevValue, [currentValue]: { ...state[currentValue], isSelected: false } };
        }, {});
        return { ...newState, [action.value._id]: { ...action.value, isSelected: true } };
    }
    if (action.type === ActionType.RemoveDashboard) {
        const newState = { ...state };
        const itemToRemove = newState[action.value];
        delete newState[action.value];
        // If the selected dashboard is deleted we mark the first dashboard selected
        const remainingKeys = Object.keys(newState);
        if (itemToRemove.isSelected && remainingKeys.length > 0) {
            newState[remainingKeys[0]].isSelected = true;
        }
        return newState;
    }
    return state;
};
export const widgets = (state = {}, action) => {
    if (action.type === ActionType.AddWidgets) {
        const widgetDefinitions = action.value.reduce((prevValue, currentValue) => ({
            ...prevValue,
            [currentValue._id]: currentValue,
        }), {});
        return { ...state, ...widgetDefinitions };
    }
    if (action.type === ActionType.ClearWidgetOptions) {
        return Object.keys(state)
            .map((widgetId) => {
            return { ...state[widgetId], options: undefined };
        })
            .reduce((accu, next) => {
            return { ...accu, [next._id]: next };
        }, {});
    }
    if (action.type === ActionType.SetWidgetData) {
        const widgetDefinition = state[action.value.widgetId];
        return { ...state, [action.value.widgetId]: { ...widgetDefinition, data: action.value.data } };
    }
    if (action.type === ActionType.AddWidgetData) {
        const widgetDefinition = state[action.value.widgetId];
        return {
            ...state,
            [action.value.widgetId]: { ...widgetDefinition, data: deepMerge(widgetDefinition.data, action.value.data) },
        };
    }
    if (action.type === ActionType.SetWidgetOptions) {
        const widgetDefinition = state[action.value.widgetId];
        return { ...state, [action.value.widgetId]: { ...widgetDefinition, options: action.value.options } };
    }
    return state;
};
export const availableDashboards = (state = [], action) => {
    const newState = [...state];
    switch (action.type) {
        case ActionType.AddAvailableDashboards:
            return uniqBy([...newState, ...action.value], v => v._id);
        case ActionType.RemoveDashboard:
            const indexToRemove = newState.findIndex(d => String(d._id) === action.value);
            if (indexToRemove !== -1) {
                newState.splice(indexToRemove, 1);
            }
            return newState;
        case ActionType.AddDashboard:
            const indexToUpdate = newState.findIndex(d => String(d._id) === action.value._id);
            const newEntry = { _id: action.value._id, title: action.value.title };
            if (indexToUpdate === -1) {
                return [...newState, newEntry];
            }
            newState[indexToUpdate] = newEntry;
            return newState;
        default:
            // We have to return the original state, not the cloned object so we don't trigger unessential updates
            return state;
    }
};
export const dashboard = combineReducers({
    availableDashboards,
    dashboardEditor,
    dashboards,
    widgetEditor,
    widgets,
});
//# sourceMappingURL=dashboard.js.map