import type { AbstractWidget as BmsAbstractWidget, RowDefinition } from '@sage/bms-dashboard';
import type { ClientNode } from '@sage/xtrem-client';
import type { Dashboard, DashboardItem, Dict } from '@sage/xtrem-shared';
import type { AbstractWidget, WidgetDefinition } from '../dashboard/widgets/abstract-widget';
import type { DashboardListItem } from '../redux/state';
export declare const DASHBOARD_SCREEN_ID = "$dashboard";
export declare const DASHBOARD_DETAILS_QUERY: {
    _id: boolean;
    title: boolean;
    children: {
        _id: boolean;
        type: boolean;
        settings: boolean;
        x: boolean;
        y: boolean;
        h: boolean;
        w: boolean;
    };
};
export declare const fetchCurrentDashboardDefinition: (shouldFetchPlatformLiterals?: boolean) => Promise<{
    dashboard: Dashboard | null;
    stringLiterals: Dict<string>;
    availableDashboards: DashboardListItem[] | null;
}>;
export declare const fetchWidgetCategories: () => Promise<Dict<string>>;
export declare const fetchDashboardTemplates: () => Promise<DashboardListItem[]>;
export declare const setSelectedDashboard: (selectedId: string) => Promise<Dashboard>;
export declare const cloneDashboard: (dashboardIdToClone: string) => Promise<Dashboard>;
export declare const deleteDashboard: (dashboardIdToDelete: string) => Promise<void>;
export declare const createEmptyDashboard: () => Promise<Dashboard>;
export declare const updateDashboard: (dashboardDefinition: Dashboard) => Promise<Dashboard>;
export interface XtremUiWidgetCategory extends ClientNode {
    title: string;
    sortValue?: number;
}
export interface XtremUiWidget extends ClientNode {
    category: XtremUiWidgetCategory;
    title: string;
    description: string;
    type: string;
}
/**
 * Fetches widget list from the server and adds "Others" category to those which doesn't have one.
 * It also adds a _sortValue as the items should be categorized alphabetically, e
 * except the Others, so we cannot sort them just by their label
 * @returns
 */
export declare const getWidgetList: () => Promise<{
    widgets: XtremUiWidget[];
    categories: XtremUiWidgetCategory[];
}>;
export declare const fetchWidgetPage: ({ queryArgs, widgetId, }: {
    widgetId: string;
    queryArgs: LoadMoreRowsParams;
}) => Promise<RowDefinition[]>;
export type PillColorVariant = 'warning' | 'neutral' | 'negative' | 'positive';
export type LoadMoreRowsParams = {
    startIndex: number;
    stopIndex: number;
    pageCount: number;
    pageSize: number;
    after?: RowDefinition;
    first: number;
};
export declare const getVisualProcessWidgetConfig: (widgetId: string, widgetDefinition: WidgetDefinition, isEditing?: boolean) => Partial<BmsAbstractWidget>;
export declare const getWidgetsFromDashboardItems: (dashboardId: string, children: DashboardItem[], widgets: Dict<WidgetDefinition>, isEditing?: boolean, onCloseCallback?: ((widgetId: string) => void) | undefined) => BmsAbstractWidget[];
export declare const fetchWidgetData: ({ forceRefetch, locale, version, widgetDefinition, queryArgs, }: {
    forceRefetch?: boolean | undefined;
    locale?: string | undefined;
    version?: string | undefined;
    widgetDefinition: WidgetDefinition;
    queryArgs?: Partial<LoadMoreRowsParams> | undefined;
}) => Promise<any>;
export declare const resolveWidgetProperty: <T extends unknown>(property: T, widget: string | AbstractWidget, ...args: any[]) => any;
//# sourceMappingURL=dashboard-service.d.ts.map