import type { Filter, FilterOperatorComparable, FilterOperatorEquality, FilterOperatorInclusion, Logical, Quantifiers } from '@sage/xtrem-client';
import { type Dict } from '@sage/xtrem-shared';
import type { PropertyValueType } from '../../component/field/reference/reference-types';
import type { NestedField, NestedFieldTypes } from '../../component/nested-fields';
import type { ReadonlyFieldControlObject, ReadonlyFieldProperties } from '../../component/readonly-field-control-object';
import type { OrderByType } from '../../component/types';
import type { CardDefinition } from '../../component/ui/card/card-component';
import type { NodeTypeDict } from '../../redux/state';
import type { NodePropertyType } from '../../types';
import type { CollectionQuery, ExecutableQuery, GraphQLFilter, NodeCollection, NonArrayGraphQLFilter, QueryArguments, QueryBuilderOptions, QueryEnumWrapper, QueryFilterOperator, QueryProperty, QueryWrapper, TotalCountQuery } from '../graphql-utils';
import type { Page } from '../page';
import type { PageMetadata } from '../page-metadata';
import type { ScreenBaseDefinition } from '../screen-base-definition';
export declare const RESTRICTED_COLUMN_PREFIX = "__restricted_";
export declare const RESTRICTED_COLUMN_ALL_PREFIX = "__all_";
export type QuantifierType = keyof Quantifiers;
export declare const quantifiers: QuantifierType[];
export * from './field-query-builder';
export type FilterReservedWord = keyof FilterOperatorComparable<any> | keyof FilterOperatorEquality<any> | keyof FilterOperatorInclusion<any> | keyof Logical<any> | keyof Quantifiers | keyof QueryFilterOperator;
export declare const filterReservedWords: ("_and" | "_or" | "_not" | "_mod" | "_regex" | "_options" | "_gt" | "_gte" | "_lt" | "_lte" | "_eq" | "_ne" | "_in" | "_nin" | "_contains" | "_containsRange" | "_containedBy" | "start" | "end" | "_atLeast" | "_atMost" | "_every" | "_none")[];
export declare const getPlatformStringLiteralsSchemaFragment: () => ExecutableQuery;
export declare const addTotalCountTransform: (filter: Filter<any>, initial: CollectionQuery['edges']['node']) => Filter<any>;
export declare const addReferenceIdsAssign: (filter: Filter<any>, node?: NodePropertyType, nodeTypes?: Dict<NodeTypeDict>) => Filter<any>;
export declare const parseFilterEnumFields: (source: NonArrayGraphQLFilter) => GraphQLFilter;
export declare const convertFilterDecoratorToGraphQLFilter: (screenDefinition: ScreenBaseDefinition, filter?: any, recordContext?: Dict<any>) => GraphQLFilter | undefined;
export declare const queryBuilder: (node: NodePropertyType, options: QueryBuilderOptions) => NodeCollection;
export declare const getUsedEnums: (pageMetadata: PageMetadata, knownEnumDefinitions: string[]) => string[];
export declare const buildEnumQuery: (enumName: string) => QueryEnumWrapper;
export declare const getUsedNodes: (pageMetadata: PageMetadata, knownTypeDefinitions: string[], rootNode?: string) => string[];
export declare const buildTypeQuery: (nodeName: string, level?: number) => QueryEnumWrapper;
export declare const getRequestableFieldIds: (fieldControlObjects: Dict<ReadonlyFieldControlObject<any, any, any>>, screenDefinition: ScreenBaseDefinition) => string[];
export declare const buildEnumQueries: (pageMetadata: PageMetadata, knownTypes: string[]) => QueryEnumWrapper;
export declare const buildTypeQueries: (pageMetadata: PageMetadata, knownTypes: string[], rootNode?: string) => QueryEnumWrapper;
export declare const buildTableTotalCountQuery: ({ filter }: {
    filter: string;
}) => TotalCountQuery;
export declare const buildFieldQuery: (rootNode: NodePropertyType, fieldControlObject: ReadonlyFieldControlObject<any, any, any>, screenDefinition: ScreenBaseDefinition, fieldProperties: ReadonlyFieldProperties, elementId: string, recordId: string, nodeTypes: Dict<NodeTypeDict>) => NodeCollection;
export declare const buildRootNodeQuery: (rootNode: NodePropertyType, fieldControlObjects: Dict<ReadonlyFieldControlObject<any, any, any>>, screenDefinition: ScreenBaseDefinition, _id: string, alias?: string, nodeTypes?: Dict<NodeTypeDict>, isDuplicate?: boolean) => QueryWrapper<any>;
export declare const getFilterAsString: (filters: (GraphQLFilter | (() => GraphQLFilter) | undefined)[], screenDefinition: ScreenBaseDefinition, recordContext?: Dict<any>) => string | undefined;
export declare const mergeFilters: (filters: (GraphQLFilter | (() => GraphQLFilter) | undefined)[], screenDefinition: ScreenBaseDefinition, recordContext?: Dict<any>) => GraphQLFilter;
export declare const applyDeepNestedKey: (elementId: string, fieldDetails: any, addAlias?: boolean, bind?: PropertyValueType, parentNode?: NodePropertyType, nodeTypes?: Dict<NodeTypeDict>) => any;
/**
 * Inspects the filter object, and prepare it for server side consumption.
 * It remaps id field names to match current server inconsistencies and creates nested sorting conditions for reference
 * fields.
 * @param orderBy
 */
export declare const createOrderByQueryArgument: (orderBy: OrderByType) => string;
export declare const getAggregationValues: (aggregations: object) => any;
export declare const nestedFieldsToQueryProperties: ({ screenDefinition, nestedFields, node, nodeTypes, }: {
    screenDefinition: ScreenBaseDefinition;
    nestedFields: NestedField<Page, NestedFieldTypes>[];
    nodeTypes?: Dict<NodeTypeDict> | undefined;
    node?: NodePropertyType | undefined;
}) => QueryProperty[];
export declare const getNestedFieldsQuery: ({ screenDefinition, nestedFields, queryArguments, alias, wrapNodeWithEdges, node, nodeTypes, }: {
    screenDefinition: ScreenBaseDefinition;
    nestedFields: NestedField<Page, NestedFieldTypes>[];
    queryArguments?: QueryArguments | undefined;
    alias?: string | undefined;
    wrapNodeWithEdges?: boolean | undefined;
    nodeTypes?: Dict<NodeTypeDict> | undefined;
    node?: NodePropertyType | undefined;
}) => NodeCollection;
export declare const parseQueryArguments: (inputArguments: QueryArguments) => QueryArguments;
export declare const buildRowDefaultQuery: ({ screenDefinition, elementId, isNewRow, alias, recordId, data, nodeTypes, }: {
    screenDefinition: ScreenBaseDefinition;
    elementId: string;
    isNewRow?: boolean | undefined;
    alias?: string | undefined;
    recordId?: string | undefined;
    data?: any;
    nodeTypes: Dict<NodeTypeDict>;
}) => QueryWrapper<any>;
export declare const buildNestedDefaultsQuery: ({ screenDefinition, elementId, isNewRow, alias, recordId, level, data, nodeTypes, }: {
    screenDefinition: ScreenBaseDefinition;
    elementId: string;
    isNewRow?: boolean | undefined;
    alias?: string | undefined;
    recordId?: string | undefined;
    level?: number | undefined;
    data?: any;
    nodeTypes: Dict<NodeTypeDict>;
}) => QueryWrapper<any>;
/**
 * Builds a query to request default values from the server.
 * If a list of fields is not provided as the last argument, the function checks the screen definition and requests values for the non-dirty fields.
 */
export declare const buildDefaultsQuery: ({ screenDefinition, alias, requestedFieldIds, clean, additionalData, sendNonDirtyFields, node, nodeTypes, }: {
    screenDefinition: ScreenBaseDefinition;
    alias?: string | undefined;
    requestedFieldIds?: string[] | undefined;
    clean?: boolean | undefined;
    additionalData?: Dict<any> | undefined;
    sendNonDirtyFields?: boolean | undefined;
    nodeTypes?: Dict<NodeTypeDict> | undefined;
    node?: NodePropertyType | undefined;
}) => QueryWrapper<any>;
export declare const getNavigationPanelOrderByDefinition: (listItem: CardDefinition, explicitOrderBy?: OrderByType) => OrderByType;
//# sourceMappingURL=index.d.ts.map