/// <reference types="lodash" />
import type { ClientNode } from '@sage/xtrem-client';
import type { Dict } from '@sage/xtrem-shared';
import type { CancelToken } from 'axios';
import type { OptionsMenuItem } from '../component/container/page/page-types';
import type { CollectionValueFieldProperties, MultiReferenceProperties } from '../component/control-objects';
import type { ReferenceProperties, TreeProperties } from '../component/field/field-properties';
import type { NestedReferenceProperties, PropertyValueType } from '../component/field/reference/reference-types';
import type { TableDecoratorProperties } from '../component/field/table/table-component-types';
import type { NestedField, NestedFieldTypes } from '../component/nested-fields';
import type { ReadonlyFieldProperties } from '../component/readonly-field-control-object';
import type { OrderByType } from '../component/types';
import type { ApplicationContext, NodeType, NodeTypeDict } from '../redux/state';
import type { NodePropertyType } from '../types';
import { CollectionFieldTypes } from './collection-data-types';
import type { GraphQLFilter, NodeCollectionResult, QueryArguments } from './graphql-utils';
import type { ArtifactType, MetadataResponse, ModuleEntryProperties } from './metadata-types';
import type { Page } from './page';
import type { PageDefinition } from './page-definition';
import type { PageMetadata } from './page-metadata';
import type { XtremUiPlugin } from './plugin-service';
import type { ScreenBase } from './screen-base';
import type { ScreenBaseDefinition } from './screen-base-definition';
export declare const fetchCollectionDataCount: ({ rootNode, filter, }: {
    rootNode: NodePropertyType;
    filter: string;
}) => Promise<number>;
export declare const fetchCollectionData: ({ bind, elementId, group, nestedFields, node, nodeTypes, queryArguments, rootNode, rootNodeId, screenDefinition, totalCount, treeProperties, }: {
    bind?: PropertyValueType;
    elementId: string;
    group?: {
        key: string;
        value?: string | undefined;
    } | undefined;
    nestedFields: NestedField<ScreenBase, NestedFieldTypes>[];
    node?: string | undefined;
    nodeTypes?: Dict<NodeTypeDict> | undefined;
    queryArguments?: QueryArguments | undefined;
    rootNode: NodePropertyType;
    rootNodeId: string;
    screenDefinition: ScreenBaseDefinition;
    totalCount?: boolean | undefined;
    treeProperties?: TreeProperties<Page<any, any>, any> | undefined;
}) => Promise<any>;
export declare const fetchCollectionRecord: (screenDefinition: ScreenBaseDefinition, nestedFields: NestedField<ScreenBase, NestedFieldTypes, any, any>[], nodeName: NodePropertyType, recordId: string) => Promise<any>;
export declare const formatNavigationPanelResponse: (navigationPanelResponse: NodeCollectionResult) => any[];
export declare const buildFilterForNestedFields: <T extends ClientNode = any>(nestedFields: NestedField<ScreenBase<any, any>, NestedFieldTypes, T, any>[], nodeTypes: Dict<NodeTypeDict>, filterText: string, locale?: string, node?: NodePropertyType) => GraphQLFilter<T>[];
export declare const fetchNavigationPanelData: (screenId: string, screenDefinition: ScreenBaseDefinition, tableDecoratorProperties: TableDecoratorProperties, orderBy?: OrderByType, filter?: GraphQLFilter, first?: number, nodeTypes?: Dict<NodeTypeDict>, optionMenuItem?: OptionsMenuItem) => Promise<any[]>;
export declare const createSearchBoxFilter: <T extends ClientNode = any>(fieldProperties: ReferenceProperties<ScreenBase<any, any>, T> | MultiReferenceProperties<ScreenBase<any, any>, T, void> | CollectionValueFieldProperties<ScreenBase<any, any>, T>, nodeTypes: Dict<NodeTypeDict>, locale?: string, collectionFieldType?: CollectionFieldTypes, searchBoxText?: string, exactMatch?: boolean, isArray?: boolean) => GraphQLFilter<T> | undefined;
export interface FetchReferenceFieldSuggestionsInput<T extends ClientNode = any> {
    after?: string;
    contextNode?: NodePropertyType;
    exactMatch?: boolean;
    fieldId: string;
    fieldProperties: Omit<ReferenceProperties<ScreenBase, T>, 'parent'>;
    filterValue?: string;
    isFilterLimitedToDataset?: boolean;
    level?: number;
    locale?: string;
    parentElementId?: string;
    recordContext?: Dict<any>;
    screenId: string;
}
export declare const fetchReferenceFieldSuggestions: <T extends ClientNode = any>({ after, contextNode, exactMatch, fieldId, fieldProperties, filterValue, isFilterLimitedToDataset, level, locale, parentElementId, recordContext, screenId, }: FetchReferenceFieldSuggestionsInput<T>) => Promise<T[]>;
export declare const fetchReferenceFieldData: <T extends ClientNode = any>({ after, axiosCancelToken, contextNode, elementId, fieldProperties, filter, group, isFilterLimitedToDataset, level, orderBy, pageSize, parentElementId, recordContext, screenId, valueField, }: {
    after?: string | undefined;
    axiosCancelToken?: CancelToken | undefined;
    contextNode?: NodePropertyType | undefined;
    elementId: string;
    fieldProperties: Omit<ReferenceProperties<ScreenBase<any, any>, T>, "parent">;
    filter?: GraphQLFilter<T> | undefined;
    group?: {
        key: string;
        value?: string | undefined;
    } | undefined;
    isFilterLimitedToDataset?: boolean | undefined;
    level?: number | undefined;
    orderBy?: OrderByType<T> | undefined;
    pageSize?: number | undefined;
    parentElementId?: string | undefined;
    recordContext?: Dict<any> | undefined;
    screenId: string;
    valueField?: any;
}) => Promise<NodeCollectionResult<T>>;
export declare const fetchReferenceFieldDataById: <T extends ClientNode = any>({ _id, contextNode, elementId, fieldProperties, level, parentElementId, recordContext, screenId, valueField, }: {
    _id: string;
    contextNode?: NodePropertyType | undefined;
    elementId: string;
    fieldProperties: Omit<ReferenceProperties<ScreenBase<any, any>, T>, "parent">;
    level?: number | undefined;
    parentElementId?: string | undefined;
    recordContext?: Dict<any> | undefined;
    screenId: string;
    valueField?: any;
}) => Promise<any>;
export declare const fetchRecordData: (screenId: string, recordId: string, screenDefinition: ScreenBaseDefinition) => Promise<any>;
export declare const fetchField: (screenDefinition: ScreenBaseDefinition, fieldProperties: ReadonlyFieldProperties, recordId: string, elementId: string, plugins: Dict<XtremUiPlugin>, nodeTypes: Dict<NodeTypeDict>, nodeName?: string, keepPageInfo?: boolean) => Promise<any>;
export interface InitialData {
    navigationPanel: any[];
    values: ScreenBaseDefinition['values'];
}
export declare const fetchInitialTypes: (pageMetadata: PageMetadata, knownNodeTypes: string[]) => Promise<{
    types: any;
} | undefined>;
export declare const fetchEnumTranslations: (enums: string[], locale: string) => Promise<Dict<string>>;
/**
 * Gets the Graphql type of the (possibly nested) property a reference field's valueField is pointing to.
 *
 * @param {string} screenId the id of the current screen
 * @param {NestedReferenceProperties<ScreenBase, any>} referenceProperties the reference properties
 * @returns {Promise<GraphQLTypes>} a Graphql type
 */
export declare const getGraphqlType: (screenId: string, referenceProperties: NestedReferenceProperties<ScreenBase, any>) => Promise<NodeType>;
export declare const fetchInitialData: (pageDefinition: PageDefinition, recordId?: string, path?: string, applicationContext?: ApplicationContext, nodeTypes?: Dict<NodeTypeDict>, values?: Dict<any>, isDuplicate?: boolean) => Promise<InitialData>;
export interface FetchInitialSchemaInfoResult {
    types: Dict<NodeTypeDict>;
    enums: Dict<string[]>;
}
export declare const fetchInitialSchemaInfo: (pageDefinition: PageDefinition, knownNodeTypes?: string[], knownEnumTypes?: string[]) => Promise<FetchInitialSchemaInfoResult>;
export declare const fetchEnumDefinitions: (enumNames: string[]) => Promise<Dict<string[]>>;
export declare const purgeMetaDataCache: () => Promise<void>;
export interface QueryMetadataArgs {
    applicationPackages?: Dict<string>;
    metadataType: ArtifactType;
    metadataProperties: ModuleEntryProperties[];
    path?: string;
    shouldFetchPlatformLiterals?: boolean;
    exactMatch?: boolean;
    locale?: string;
    node?: string;
}
export declare const queryMetadata: ({ applicationPackages, metadataType, metadataProperties, path, shouldFetchPlatformLiterals, locale, exactMatch, node, }: QueryMetadataArgs) => Promise<MetadataResponse>;
export interface InitialMetadataQueryResult {
    installedPackages: {
        name: string;
        version: string;
    }[];
    customizationWizardPage: string | null;
    exportConfigurationPage: string | null;
}
export declare const queryInitialMetadata: () => Promise<InitialMetadataQueryResult>;
export declare const queryPagesByNodeType: ((pageNode: string) => Promise<Array<{
    key: string;
    title: string;
}>>) & import("lodash").MemoizedFunction;
export declare const fetchNestedDefaultValues: ({ screenId, elementId, isNewRow, recordId, nestedElementId, level, data, }: {
    screenId: string;
    elementId: string;
    isNewRow?: boolean | undefined;
    recordId?: string | undefined;
    nestedElementId?: string | undefined;
    level?: number | undefined;
    data?: any;
}) => Promise<{
    pageDefaults?: Dict<any> | undefined;
    nestedDefaults?: Dict<any> | undefined;
}>;
export declare const fetchDefaultValues: (screenDefinition: ScreenBaseDefinition, rootNode: string, requestedFieldIds?: string[], clean?: boolean, nodeTypes?: Dict<NodeTypeDict>) => Promise<Dict<any>>;
//# sourceMappingURL=graphql-service.d.ts.map