import type { Dict, MetaCustomField } from '@sage/xtrem-shared';
import type { UiComponentProperties } from '../component/abstract-ui-control-object';
import type { DetailPanelControlObject, PageActionControlObject, PageControlObject } from '../component/control-objects';
import type { ControlObjectInstance } from '../component/types';
import type { PageArticleItem, PageArticleLayout } from './layout-service';
import type { Page } from './page';
import type { ScreenBase } from './screen-base';
import type { Key } from './shortcut-service';
export interface ElementWithShortcut {
    elementId: string;
    shortcut: Key | Key[];
}
/**
 * This object is used while the decorators are executed to gather all metadata and share data between the decorators.
 */
export interface PageMetadata {
    blockThunks: Dict<() => Partial<PageArticleItem>>;
    businessActionsExtensionsThunk: Array<(ctx: Page) => PageActionControlObject[]>;
    businessActionsThunk?: (ctx: Page) => PageActionControlObject[];
    controlObjects: Dict<ControlObjectInstance<any>>;
    duplicateBindings?: string[];
    customizableNodes?: string[];
    customizableNodesWizard?: string[];
    customizations: Dict<MetaCustomField[]>;
    defaultEntryThunk?: (ctx: Page) => null | string | Promise<null | string>;
    /** Duplicate of uiComponentProperties. This object is used whenever we need to reset the screen to its original state. */
    defaultUiComponentProperties: Dict<UiComponentProperties>;
    definitionOrder: string[];
    detailPanelThunk?: (ctx: Page) => DetailPanelControlObject;
    elementsWithShortcut: ElementWithShortcut[];
    exportTemplatesByNode?: Dict<Dict<string>>;
    extensionOverrideThunks: Dict<(() => UiComponentProperties)[]>;
    fieldThunks: Dict<() => PageArticleItem>;
    layout: PageArticleLayout;
    layoutBlocks: Dict<Partial<PageArticleItem>>;
    layoutFields: Dict<PageArticleItem>;
    pageActions: Dict<PageActionControlObject>;
    pageActionThunks: Dict<() => PageActionControlObject>;
    pageExtensionThunks: Array<() => void>;
    pageThunk?: () => PageControlObject;
    screenId: string;
    sectionThunks: Dict<() => Partial<PageArticleItem>>;
    target?: ScreenBase;
    uiComponentProperties: Dict<UiComponentProperties>;
}
export declare const setPreferredScreenId: (screenId: string) => void;
export declare const unsetPreferredScreenId: () => void;
export declare const getNewPageMetadata: (screenId: string, target?: ScreenBase) => PageMetadata;
/**
 * Get the page metadata object from the constructor
 *
 * The metadata object is added to the constructor of the page which is being built because all decorator functions
 * have direct access to the object constructor, so it is an easy way to have a global shared object.
 */
export declare const getPageMetadata: (pageConstructor: Function, target?: ScreenBase) => PageMetadata;
//# sourceMappingURL=page-metadata.d.ts.map