"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Tree = void 0;
const checkbox_1 = require("carbon-react/esm/components/checkbox");
const icon_1 = __importDefault(require("carbon-react/esm/components/icon"));
const icon_button_1 = __importDefault(require("carbon-react/esm/components/icon-button"));
const React = __importStar(require("react"));
const tokens = __importStar(require("@sage/design-tokens/js/base/common"));
const lodash_1 = require("lodash");
const link_1 = __importDefault(require("carbon-react/esm/components/link"));
const computeUnderlinedContent = (label, searchText) => {
    if (!searchText) {
        return [label];
    }
    const regex = new RegExp(`(${searchText})`, 'gi');
    const parts = label.split(regex);
    const underlinedLabel = [];
    for (let i = 0; i < parts.length; i += 1) {
        const part = parts[i];
        if (part.toLowerCase() === searchText.toLowerCase()) {
            underlinedLabel.push(React.createElement("span", { key: i, className: "e-tree-view-underlined" }, part));
        }
        else {
            underlinedLabel.push(part);
        }
    }
    return underlinedLabel;
};
exports.Tree = React.memo(({ checkedItems, element, fetchItems, isDisabled, isReadOnly, level, listOpenedItems, onCheckedItemsUpdated, onCloseChild, onOpenChild, selectionMode = 'multiple', searchText = '', isFolderIconHidden = false, }) => {
    const [listItems, setListItems] = React.useState(null);
    const [isOpen, setOpen] = React.useState(() => {
        if (level === 0) {
            return true;
        }
        if (listOpenedItems && element.key in listOpenedItems) {
            return true;
        }
        return false;
    });
    const onOpen = React.useCallback((ev) => {
        ev.preventDefault();
        setOpen(!isOpen);
        if (isOpen && onCloseChild) {
            onCloseChild(element.key);
        }
    }, [element.key, isOpen, onCloseChild]);
    const previousListItemsRef = React.useRef(listItems);
    React.useEffect(() => {
        if (isOpen) {
            fetchItems(element).then(elements => {
                const sortedElements = [...elements];
                sortedElements.sort((a, b) => a.label.localeCompare(b.label));
                setListItems(sortedElements);
            });
        }
    }, [isOpen, element, fetchItems]);
    React.useEffect(() => {
        if (level !== 0 && onOpenChild && listItems && listItems !== previousListItemsRef.current) {
            onOpenChild(element.key, listItems.map(item => item.label));
        }
        previousListItemsRef.current = listItems;
    }, [listItems, level, onOpenChild, element.key]);
    function findValuesByPartialPath(obj, partialPath) {
        return (0, lodash_1.flatMap)((0, lodash_1.filter)(obj, (_value, key) => (0, lodash_1.includes)(key, partialPath)));
    }
    const findSearchText = React.useCallback((item) => {
        const result = findValuesByPartialPath(listOpenedItems, item.key);
        return (item.label.toLowerCase().includes(searchText.toLowerCase()) ||
            result.findIndex(ele => ele.toLowerCase().includes(searchText.toLowerCase())) !== -1);
    }, [listOpenedItems, searchText]);
    const renderBody = React.useCallback(() => {
        return (React.createElement("ul", { className: `e-tree-view-element-body e-tree-view-element-body-level-${level}` }, listItems
            ?.filter(item => findSearchText(item))
            .map(childElement => (React.createElement(exports.Tree, { key: childElement.key, element: childElement, checkedItems: checkedItems, onCheckedItemsUpdated: onCheckedItemsUpdated, fetchItems: fetchItems, level: level + 1, onOpenChild: onOpenChild, onCloseChild: onCloseChild, listOpenedItems: listOpenedItems, searchText: searchText, isDisabled: isDisabled, isReadOnly: isReadOnly, selectionMode: selectionMode, isFolderIconHidden: isFolderIconHidden })))));
    }, [
        level,
        selectionMode,
        listItems,
        findSearchText,
        checkedItems,
        onCheckedItemsUpdated,
        fetchItems,
        onOpenChild,
        onCloseChild,
        listOpenedItems,
        searchText,
        isDisabled,
        isReadOnly,
        isFolderIconHidden,
    ]);
    const onChecked = React.useCallback((ev) => {
        const newCheckedItems = { ...(checkedItems || {}) };
        if (ev.target.checked) {
            newCheckedItems[element.key] = {
                label: element.label,
                data: element.data,
                id: element.key,
                key: element.key,
                labelKey: element.labelKey,
                labelPath: element.labelKey,
            };
        }
        else {
            delete newCheckedItems[element.key];
        }
        if (onCheckedItemsUpdated) {
            onCheckedItemsUpdated(newCheckedItems);
        }
    }, [checkedItems, element, onCheckedItemsUpdated]);
    const onButtonClick = React.useCallback(() => {
        const newCheckedItems = { ...(checkedItems || {}) };
        newCheckedItems[element.key] = {
            label: element.label,
            data: element.data,
            id: element.key,
            key: element.key,
            labelKey: element.labelKey,
            labelPath: element.labelKey,
        };
        if (onCheckedItemsUpdated) {
            onCheckedItemsUpdated(newCheckedItems);
        }
    }, [checkedItems, element, onCheckedItemsUpdated]);
    if (level === 0) {
        return renderBody();
    }
    const indentations = [];
    for (let i = 1; i < level; i += 1) {
        indentations.push(React.createElement("span", { key: i, className: `e-tree-view-element-tree-branch e-tree-view-element-tree-branch-level-${i}` }));
    }
    const isChecked = checkedItems[element.key];
    return (React.createElement("li", { className: `e-tree-view-element e-tree-view-element-level-${level} ${isChecked ? ' checked' : ''}` },
        React.createElement("div", { className: `e-tree-view-element-container e-tree-view-element-container-${selectionMode}` },
            indentations.length > 0 && React.createElement("span", { className: "e-tree-view-indent-container" }, indentations),
            level > 1 && React.createElement("span", { className: "e-tree-view-line" }),
            element.canBeSelected && !isReadOnly && selectionMode !== 'button' && (React.createElement("div", { className: "e-tree-view-checkbox-container" }, selectionMode === 'multiple' && (React.createElement(checkbox_1.Checkbox, { "data-testid": `e-tree-view-checkbox e-tree-view-checkbox-label-${(0, lodash_1.camelCase)(element.label)}`, checked: !!checkedItems[element.key], onChange: onChecked, mb: "0px", disabled: isDisabled })))),
            element.canBeSelected && isReadOnly && (React.createElement(icon_1.default, { className: "e-tree-view-switcher-icon", type: checkedItems[element.key] ? 'tick' : 'cross', color: tokens.colorsYin090 })),
            element.canBeExpanded && (React.createElement("div", { className: "e-tree-view-element-node-container" },
                React.createElement("span", { className: `e-tree-view-switcher-container${isOpen ? ' e-tree-view-switcher-container-open' : ''}${isFolderIconHidden ? ' e-tree-view-switcher-container-hidden-folder' : ''}` },
                    React.createElement(icon_button_1.default, { "data-testid": "e-tree-view-switcher-icon-container", onClick: onOpen, disabled: isDisabled },
                        React.createElement(icon_1.default, { className: "e-tree-view-switcher-icon", type: !isOpen ? 'plus' : 'minus', color: tokens.colorsActionMinor400 }))),
                !isFolderIconHidden && React.createElement(icon_1.default, { type: "folder", className: "e-tree-view-element-icon" }),
                React.createElement("label", null, computeUnderlinedContent(element.label, searchText)))),
            !element.canBeExpanded && (React.createElement("div", { className: "e-tree-view-icon-container", "data-testid": `e-tree-view-container-label-${(0, lodash_1.camelCase)(element.label)}` },
                selectionMode === 'button' && (React.createElement(link_1.default, { "data-testid": `e-tree-view-checkbox e-tree-view-checkbox-label-${(0, lodash_1.camelCase)(element.label)}`, onClick: onButtonClick, disabled: isDisabled, icon: element.data.iconType || 'file_generic', iconAlign: "left", variant: "neutral" }, computeUnderlinedContent(element.label, searchText))),
                selectionMode !== 'button' && (React.createElement(React.Fragment, null,
                    React.createElement(icon_1.default, { type: element.data.iconType || 'file_generic', className: "e-tree-view-element-icon" }),
                    React.createElement("label", null, computeUnderlinedContent(element.label, searchText))))))),
        isOpen && listItems !== null && renderBody()));
});
exports.Tree.displayName = 'Tree';
//# sourceMappingURL=tree.js.map