import { MENU_SEPARATOR } from '../component/control-objects';
import { getElementAccessStatusWithoutId } from './access-utils';
import { resolveByValue } from './resolve-value-utils';
export function calculateActionMenu({ screenId, accessBindings = {}, rowValue, actions, onTriggerMenuItem, }) {
    if (!actions) {
        return [];
    }
    const recordId = rowValue?._id;
    let idx = 0;
    const filterFn = (a) => {
        if (a === MENU_SEPARATOR) {
            return true;
        }
        const accessRule = getElementAccessStatusWithoutId(accessBindings, a.access);
        return accessRule === 'authorized';
    };
    const mapFn = (a) => {
        if (a === MENU_SEPARATOR) {
            return a;
        }
        const isDisabled = resolveByValue({
            screenId,
            propertyValue: a.isDisabled,
            rowValue,
            fieldValue: recordId,
            skipHexFormat: true,
        }) || false;
        const isHidden = resolveByValue({
            screenId,
            propertyValue: a.isHidden,
            rowValue,
            fieldValue: recordId,
            skipHexFormat: true,
        }) || false;
        const { children: hasChildren } = a;
        const children = hasChildren ? hasChildren.filter(filterFn).map(mapFn) : [];
        const { isDestructive, onClick } = a;
        idx += 1;
        return {
            isDisabled,
            isHidden,
            isDestructive,
            title: a.title,
            icon: a.icon,
            onClick: () => (isDisabled ? undefined : onTriggerMenuItem(onClick, a.onError)),
            key: `${idx}_${a.title}`,
            priority: idx,
            childrenProp: children,
        };
    };
    return actions.filter(filterFn).map(mapFn);
}
//# sourceMappingURL=action-menu-utils.js.map