import { localize } from '../../service/i18n-service';
import * as tokens from '@sage/design-tokens/js/base/common';
import { COLUMN_ID_ROW_ACTIONS, COLUMN_ID_ROW_SELECTION, COLUMN_ID_VALIDATIONS } from './ag-grid-column-config';
import { memoize } from 'lodash';
import { FieldKey } from '../../component/types';
import { KEY_ENTER, KEY_TAB, getCharCodeFromEvent } from '../keyboard-event-utils';
export function isLeftOrRight(event) {
    return [37, 39].indexOf(event.keyCode) > -1;
}
export function isCharNumeric(charStr) {
    return (!!/\d/.test(charStr) || charStr === localize('@sage/xtrem-ui/number-format-separator', '.') || charStr === '-');
}
export function isAllowedDateCharacter(charStr) {
    return !!/\d/.test(charStr) || charStr === localize('@sage/xtrem-ui/date-format-separator', '/');
}
export function isValidUrl(text) {
    return Boolean(
    // eslint-disable-next-line no-useless-escape
    /(ftp|http|https):\/\/(www\.)?[-a-zA-Z0-9@:%._\+~#=]{1,256}\.[a-zA-Z0-9()]{1,6}\b([-a-zA-Z0-9()!@:%_\+.~#?&\/\/=]*)/.test(text));
}
export function isKeyPressedNumeric(event) {
    const charCode = getCharCodeFromEvent(event);
    const charStr = event.key ? event.key : String.fromCharCode(charCode);
    return isCharNumeric(charStr);
}
export function isKeyPressedDateComponent(event) {
    const charCode = getCharCodeFromEvent(event);
    const charStr = event.key ? event.key : String.fromCharCode(charCode);
    return isAllowedDateCharacter(charStr);
}
export function isFinishedEditingPressed(event) {
    const charCode = getCharCodeFromEvent(event);
    return charCode === KEY_ENTER || charCode === KEY_TAB;
}
export const defaultCellRendederStyles = {
    lineHeight: '24px',
    fontSize: '14px',
    fontFamily: tokens.fontFamiliesDefault,
};
export const defaultCellEditorStyles = {
    width: '100%',
    height: '100%',
    border: 'none',
    outline: 'none',
    background: 'transparent',
    ...defaultCellRendederStyles,
};
export const setDefaultAgGridInputStyles = (input) => {
    Object.entries(defaultCellRendederStyles).forEach(([key, value]) => {
        input.style[key] = value;
    });
};
export const getColumnsToExport = (columns) => columns.filter(column => !(column.getColId() === COLUMN_ID_ROW_SELECTION ||
    column.getColId() === COLUMN_ID_VALIDATIONS ||
    column.getColId() === COLUMN_ID_ROW_ACTIONS ||
    column.getColDef().type === FieldKey.Image));
export const cellExportFormatter = (column, value) => {
    if (value === undefined || value === null || value === '')
        return '';
    if (column.type === FieldKey.Numeric)
        return Number(value).toString(10);
    if (column.type === FieldKey.Progress)
        return `${value}%`;
    return String(value);
};
export const getRowClassRules = memoize(({ canSelect, openedRecordId }) => ({
    'e-row-is-edited-with-select': memoize((params) => {
        return params.data?.__dirty === true && canSelect;
    }),
    'e-row-is-edited-no-select': memoize((params) => {
        return params.data?.__dirty === true && !canSelect;
    }),
    'e-row-is-open-in-sidebar': memoize((params) => {
        return Boolean(openedRecordId) && params.data?._id === openedRecordId;
    }),
}));
//# sourceMappingURL=ag-grid-cell-editor-utils.js.map