/// <reference types="react" />
import type { IconType } from 'carbon-react/lib/components/icon/icon-type';
import type { Dict, Locale, DashboardValueOrCallback, StringLiterals, CallToActionDefinition } from '../../types';
export declare type EventListener = (i: string | number) => void;
export declare type ValueFormatType = 'number' | 'string';
export declare type RenderAsType = 'link' | 'pill' | 'normal' | null | undefined;
export interface DisplayOptions {
    colorVariant?: DashboardValueOrCallback<'neutral' | 'negative' | 'positive' | 'warning'>;
    tooltipText?: DashboardValueOrCallback<string>;
}
export interface ColumnDefinitionOptions {
    title: string;
    onClick?: EventListener;
    displayOptions?: DisplayOptions;
    renderedAs?: RenderAsType;
    valueFormat?: ValueFormatType;
    decimalDigits?: number;
}
export interface RowDefinition {
    title: ColumnDefinitionOptions;
    titleRight?: ColumnDefinitionOptions;
    line2?: ColumnDefinitionOptions;
    line2Right?: ColumnDefinitionOptions;
    line3?: ColumnDefinitionOptions;
    line3Right?: ColumnDefinitionOptions;
    image?: ColumnDefinitionOptions;
    icon?: ColumnDefinitionOptions;
    [key: string]: ColumnDefinitionOptions | undefined;
}
export interface TableDataRow {
    i: string | number;
    title: string | number;
    titleRight?: string | number;
    line2?: string | number;
    line2Right?: string | number;
    line3?: string | number;
    line3Right?: string | number;
    image?: string;
    icon?: IconType;
    [key: string]: string | number | undefined;
}
export declare enum TableRowStatus {
    LOADING = 0,
    LOADED = 1,
    FAILED = 2,
    STALE = 3
}
export interface TableWidgetProps {
    data?: TableDataRow[];
    rowDefinition: RowDefinition;
    locale: Locale;
    mode?: 'card' | 'table';
    canChangeViewMode?: boolean;
    selectedViewMode?: 'card' | 'table';
    canSelect?: boolean;
    title?: string;
    dataOptions?: Dict<Dict<string>>;
    emptyStateMessage?: string;
    onSelectionChanged?: (selected: (string | number)[]) => void;
    onDataOptionsChanged?: (options: Dict<string>) => void;
    onRepresentationModeChanged?: (mode: 'card' | 'table') => void;
    stringLiterals: StringLiterals;
    callToActions?: Dict<CallToActionDefinition>;
    selectedDataOptions?: Dict<string>;
    loadMoreRows?: TableBodyRendererProps['loadMoreRows'];
    pageSize?: number;
}
export interface TableRowRendererProps {
    row: TableDataRow;
    rowDefinition: RowDefinition;
    locale: Locale;
    canSelect?: boolean;
    isSelected?: boolean;
    hasImage: boolean;
    hasIcon: boolean;
    onSelectionChange: (i: string | number) => void;
    style?: React.CSSProperties & {
        columnWidth?: number;
    };
}
export interface TableValueComponentProps {
    i: string | number;
    value: any;
    locale: Locale;
    definition?: ColumnDefinitionOptions;
    isLeftPosition?: boolean;
    isInTable?: boolean;
}
export interface TableBodyRendererProps {
    canSelect?: boolean;
    data: TableDataRow[];
    hasIcon: boolean;
    hasImage: boolean;
    height?: number;
    loadMoreRows?: (args: {
        startIndex: number;
        stopIndex: number;
        pageCount: number;
        pageSize: number;
        after?: TableDataRow;
        first: number;
    }) => Promise<TableDataRow[]>;
    locale: Locale;
    onSelectAllChange: (newState: boolean) => void;
    onSelectionChange: (i: string | number) => void;
    rowDefinition: RowDefinition;
    selectedRows: (string | number)[];
    setHasAllDataLoaded: (allDataLoaded: boolean) => void;
}
