import type { Layout } from 'react-grid-layout';
import type { IconType } from 'carbon-react/lib/components/icon/icon-type';
export interface LayoutDefinition {
    cols: number;
    rowHeight: number;
    width: number;
    isDraggable?: boolean;
    isResizable?: boolean;
    displayAnchors?: boolean;
    editMode?: boolean;
    /** Optional URL where the layout is sent using a PUT method whenever the user saves the changes */
    url?: string;
}
export declare type WidgetType = 'bar-chart' | 'basic' | 'gauge' | 'horizontal-bar' | 'line-chart' | 'line' | 'multiple-indicators' | 'simple-list' | 'pie-chart' | 'preview' | 'progress-tracker' | 'separator' | 'simple-indicator' | 'status-report' | 'table' | 'tile-indicator' | 'treemap' | 'visual-process';
export interface DropdownItem {
    i: string;
    label: string;
    icon?: IconType;
    action?: 'closeWidget' | 'editLayout';
    onClick?: () => void;
}
export interface DropdownItemDivider {
    i: string;
    isDivider?: boolean;
}
export interface DropdownDefinition {
    title?: string;
    items?: (DropdownItem | DropdownItemDivider)[];
}
export interface CallToActionDefinition {
    title: string;
    onClick: string | (() => void);
    target?: string;
    isDisabled?: boolean;
    isHidden?: boolean;
}
export interface AbstractWidget<T = any> extends Layout {
    type: WidgetType;
    i: string;
    title?: string;
    data?: T;
    dropdown?: DropdownDefinition;
    callToActions?: Dict<CallToActionDefinition>;
    url?: string;
}
export declare type Locale = 'en-US' | 'en-GB' | 'fr-FR' | 'es-ES' | 'pt-PT' | 'pt-BR' | 'ar-SA' | 'de-DE' | 'it-IT' | 'pl-PL' | 'zh-CN';
export declare type DashboardValueOrCallback<T> = T | ((i: string | number) => T);
export interface Dict<T> {
    [key: string]: T;
}
export interface StringLiterals {
    action_edit: string;
    action_close: string;
    action_delete: string;
    action_clone: string;
    action_share: string;
    general_invalid_json: string;
    general_finish_editing: string;
    general_welcome_page: string;
    dashboard_settings: string;
    table_select_all: string;
    table_variant_card: string;
    table_variant_table: string;
    table_variant_area: string;
    table_switch_to_table_view: string;
    table_switch_to_card_view: string;
    table_compare_with_previous_period: string;
    no_change: string;
    [key: string]: string | object;
}
export declare const NEW_WIDGET_ID = "__NEW_WIDGET";
export declare const PENDING_WIDGET_ID = "__PENDING_ITEM";
export declare type Currency = 'AED' | 'AFN' | 'ALL' | 'AMD' | 'ANG' | 'AOA' | 'ARS' | 'AUD' | 'AWG' | 'AZN' | 'BAM' | 'BBD' | 'BDT' | 'BGN' | 'BHD' | 'BIF' | 'BMD' | 'BND' | 'BOB' | 'BOV' | 'BRL' | 'BSD' | 'BTN' | 'BWP' | 'BYN' | 'BZD' | 'CAD' | 'CDF' | 'CHE' | 'CHF' | 'CHW' | 'CLF' | 'CLP' | 'CNY' | 'COP' | 'COU' | 'CRC' | 'CUC' | 'CUP' | 'CVE' | 'CZK' | 'DJF' | 'DKK' | 'DOP' | 'DZD' | 'EGP' | 'ERN' | 'ETB' | 'EUR' | 'FJD' | 'FKP' | 'GBP' | 'GEL' | 'GHS' | 'GIP' | 'GMD' | 'GNF' | 'GTQ' | 'GYD' | 'HKD' | 'HNL' | 'HRK' | 'HTG' | 'HUF' | 'IDR' | 'ILS' | 'INR' | 'IQD' | 'IRR' | 'ISK' | 'JMD' | 'JOD' | 'JPY' | 'KES' | 'KGS' | 'KHR' | 'KMF' | 'KPW' | 'KRW' | 'KWD' | 'KYD' | 'KZT' | 'LAK' | 'LBP' | 'LKR' | 'LRD' | 'LSL' | 'LYD' | 'MAD' | 'MDL' | 'MGA' | 'MKD' | 'MMK' | 'MNT' | 'MOP' | 'MRU' | 'MUR' | 'MVR' | 'MWK' | 'MXN' | 'MXV' | 'MYR' | 'MZN' | 'NAD' | 'NGN' | 'NIO' | 'NOK' | 'NPR' | 'NZD' | 'OMR' | 'PAB' | 'PEN' | 'PGK' | 'PHP' | 'PKR' | 'PLN' | 'PYG' | 'QAR' | 'RON' | 'RSD' | 'RUB' | 'RWF' | 'SAR' | 'SBD' | 'SCR' | 'SDG' | 'SEK' | 'SGD' | 'SHP' | 'SLE' | 'SLL' | 'SOS' | 'SRD' | 'SSP' | 'STN' | 'SVC' | 'SYP' | 'SZL' | 'THB' | 'TJS' | 'TMT' | 'TND' | 'TOP' | 'TRY' | 'TTD' | 'TWD' | 'TZS' | 'UAH' | 'UGX' | 'USD' | 'USN' | 'UYI' | 'UYU' | 'UYW' | 'UZS' | 'VED' | 'VES' | 'VND' | 'VUV' | 'WST' | 'XAF' | 'XAG' | 'XAU' | 'XBA' | 'XBB' | 'XBC' | 'XBD' | 'XCD' | 'XDR' | 'XOF' | 'XPD' | 'XPF' | 'XPT' | 'XSU' | 'XTS' | 'XUA' | 'XXX' | 'YER' | 'ZAR' | 'ZMW' | 'ZWL';
