import { BackendSettings } from "../contexts/BackendContext";
import { AxiosError } from "axios";
import { UseQueryResult } from "@tanstack/react-query";
export declare const backendIsMocked: (url: string) => boolean;
type Method = "get" | "post" | "put" | "delete" | "patch";
interface BackendServiceParams {
    [key: string]: string;
}
interface UseBackendServiceOptions<TData, TQueryData> {
    params?: BackendServiceParams;
    select?: (data: TQueryData) => TData;
    onSuccess?: (data: TData) => void;
    onError?: (err: AxiosError) => void;
    enabled?: boolean;
    refetchInterval?: number | false;
    refetchOnMount?: boolean;
    refetchOnReconnect?: boolean;
    refetchOnWindowFocus?: boolean;
    staleTime?: number;
}
export declare function fetchFromBackend<TQueryData, TParams>(backendSettings: BackendSettings, clientSpecific: boolean, endpoint: string, params: TParams, method?: Method): Promise<TQueryData>;
export declare function useBackendService<TData>(clientSpecific: boolean, endpoint: string, queryKeys: string[], options: UseBackendServiceOptions<TData, unknown>, method?: Method): UseQueryResult<TData, AxiosError>;
export declare function useBackendService<TData, TQueryData>(clientSpecific: boolean, endpoint: string, queryKeys: string[], options: UseBackendServiceOptions<TData, TQueryData>, method?: Method): UseQueryResult<TData, AxiosError>;
export default useBackendService;
